@@ -242,7 +242,7 @@ and use ``S`` to walk around the exchange graph of ``A``::
     sage: S.cluster_variable(3)
     (x2 + 1)/x3
 
-Walking around by mutating ``S`` updates the informations stored in ``A``::
+Walking around by mutating ``S`` updates the information stored in ``A``::
 
     sage: len(A.g_vectors_so_far())
     10
@@ -355,6 +355,7 @@ mutating at the initial seed::
 # ****************************************************************************
 
 from copy import copy
+from typing import Any
 
 from sage.arith.misc import binomial
 from sage.categories.homset import Hom
@@ -461,7 +462,7 @@ class ClusterAlgebraElement(ElementWrapper):
             sage: x.d_vector()
             (1, 1, 2, -2)
         """
-        monomials = self.lift().dict()
+        monomials = self.lift().monomial_coefficients()
         minimal = map(min, zip(*monomials))
         return tuple(-vector(minimal))[:self.parent().rank()]
 
@@ -562,7 +563,7 @@ class PrincipalClusterAlgebraElement(ClusterAlgebraElement):
         """
         deg_matrix = block_matrix([[identity_matrix(self.parent().rank()),
                                     -self.parent().b_matrix()]])
-        components = {}
+        components: dict[tuple, Any] = {}
         x = self.lift()
         monomials = x.monomials()
         for m in monomials:
@@ -571,12 +572,12 @@ class PrincipalClusterAlgebraElement(ClusterAlgebraElement):
                 components[g_vect] += self.parent().retract(x.monomial_coefficient(m) * m)
             else:
                 components[g_vect] = self.parent().retract(x.monomial_coefficient(m) * m)
-        for g_vect in components:
-            components[g_vect]._is_homogeneous = True
-            components[g_vect]._g_vector = g_vect
+        for g_vect, compo in components.items():
+            compo._is_homogeneous = True
+            compo._g_vector = g_vect
         self._is_homogeneous = (len(components) == 1)
         if self._is_homogeneous:
-            self._g_vector = list(components.keys())[0]
+            self._g_vector = next(iter(components))
         return components
 
     def theta_basis_decomposition(self):
@@ -614,8 +615,9 @@ class PrincipalClusterAlgebraElement(ClusterAlgebraElement):
             f_poly = components[g_vect].F_polynomial()
             g_vect = vector(g_vect)
             while f_poly != zero_U:
-                y_exp = min(f_poly.dict())
-                coeff = f_poly.dict()[y_exp]
+                coeffs = f_poly.monomial_coefficients()
+                y_exp = min(coeffs)
+                coeff = coeffs[y_exp]
                 g_theta = tuple(g_vect + B * vector(y_exp))
                 out[g_theta] = out.get(g_theta, zero_A) + A({zero_t + tuple(y_exp): coeff})
                 f_poly -= U({y_exp: coeff}) * A.theta_basis_F_polynomial(g_theta)
@@ -638,7 +640,7 @@ class ClusterAlgebraSeed(SageObject):
     - ``G`` -- the matrix of g-vectors of ``self``
     - ``parent`` -- :class:`ClusterAlgebra`; the algebra to which the
       seed belongs
-    - ``path`` -- list (default ``[]``); the mutation sequence from the
+    - ``path`` -- list (default: ``[]``); the mutation sequence from the
       initial seed of ``parent`` to ``self``
 
     .. WARNING::
@@ -902,7 +904,7 @@ class ClusterAlgebraSeed(SageObject):
 
         INPUT:
 
-        - ``j`` -- an integer in ``range(self.parent().rank())``;
+        - ``j`` -- integer in ``range(self.parent().rank())``;
           the index of the c-vector to return
 
         EXAMPLES::
@@ -953,7 +955,7 @@ class ClusterAlgebraSeed(SageObject):
 
         INPUT:
 
-        - ``j`` -- an integer in ``range(self.parent().rank())``;
+        - ``j`` -- integer in ``range(self.parent().rank())``;
           the index of the g-vector to return
 
         EXAMPLES::
@@ -984,7 +986,7 @@ class ClusterAlgebraSeed(SageObject):
 
         INPUT:
 
-        - ``j`` -- an integer in ``range(self.parent().rank())``;
+        - ``j`` -- integer in ``range(self.parent().rank())``;
           the index of the F-polynomial to return
 
         EXAMPLES::
@@ -1015,7 +1017,7 @@ class ClusterAlgebraSeed(SageObject):
 
         INPUT:
 
-        - ``j`` -- an integer in ``range(self.parent().rank())``;
+        - ``j`` -- integer in ``range(self.parent().rank())``;
           the index of the cluster variable to return
 
         EXAMPLES::
@@ -1055,9 +1057,10 @@ class ClusterAlgebraSeed(SageObject):
           * an iterable of such integers to mutate along a sequence
           * a string "sinks" or "sources" to mutate at all sinks or sources simultaneously
 
-        - ``inplace`` -- bool (default ``True``); whether to mutate in place or to return a new object
+        - ``inplace`` -- boolean (default: ``True``); whether to mutate in place
+          or to return a new object
 
-        - ``mutating_F`` -- bool (default ``True``); whether to compute
+        - ``mutating_F`` -- boolean (default: ``True``); whether to compute
           F-polynomials while mutating
 
         .. NOTE::
@@ -1162,10 +1165,10 @@ class ClusterAlgebraSeed(SageObject):
 
         INPUT:
 
-        - ``k`` --  an integer in ``range(self.parent().rank())``;
+        - ``k`` -- an integer in ``range(self.parent().rank())``;
           the direction in which we are mutating
 
-        - ``old_g_vector`` -- tuple; the k-th g-vector of ``self``
+        - ``old_g_vector`` -- tuple; the `k`-th g-vector of ``self``
           before mutating
 
         .. NOTE::
@@ -1219,22 +1222,22 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
     - ``data`` -- some data defining a cluster algebra; it can be anything
       that can be parsed by :class:`ClusterQuiver`
 
-    - ``scalars`` -- a ring (default `\ZZ`); the scalars over
+    - ``scalars`` -- a ring (default: `\ZZ`); the scalars over
       which the cluster algebra is defined
 
-    - ``cluster_variable_prefix`` -- string (default ``'x'``); it needs to be
+    - ``cluster_variable_prefix`` -- string (default: ``'x'``); it needs to be
       a valid variable name
 
-    - ``cluster_variable_names`` -- a list of strings; each element needs
+    - ``cluster_variable_names`` -- list of strings; each element needs
       to be a valid variable name;  supersedes ``cluster_variable_prefix``
 
-    - ``coefficient_prefix`` -- string (default ``'y'``); it needs to be
-      a valid variable name.
+    - ``coefficient_prefix`` -- string (default: ``'y'``); it needs to be
+      a valid variable name
 
-    - ``coefficient_names`` -- a list of strings; each element needs
+    - ``coefficient_names`` -- list of strings; each element needs
       to be a valid variable name; supersedes ``cluster_variable_prefix``
 
-    - ``principal_coefficients`` -- bool (default ``False``); supersedes any
+    - ``principal_coefficients`` -- boolean (default: ``False``); supersedes any
       coefficient defined by ``data``
 
     ALGORITHM:
@@ -1431,11 +1434,11 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
              and coefficients y0, y1 over Integer Ring
         """
         var_names = self.initial_cluster_variable_names()
-        var_names = (" " if len(var_names) == 1 else "s ") + ", ".join(var_names)
+        var_names_str = (" " if len(var_names) == 1 else "s ") + ", ".join(var_names)
         coeff_names = self.coefficient_names()
         coeff_prefix = " and" + (" " if len(coeff_names) > 0 else " no ") + "coefficient"
         coeff = coeff_prefix + (" " if len(coeff_names) == 1 else "s ") + ", ".join(coeff_names) + (" " if len(coeff_names) > 0 else "")
-        return "A Cluster Algebra with cluster variable" + var_names + coeff + "over " + repr(self.scalars())
+        return "A Cluster Algebra with cluster variable" + var_names_str + coeff + "over " + repr(self.scalars())
 
     def _an_element_(self):
         r"""
@@ -1811,7 +1814,7 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
 
         INPUT:
 
-        - ``mutating_F`` -- bool (default ``True``); whether to compute
+        - ``mutating_F`` -- boolean (default: ``True``); whether to compute
           F-polynomials; disable this for speed considerations
 
         ALGORITHM:
@@ -1990,12 +1993,13 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
 
     def find_g_vector(self, g_vector, depth=infinity):
         r"""
-        Return a mutation sequence to obtain a seed containing the g-vector ``g_vector`` from the initial seed.
+        Return a mutation sequence to obtain a seed containing the g-vector
+        ``g_vector`` from the initial seed.
 
         INPUT:
 
-        - ``g_vector`` -- a tuple: the g-vector to find
-        - ``depth`` -- a positive integer or infinity (default ``infinity``);
+        - ``g_vector`` -- tuple; the g-vector to find
+        - ``depth`` -- positive integer or infinity (default: ``infinity``);
           the maximum distance from ``self.current_seed`` to reach
 
         OUTPUT:
@@ -2090,7 +2094,7 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
         return self(x)
 
     @cached_method
-    def gens(self):
+    def gens(self) -> tuple:
         r"""
         Return the list of initial cluster variables and coefficients of ``self``.
 
@@ -2111,7 +2115,7 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
 
         INPUT:
 
-        - ``j`` -- an integer in ``range(self.parent().rank())``;
+        - ``j`` -- integer in ``range(self.parent().rank())``;
           the index of the coefficient to return
 
         EXAMPLES::
@@ -2167,7 +2171,7 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
 
         INPUT:
 
-        - ``j`` -- an integer in ``range(self.parent().rank())``;
+        - ``j`` -- integer in ``range(self.parent().rank())``;
           the index of the cluster variable to return
 
         EXAMPLES::
@@ -2212,19 +2216,19 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
 
         INPUT:
 
-        - ``from_current_seed`` -- bool (default ``False``); whether to start
+        - ``from_current_seed`` -- boolean (default: ``False``); whether to start
           the iterator from :meth:`current_seed` or :meth:`initial_seed`
 
-        - ``mutating_F`` -- bool (default ``True``); whether to compute
+        - ``mutating_F`` -- boolean (default: ``True``); whether to compute
           F-polynomials also; disable this for speed considerations
 
         - ``allowed_directions`` -- iterable of integers
-          (default ``range(self.rank())``); the directions in which to mutate
+          (default: ``range(self.rank())``); the directions in which to mutate
 
-        - ``depth`` -- a positive integer or infinity (default ``infinity``);
+        - ``depth`` -- positive integer or infinity (default: ``infinity``);
           the maximum depth at which to stop searching
 
-        - ``catch_KeyboardInterrupt`` -- bool (default ``False``); whether to
+        - ``catch_KeyboardInterrupt`` -- boolean (default: ``False``); whether to
           catch ``KeyboardInterrupt`` and return it rather then raising an
           exception -- this allows the iterator returned by this method to be
           resumed after being interrupted
@@ -2319,7 +2323,7 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
 
         INPUT:
 
-        - ``mutating_F`` -- bool (default ``True``); whether to also compute
+        - ``mutating_F`` -- boolean (default: ``True``); whether to also compute
           F-polynomials; disable this for speed considerations
 
         EXAMPLES::
@@ -2343,7 +2347,7 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
 
         INPUT:
 
-        - ``depth`` -- a positive integer or infinity; the maximum depth
+        - ``depth`` -- positive integer or infinity; the maximum depth
           at which to stop searching
 
         EXAMPLES::
@@ -2370,7 +2374,7 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
 
         INPUT:
 
-        - ``depth`` -- a positive integer or infinity (default ``infinity``);
+        - ``depth`` -- positive integer or infinity (default: ``infinity``);
           the maximum depth at which to compute
 
         EXAMPLES::
@@ -2401,7 +2405,7 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
           * an iterable of such integers to mutate along a sequence
           * a string "sinks" or "sources" to mutate at all sinks or sources simultaneously
 
-        - ``mutating_F`` -- bool (default ``True``); whether to compute
+        - ``mutating_F`` -- boolean (default: ``True``); whether to compute
           F-polynomials while mutating
 
         .. NOTE::
