@@ -155,9 +155,7 @@ def schur_representative_from_index(i0, i1):
 
     - A pair of tuples of length `r` with elements in `\{1,\dots,n\}`
 
-    OUTPUT:
-
-    - The corresponding pair of tuples ordered correctly.
+    OUTPUT: the corresponding pair of tuples ordered correctly
 
     EXAMPLES::
 
@@ -182,7 +180,7 @@ class SchurAlgebra(CombinatorialFreeModule):
     A Schur algebra.
 
     Let `R` be a commutative ring, `n` be a positive integer, and `r`
-    be a non-negative integer. Define `A_R(n,r)` to be the set of
+    be a nonnegative integer. Define `A_R(n,r)` to be the set of
     homogeneous polynomials of degree `r` in `n^2` variables `x_{ij}`.
     Therefore we can write `R[x_{ij}] = \bigoplus_{r \geq 0} A_R(n,r)`,
     and `R[x_{ij}]` is known to be a bialgebra with coproduct given by
@@ -225,7 +223,7 @@ class SchurAlgebra(CombinatorialFreeModule):
             sage: SchurAlgebra(ZZ, 2, -2)
             Traceback (most recent call last):
             ...
-            ValueError: r (=-2) must be a non-negative integer
+            ValueError: r (=-2) must be a nonnegative integer
             sage: SchurAlgebra('niet', 2, 2)
             Traceback (most recent call last):
             ...
@@ -234,7 +232,7 @@ class SchurAlgebra(CombinatorialFreeModule):
         if n not in ZZ or n <= 0:
             raise ValueError("n (={}) must be a positive integer".format(n))
         if r not in ZZ or r < 0:
-            raise ValueError("r (={}) must be a non-negative integer".format(r))
+            raise ValueError("r (={}) must be a nonnegative integer".format(r))
         if R not in Rings.Commutative():
             raise ValueError("R (={}) must be a commutative ring".format(R))
 
@@ -543,13 +541,11 @@ def GL_irreducible_character(n, mu, KK):
 
     INPUT:
 
-    - ``n`` -- a positive integer
-    - ``mu`` -- a partition of at most ``n`` parts
+    - ``n`` -- positive integer
+    - ``mu`` -- a partition of at most `n` parts
     - ``KK`` -- a field
 
-    OUTPUT:
-
-    a symmetric function which should be interpreted in ``n``
+    OUTPUT: a symmetric function which should be interpreted in `n`
     variables to be meaningful as a character
 
     EXAMPLES:
