@@ -47,17 +47,17 @@ diagonal, the coefficient is zero, because `3=1+2` and `10=2+8`: they
 both have a summand of 2.)
 
 Now, for each matrix with multinomial coefficient 1, let `t_n` be
-the sum of the nth diagonal in the matrix; then
+the sum of the `n`-th diagonal in the matrix; then
 
 .. MATH::
 
   \text{Sq}(r_1, r_2, ...) \text{Sq}(s_1, s_2, ...) = \sum \text{Sq}(t_1, t_2, ...)
 
 The function :func:`milnor_multiplication` takes as input two tuples
-of non-negative integers, `r` and `s`, which represent
+of nonnegative integers, `r` and `s`, which represent
 `\text{Sq}(r)=\text{Sq}(r_1, r_2, ...)` and
 `\text{Sq}(s)=\text{Sq}(s_1, s_2, ...)`; it returns as output a
-dictionary whose keys are tuples `t=(t_1, t_2, ...)` of non-negative
+dictionary whose keys are tuples `t=(t_1, t_2, ...)` of nonnegative
 integers, and for each tuple the associated value is the coefficient
 of `\text{Sq}(t)` in the product formula.  (Since we are working mod 2,
 this coefficient is 1 -- if it is zero, the element is omitted from
@@ -128,10 +128,10 @@ For example when `p=5`, we have
     \mathcal{P}(5) \mathcal{P}(1,1) = \mathcal{P}(6,1) + 2 \mathcal{P}(0,2).
 
 The function :func:`milnor_multiplication` takes as input two pairs of
-tuples of non-negative integers, `(g,q)` and `(f,s)`, which represent
+tuples of nonnegative integers, `(g,q)` and `(f,s)`, which represent
 `Q_{g_1} Q_{g_2} ... \mathcal{P}(q_1, q_2, ...)` and
 `Q_{f_1} Q_{f_2} ... \mathcal{P}(s_1, s_2, ...)`.  It returns as output a
-dictionary whose keys are pairs of tuples `(e,t)` of non-negative
+dictionary whose keys are pairs of tuples `(e,t)` of nonnegative
 integers, and for each tuple the associated value is the coefficient
 in the product formula.
 
@@ -158,7 +158,7 @@ there.  Repeat with the resulting terms.  One can prove that this
 process terminates in a finite number of steps, and therefore gives a
 procedure for multiplying elements of the Serre-Cartan basis.
 
-At an odd prime `p`, the Steenrod algebra is generated by the pth
+At an odd prime `p`, the Steenrod algebra is generated by the `p`-th
 power operations `\mathcal{P}^a` (the same as `\mathcal{P}(a)` in the
 Milnor basis) and the Bockstein operation `\beta` (= `Q_0` in the
 Milnor basis).  The odd primary *Adem relations* are as follows: if `a
@@ -190,7 +190,7 @@ prime 2, these form a basis for the Steenrod algebra.
 
 The main function for this is :func:`make_mono_admissible`,
 which converts a product of Steenrod
-squares or pth power operations and Bocksteins into a dictionary
+squares or `p`-th power operations and Bocksteins into a dictionary
 representing a sum of admissible monomials.
 """
 
@@ -204,19 +204,19 @@ from sage.misc.cachefunc import cached_function
 # Milnor, p=2
 
 
-def milnor_multiplication(r,s):
+def milnor_multiplication(r, s):
     r"""
     Product of Milnor basis elements r and s at the prime 2.
 
     INPUT:
 
-    - r -- tuple of non-negative integers
-    - s -- tuple of non-negative integers
+    - ``r`` -- tuple of nonnegative integers
+    - ``s`` -- tuple of nonnegative integers
 
     OUTPUT:
 
     Dictionary of terms of the form (tuple: coeff), where
-    'tuple' is a tuple of non-negative integers and 'coeff' is 1.
+    'tuple' is a tuple of nonnegative integers and 'coeff' is 1.
 
     This computes Milnor matrices for the product of `\text{Sq}(r)`
     and `\text{Sq}(s)`, computes their multinomial coefficients, and
@@ -312,9 +312,9 @@ def milnor_multiplication(r,s):
                     else:
                         sum = sum + M[i][j] * 2**j
                 else:
-                        sum = sum + M[i][j] * 2**j
-                j = j + 1
-            i = i + 1
+                    sum = sum + M[i][j] * 2**j
+                j += 1
+            i += 1
     return result
 
 
@@ -324,11 +324,9 @@ def multinomial(list):
 
     INPUT:
 
-    - list -- list of integers
+    - ``list`` -- list of integers
 
-    OUTPUT:
-
-    None if the multinomial coefficient is 0, or sum of list if it is 1
+    OUTPUT: none if the multinomial coefficient is 0, or sum of list if it is 1
 
     Given the input `[n_1, n_2, n_3, ...]`, this computes the
     multinomial coefficient `(n_1 + n_2 + n_3 + ...)! / (n_1! n_2!
@@ -374,16 +372,16 @@ def multinomial(list):
 # Milnor, p odd
 
 
-def milnor_multiplication_odd(m1,m2,p):
+def milnor_multiplication_odd(m1, m2, p):
     r"""
     Product of Milnor basis elements defined by m1 and m2 at the odd prime p.
 
     INPUT:
 
-    - m1 -- pair of tuples (e,r), where e is an increasing tuple of
-      non-negative integers and r is a tuple of non-negative integers
-    - m2 -- pair of tuples (f,s), same format as m1
-    - p -- odd prime number
+    - ``m1`` -- pair of tuples (e,r), where e is an increasing tuple of
+      nonnegative integers and r is a tuple of nonnegative integers
+    - ``m2`` -- pair of tuples (f,s), same format as m1
+    - ``p`` -- odd prime number
 
     OUTPUT:
 
@@ -570,18 +568,16 @@ def milnor_multiplication_odd(m1,m2,p):
     return result
 
 
-def multinomial_odd(list,p):
+def multinomial_odd(list, p):
     r"""
     Multinomial coefficient of list, mod p.
 
     INPUT:
 
-    - list -- list of integers
-    - p -- a prime number
+    - ``list`` -- list of integers
+    - ``p`` -- a prime number
 
-    OUTPUT:
-
-    Associated multinomial coefficient, mod p
+    OUTPUT: associated multinomial coefficient, mod p
 
     Given the input `[n_1, n_2, n_3, ...]`, this computes the
     multinomial coefficient `(n_1 + n_2 + n_3 + ...)! / (n_1! n_2!
@@ -639,7 +635,7 @@ def multinomial_odd(list,p):
 # Adem relations, Serre-Cartan basis, admissible sequences
 
 
-def binomial_mod2(n,k):
+def binomial_mod2(n, k):
     r"""
     The binomial coefficient `\binom{n}{k}`, computed mod 2.
 
@@ -647,9 +643,7 @@ def binomial_mod2(n,k):
 
     - `n`, `k` -- integers
 
-    OUTPUT:
-
-    `n` choose `k`, mod 2
+    OUTPUT: `n` choose `k`, mod 2
 
     EXAMPLES::
 
@@ -671,18 +665,16 @@ def binomial_mod2(n,k):
         return 0
 
 
-def binomial_modp(n,k,p):
+def binomial_modp(n, k, p):
     r"""
     The binomial coefficient `\binom{n}{k}`, computed mod `p`.
 
     INPUT:
 
     - `n`, `k` -- integers
-    - `p` -- prime number
+    - ``p`` -- prime number
 
-    OUTPUT:
-
-    `n` choose `k`, mod `p`
+    OUTPUT: `n` choose `k`, mod `p`
 
     EXAMPLES::
 
@@ -700,14 +692,14 @@ def binomial_modp(n,k,p):
 @cached_function
 def adem(a, b, c=0, p=2, generic=None):
     r"""
-    The mod `p` Adem relations
+    The mod `p` Adem relations.
 
     INPUT:
 
-    - `a`, `b`, `c` (optional) -- nonnegative integers, corresponding
+    - `a`, `b`, `c` -- nonnegative integers (optional); corresponding
       to either `P^a P^b` or (if `c` present) to `P^a \beta^b P^c`
-    - `p` -- positive prime number (default: 2)
-    - `generic` -- whether to use the generic Steenrod algebra, (default: depends on prime)
+    - ``p`` -- positive prime number (default: 2)
+    - ``generic`` -- whether to use the generic Steenrod algebra, (default: depends on prime)
 
     OUTPUT:
 
@@ -792,7 +784,7 @@ def adem(a, b, c=0, p=2, generic=None):
         return result
     # p odd
     if a == 0 and b == 0:
-            return {(c,): 1}
+        return {(c,): 1}
     if c == 0:
         bockstein = 0
         A = a
@@ -854,14 +846,14 @@ def make_mono_admissible(mono, p=2, generic=None):
 
     INPUT:
 
-    - ``mono`` -- a tuple of non-negative integers
-    - `p` -- prime number, optional (default 2)
-    - `generic` -- whether to use the generic Steenrod algebra, (default: depends on prime)
+    - ``mono`` -- tuple of nonnegative integers
+    - ``p`` -- prime number (default: 2)
+    - ``generic`` -- whether to use the generic Steenrod algebra (default: depends on prime)
 
     OUTPUT:
 
     Dictionary of terms of the form (tuple: coeff), where
-    'tuple' is an admissible tuple of non-negative integers and
+    'tuple' is an admissible tuple of nonnegative integers and
     'coeff' is its coefficient.  This corresponds to a linear
     combination of admissible monomials.  When `p` is odd, each tuple
     must have an odd length: it should be of the form `(e_1, i_1, e_2,
