@@ -100,12 +100,6 @@ warnings.filterwarnings('ignore', category=DeprecationWarning,
                         message=r"Pickle, copy, and deepcopy support will be "
                                 r"removed from itertools in Python 3.14.")
 
-# triggered in Python 3.9 on Redhat-based distributions
-# https://github.com/sagemath/sage/issues/37863
-# https://github.com/networkx/networkx/issues/7101
-warnings.filterwarnings('ignore', category=RuntimeWarning,
-                        message="networkx backend defined more than once: nx-loopback")
-
 from sage.all__sagemath_objects import *
 from sage.all__sagemath_environment import *
 
