@@ -46,8 +46,80 @@ class CommutativeRings(CategoryWithAxiom):
 
         sage: GroupAlgebra(CyclicPermutationGroup(3), QQ) in CommutativeRings()     # not implemented, needs sage.groups sage.modules
         True
+
+    Some tests for the method ``is_commutative``::
+
+        sage: QQ.is_commutative()
+        True
+        sage: ZpCA(7).is_commutative()                                              # needs sage.rings.padics
+        True
+        sage: A = QuaternionAlgebra(QQ, -1, -3, names=('i','j','k')); A             # needs sage.combinat sage.modules
+        Quaternion Algebra (-1, -3) with base ring Rational Field
+        sage: A.is_commutative()                                                    # needs sage.combinat sage.modules
+        False
     """
     class ParentMethods:
+        def krull_dimension(self):
+            """
+            Return the Krull dimension of this commutative ring.
+
+            The Krull dimension is the length of the longest ascending chain
+            of prime ideals.
+
+            This raises :exc:`NotImplementedError` by default
+            for generic commutative rings.
+
+            Fields and PIDs, with Krull dimension equal to 0 and 1,
+            respectively, have naive implementations of ``krull_dimension``.
+            Orders in number fields also have Krull dimension 1.
+
+            EXAMPLES:
+
+            Some polynomial rings::
+
+                sage: T.<x,y> = PolynomialRing(QQ,2); T
+                Multivariate Polynomial Ring in x, y over Rational Field
+                sage: T.krull_dimension()
+                2
+                sage: U.<x,y,z> = PolynomialRing(ZZ,3); U
+                Multivariate Polynomial Ring in x, y, z over Integer Ring
+                sage: U.krull_dimension()
+                4
+
+            All orders in number fields have Krull dimension 1, including
+            non-maximal orders::
+
+                sage: # needs sage.rings.number_field
+                sage: K.<i> = QuadraticField(-1)
+                sage: R = K.order(2*i); R
+                Order of conductor 2 generated by 2*i
+                 in Number Field in i with defining polynomial x^2 + 1 with i = 1*I
+                sage: R.is_maximal()
+                False
+                sage: R.krull_dimension()
+                1
+                sage: R = K.maximal_order(); R
+                Gaussian Integers generated by i in Number Field in i
+                 with defining polynomial x^2 + 1 with i = 1*I
+                sage: R.krull_dimension()
+                1
+
+            TESTS::
+
+                sage: R = CommutativeRing(ZZ)
+                sage: R.krull_dimension()
+                Traceback (most recent call last):
+                ...
+                NotImplementedError
+
+                sage: R = GF(9).galois_group().algebra(QQ)
+                sage: R.krull_dimension()
+                Traceback (most recent call last):
+                ...
+                NotImplementedError
+            """
+            raise NotImplementedError
+
         def is_commutative(self) -> bool:
             """
             Return whether the ring is commutative.
@@ -68,12 +140,13 @@ class CommutativeRings(CategoryWithAxiom):
 
         def _ideal_class_(self, n=0):
             r"""
-            Return a callable object that can be used to create ideals in this
-            commutative ring.
+            Return a callable object that can be used to create ideals
+            in this commutative ring.
 
-            This class can depend on `n`, the number of generators of the ideal.
-            The default input of `n=0` indicates an unspecified number of generators,
-            in which case a class that works for any number of generators is returned.
+            This class can depend on `n`, the number of generators of
+            the ideal.  The default input of `n=0` indicates an
+            unspecified number of generators, in which case a class
+            that works for any number of generators is returned.
 
             EXAMPLES::
 
