@@ -5,7 +5,8 @@ Rings
 # ****************************************************************************
 #  Copyright (C) 2005      David Kohel <kohel@maths.usyd.edu>
 #                          William Stein <wstein@math.ucsd.edu>
-#                2008      Teresa Gomez-Diaz (CNRS) <Teresa.Gomez-Diaz@univ-mlv.fr>
+#                2008      Teresa Gomez-Diaz (CNRS)
+#                          <Teresa.Gomez-Diaz@univ-mlv.fr>
 #                2008-2011 Nicolas M. Thiery <nthiery at users.sf.net>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
@@ -16,6 +17,7 @@ from types import GeneratorType
 
 from sage.misc.cachefunc import cached_method
 from sage.misc.lazy_import import LazyImport
+from sage.misc.prandom import randint
 from sage.categories.category_with_axiom import CategoryWithAxiom
 from sage.categories.rngs import Rngs
 from sage.structure.element import Element
@@ -423,6 +425,29 @@ class Rings(CategoryWithAxiom):
 
             return False
 
+        def is_integrally_closed(self) -> bool:
+            r"""
+            Return whether this ring is integrally closed.
+
+            This is the default implementation that
+            raises a :exc:`NotImplementedError`.
+
+            EXAMPLES::
+
+                sage: x = polygen(ZZ, 'x')
+                sage: K.<a> = NumberField(x^2 + 189*x + 394)
+                sage: R = K.order(2*a)
+                sage: R.is_integrally_closed()
+                False
+                sage: R
+                Order of conductor 2 generated by 2*a in Number Field in a with defining polynomial x^2 + 189*x + 394
+                sage: S = K.maximal_order(); S
+                Maximal Order generated by a in Number Field in a with defining polynomial x^2 + 189*x + 394
+                sage: S.is_integrally_closed()
+                True
+            """
+            raise NotImplementedError
+
         def is_noetherian(self):
             """
             Return ``True`` if this ring is Noetherian.
@@ -531,6 +556,22 @@ class Rings(CategoryWithAxiom):
             except (TypeError, AttributeError):
                 return False
 
+        def localization(self, *args, **kwds):
+            """
+            Return the localization of ``self``.
+
+            This only works for integral domains.
+
+            EXAMPLES::
+
+                sage: R = Zmod(6)
+                sage: R.localization((4))
+                Traceback (most recent call last):
+                ...
+                TypeError: self must be an integral domain
+            """
+            raise TypeError("self must be an integral domain")
+
         def bracket(self, x, y):
             """
             Return the Lie bracket `[x, y] = x y - y x` of `x` and `y`.
@@ -621,8 +662,8 @@ class Rings(CategoryWithAxiom):
 
             INPUT:
 
-            - `x`, an object to multiply with.
-            - `switch_sides` (optional bool): If ``False``,
+            - ``x``, an object to multiply with.
+            - ``switch_sides`` (optional bool): If ``False``,
               the product is ``self*x``; if ``True``, the
               product is ``x*self``.
 
@@ -712,108 +753,20 @@ class Rings(CategoryWithAxiom):
                 from sage.modules.free_module import FreeModule
                 return FreeModule(self, n)
 
-        @cached_method
-        def ideal_monoid(self):
+        def nilradical(self):
             """
-            The monoid of the ideals of this ring.
+            Return the nilradical of this ring.
 
             EXAMPLES::
 
-                sage: # needs sage.modules
-                sage: MS = MatrixSpace(QQ, 2, 2)
-                sage: isinstance(MS, Ring)
-                False
-                sage: MS in Rings()
-                True
-                sage: MS.ideal_monoid()
-                Monoid of ideals of Full MatrixSpace of 2 by 2 dense matrices
-                over Rational Field
+                sage: QQ['x,y'].nilradical()
+                Ideal (0) of Multivariate Polynomial Ring in x, y over Rational Field
 
-            Note that the monoid is cached::
+            .. SEEALSO::
 
-                sage: MS.ideal_monoid() is MS.ideal_monoid()                            # needs sage.modules
-                True
-
-            More examples::
-
-                sage: # needs sage.combinat sage.modules
-                sage: F.<x,y,z> = FreeAlgebra(ZZ, 3)
-                sage: I = F * [x*y + y*z, x^2 + x*y - y*x - y^2] * F
-                sage: Q = F.quotient(I)
-                sage: Q.ideal_monoid()
-                Monoid of ideals of Quotient of Free Algebra on 3 generators (x, y, z)
-                 over Integer Ring by the ideal (x*y + y*z, x^2 + x*y - y*x - y^2)
-                sage: F.<x,y,z> = FreeAlgebra(ZZ, implementation='letterplace')
-                sage: I = F * [x*y + y*z, x^2 + x*y - y*x - y^2] * F
-                sage: Q = F.quo(I)
-                sage: Q.ideal_monoid()
-                Monoid of ideals of Quotient of Free Associative Unital Algebra
-                 on 3 generators (x, y, z) over Integer Ring
-                 by the ideal (x*y + y*z, x*x + x*y - y*x - y*y)
-
-                sage: ZZ.ideal_monoid()
-                Monoid of ideals of Integer Ring
-                sage: R.<x> = QQ[]; R.ideal_monoid()
-                Monoid of ideals of Univariate Polynomial Ring in x over Rational Field
+                :meth:`~sage.categories.finite_dimensional_lie_algebras_with_basis.FiniteDimensionalLieAlgebrasWithBasis.ParentMethods.nilradical`
             """
-            try:
-                from sage.rings.ideal_monoid import IdealMonoid
-                return IdealMonoid(self)
-            except TypeError:
-                from sage.rings.noncommutative_ideals import IdealMonoid_nc
-                return IdealMonoid_nc(self)
-
-        def _ideal_class_(self, n=0):
-            r"""
-            Return a callable object that can be used to create ideals in this
-            ring.
-
-            EXAMPLES::
-
-                sage: MS = MatrixSpace(QQ, 2, 2)                                        # needs sage.modules
-                sage: MS._ideal_class_()                                                # needs sage.modules
-                <class 'sage.rings.noncommutative_ideals.Ideal_nc'>
-
-            Since :issue:`7797`, non-commutative rings have ideals as well::
-
-                sage: A = SteenrodAlgebra(2)                                                # needs sage.combinat sage.modules
-                sage: A._ideal_class_()                                                     # needs sage.combinat sage.modules
-                <class 'sage.rings.noncommutative_ideals.Ideal_nc'>
-            """
-            from sage.rings.noncommutative_ideals import Ideal_nc
-            return Ideal_nc
-
-        @cached_method
-        def zero_ideal(self):
-            """
-            Return the zero ideal of this ring (cached).
-
-            EXAMPLES::
-
-                sage: ZZ.zero_ideal()
-                Principal ideal (0) of Integer Ring
-                sage: QQ.zero_ideal()
-                Principal ideal (0) of Rational Field
-                sage: QQ['x'].zero_ideal()
-                Principal ideal (0) of Univariate Polynomial Ring in x over Rational Field
-
-            The result is cached::
-
-                sage: ZZ.zero_ideal() is ZZ.zero_ideal()
-                True
-
-            TESTS:
-
-            Make sure that :issue:`13644` is fixed::
-
-                sage: # needs sage.rings.padics
-                sage: K = Qp(3)
-                sage: R.<a> = K[]
-                sage: L.<a> = K.extension(a^2-3)
-                sage: L.ideal(a)
-                Principal ideal (1 + O(a^40)) of 3-adic Eisenstein Extension Field in a defined by a^2 - 3
-            """
-            return self._ideal_class_(1)(self, [self.zero()])
+            return self.zero_ideal().radical()
 
         @cached_method
         def unit_ideal(self):
@@ -827,21 +780,6 @@ class Rings(CategoryWithAxiom):
             """
             return self._ideal_class_(1)(self, [self.one()])
 
-        def principal_ideal(self, gen, coerce=True):
-            """
-            Return the principal ideal generated by gen.
-
-            EXAMPLES::
-
-                sage: R.<x,y> = ZZ[]
-                sage: R.principal_ideal(x+2*y)
-                Ideal (x + 2*y) of Multivariate Polynomial Ring in x, y over Integer Ring
-            """
-            C = self._ideal_class_(1)
-            if coerce:
-                gen = self(gen)
-            return C(self, [gen])
-
         def characteristic(self):
             """
             Return the characteristic of this ring.
@@ -964,6 +902,22 @@ class Rings(CategoryWithAxiom):
                 Principal ideal (0) of Univariate Polynomial Ring in x over Rational Field
                 sage: R.ideal()
                 Principal ideal (0) of Univariate Polynomial Ring in x over Rational Field
+
+            Check ``ideal_class=`` keyword argument when input is empty::
+
+                sage: from sage.rings.ideal import Ideal_pid
+                sage: class CustomIdealClass(Ideal_pid):
+                ....:     pass
+                sage: type(ZZ.ideal(6))
+                <class 'sage.rings.ideal.Ideal_pid'>
+                sage: type(ZZ.ideal(6, ideal_class=CustomIdealClass))
+                <class '...CustomIdealClass'>
+                sage: type(ZZ.ideal())
+                <class 'sage.rings.ideal.Ideal_pid'>
+                sage: type(ZZ.ideal(ideal_class=CustomIdealClass))
+                <class '...CustomIdealClass'>
+                sage: type(ZZ.ideal((), ideal_class=CustomIdealClass))
+                <class '...CustomIdealClass'>
             """
             if 'coerce' in kwds:
                 coerce = kwds['coerce']
@@ -1607,6 +1561,40 @@ class Rings(CategoryWithAxiom):
                 if not x.is_zero():
                     return x
 
+        def random_element(self, *args):
+            """
+            Return a random integer coerced into this ring.
+
+            INPUT:
+
+            - either no integer, one integer or two integers
+
+            The integer is chosen uniformly from the closed interval
+            ``[-2,2]``, ``[-a,a]`` or ``[a,b]`` according to the
+            length of the input.
+
+            ALGORITHM:
+
+            This uses Python's ``randint``.
+
+            EXAMPLES::
+
+                sage: -8 <= ZZ.random_element(8) <= 8
+                True
+                sage: -8 <= QQ.random_element(8) <= 8
+                True
+                sage: 4 <= ZZ.random_element(4,12) <= 12
+                True
+            """
+            if not args:
+                a, b = -2, 2
+            elif len(args) == 1:
+                bound = args[0]
+                a, b = -bound, bound
+            else:
+                a, b = args[0], args[1]
+            return randint(a, b) * self.one()
+
     class ElementMethods:
         def is_unit(self) -> bool:
             r"""
