@@ -60,18 +60,18 @@ class Semigroups(CategoryWithAxiom):
     """
     _base_category_class_and_axiom = (Magmas, "Associative")
 
-    def example(self, choice="leftzero", **kwds):
+    def example(self, choice='leftzero', **kwds):
         r"""
-        Returns an example of a semigroup, as per
+        Return an example of a semigroup, as per
         :meth:`Category.example()
         <sage.categories.category.Category.example>`.
 
         INPUT:
 
-        - ``choice`` -- str (default: 'leftzero'). Can be either 'leftzero'
-          for the left zero semigroup, or 'free' for the free semigroup.
+        - ``choice`` -- string (default: ``'leftzero'``); can be either 'leftzero'
+          for the left zero semigroup, or 'free' for the free semigroup
         - ``**kwds`` -- keyword arguments passed onto the constructor for the
-          chosen semigroup.
+          chosen semigroup
 
         EXAMPLES::
 
@@ -81,7 +81,6 @@ class Semigroups(CategoryWithAxiom):
             An example of a semigroup: the free semigroup generated by ('a', 'b', 'c', 'd')
             sage: Semigroups().example(choice='free', alphabet=('a','b'))
             An example of a semigroup: the free semigroup generated by ('a', 'b')
-
         """
         import sage.categories.examples.semigroups as examples
         if choice == "leftzero":
@@ -114,7 +113,6 @@ class Semigroups(CategoryWithAxiom):
                 sage: L._test_associativity(elements = (L(1), L(2), L(3)))
 
             See the documentation for :class:`TestSuite` for more information.
-
             """
             tester = self._tester(**options)
             S = tester.some_elements()
@@ -173,26 +171,23 @@ class Semigroups(CategoryWithAxiom):
             assert len(args) > 0, "Cannot compute an empty product in a semigroup"
             return prod(args[1:], args[0])
 
-        def cayley_graph(self, side="right", simple=False, elements=None,
+        def cayley_graph(self, side='right', simple=False, elements=None,
                          generators=None, connecting_set=None):
             r"""
             Return the Cayley graph for this finite semigroup.
 
             INPUT:
 
-            - ``side`` -- "left", "right", or "twosided":
-              the side on which the generators act (default:"right")
-            - ``simple`` -- boolean (default: ``False``):
-              if True, returns a simple graph (no loops, no labels,
-              no multiple edges)
-            - ``generators`` -- a list, tuple, or family of elements
+            - ``side`` -- ``'left'``, ``'right'``, or ``'twosided'``:
+              the side on which the generators act (default: ``'right'``)
+            - ``simple`` -- boolean (default: ``False``); if ``True``, returns
+              a simple graph (no loops, no labels, no multiple edges)
+            - ``generators`` -- list; tuple, or family of elements
               of ``self`` (default: ``self.semigroup_generators()``)
             - ``connecting_set`` -- alias for ``generators``; deprecated
-            - ``elements`` -- a list (or iterable) of elements of ``self``
+            - ``elements`` -- list (or iterable) of elements of ``self``
 
-            OUTPUT:
-
-            - :class:`DiGraph`
+            OUTPUT: :class:`DiGraph`
 
             EXAMPLES:
 
@@ -263,7 +258,7 @@ class Semigroups(CategoryWithAxiom):
 
             ::
 
-                sage: g = S.cayley_graph(side="left", simple=True)                      # needs sage.graphs
+                sage: g = S.cayley_graph(side='left', simple=True)                      # needs sage.graphs
                 sage: g.vertices(sort=True)                                             # needs sage.graphs
                 ['a', 'ab', 'b', 'ba']
                 sage: g.edges(sort=True)                                                # needs sage.graphs
@@ -272,7 +267,7 @@ class Semigroups(CategoryWithAxiom):
 
             ::
 
-                sage: g = S.cayley_graph(side="twosided", simple=True)                  # needs sage.graphs
+                sage: g = S.cayley_graph(side='twosided', simple=True)                  # needs sage.graphs
                 sage: g.vertices(sort=True)                                             # needs sage.graphs
                 ['a', 'ab', 'b', 'ba']
                 sage: g.edges(sort=True)                                                # needs sage.graphs
@@ -281,7 +276,7 @@ class Semigroups(CategoryWithAxiom):
 
             ::
 
-                sage: g = S.cayley_graph(side="twosided")                               # needs sage.graphs
+                sage: g = S.cayley_graph(side='twosided')                               # needs sage.graphs
                 sage: g.vertices(sort=True)                                             # needs sage.graphs
                 ['a', 'ab', 'b', 'ba']
                 sage: g.edges(sort=True)                                                # needs sage.graphs
@@ -295,7 +290,7 @@ class Semigroups(CategoryWithAxiom):
 
             TESTS::
 
-                sage: SymmetricGroup(2).cayley_graph(side="both")                       # needs sage.graphs sage.groups
+                sage: SymmetricGroup(2).cayley_graph(side='both')                       # needs sage.graphs sage.groups
                 Traceback (most recent call last):
                 ...
                 ValueError: option 'side' must be 'left', 'right' or 'twosided'
@@ -344,7 +339,7 @@ class Semigroups(CategoryWithAxiom):
                     generators = self.semigroup_generators()
             if isinstance(generators, (list, tuple)):
                 generators = {self(g): self(g) for g in generators}
-            left = (side == "left"  or side == "twosided")
+            left = (side == "left" or side == "twosided")
             right = (side == "right" or side == "twosided")
 
             def add_edge(source, target, label, side_label):
@@ -379,7 +374,7 @@ class Semigroups(CategoryWithAxiom):
               ``self``, or a list, iterable, ... that can be converted
               into one (see :class:`Family`).
 
-            - ``one`` -- a unit for the subsemigroup, or ``None``.
+            - ``one`` -- a unit for the subsemigroup, or ``None``
 
             - ``category`` -- a category
 
@@ -457,7 +452,7 @@ class Semigroups(CategoryWithAxiom):
             return AutomaticSemigroup(generators, ambient=self, one=one,
                                       category=category)
 
-        def trivial_representation(self, base_ring=None, side="twosided"):
+        def trivial_representation(self, base_ring=None, side='twosided'):
             r"""
             Return the trivial representation of ``self`` over ``base_ring``.
 
@@ -479,12 +474,12 @@ class Semigroups(CategoryWithAxiom):
             from sage.modules.with_basis.representation import TrivialRepresentation
             return TrivialRepresentation(self, base_ring)
 
-        def regular_representation(self, base_ring=None, side="left"):
+        def regular_representation(self, base_ring=None, side='left'):
             """
             Return the regular representation of ``self`` over ``base_ring``.
 
-            - ``side`` -- (default: ``"left"``) whether this is the
-              ``"left"`` or ``"right"`` regular representation
+            - ``side`` -- (default: ``'left'``) whether this is the
+              ``'left'`` or ``'right'`` regular representation
 
             EXAMPLES::
 
@@ -499,7 +494,7 @@ class Semigroups(CategoryWithAxiom):
             from sage.modules.with_basis.representation import RegularRepresentation
             return RegularRepresentation(self, base_ring, side)
 
-        def representation(self, module, on_basis, side="left", *args, **kwargs):
+        def representation(self, module, on_basis, side='left', *args, **kwargs):
             r"""
             Return a representation of ``self`` on ``module`` with
             the action given by ``on_basis``.
@@ -511,11 +506,12 @@ class Semigroups(CategoryWithAxiom):
               ``g`` is an element of the semigroup and ``m`` is an element of the
               indexing set for the basis, and returns the result of ``g`` acting
               on ``m``
-            - ``side`` -- (default: ``"left"``) whether this is a
-              ``"left"`` or ``"right"`` representation
+            - ``side`` -- (default: ``'left'``) whether this is a
+              ``'left'`` or ``'right'`` representation
 
             EXAMPLES::
 
+                sage: # needs sage.groups
                 sage: G = CyclicPermutationGroup(3)
                 sage: M = algebras.Exterior(QQ, 'x', 3)
                 sage: def on_basis(g, m):  # cyclically permute generators
@@ -533,11 +529,11 @@ class Semigroups(CategoryWithAxiom):
 
         def _pow_int(self, n):
             """
-            Return ``self`` to the `n^{th}` power.
+            Return ``self`` to the `n`-th power.
 
             INPUT:
 
-            - ``n`` -- a positive integer
+            - ``n`` -- positive integer
 
             EXAMPLES::
 
@@ -830,7 +826,7 @@ class Semigroups(CategoryWithAxiom):
 
         def example(self):
             """
-            Returns an example of subquotient of a semigroup, as per
+            Return an example of subquotient of a semigroup, as per
             :meth:`Category.example()
             <sage.categories.category.Category.example>`.
 
@@ -1006,7 +1002,7 @@ class Semigroups(CategoryWithAxiom):
                 """
                 return self.monomial(g1 * g2)
 
-            def trivial_representation(self, side="twosided"):
+            def trivial_representation(self, side='twosided'):
                 """
                 Return the trivial representation of ``self``.
 
@@ -1026,14 +1022,14 @@ class Semigroups(CategoryWithAxiom):
                 S = self.basis().keys()
                 return S.trivial_representation(self.base_ring())
 
-            def regular_representation(self, side="left"):
+            def regular_representation(self, side='left'):
                 """
                 Return the regular representation of ``self``.
 
                 INPUT:
 
-                - ``side`` -- (default: ``"left"``) whether this is the
-                  ``"left"`` or ``"right"`` regular representation
+                - ``side`` -- (default: ``'left'``) whether this is the
+                  ``'left'`` or ``'right'`` regular representation
 
                 EXAMPLES::
 
@@ -1047,7 +1043,7 @@ class Semigroups(CategoryWithAxiom):
                 S = self.basis().keys()
                 return S.regular_representation(self.base_ring(), side)
 
-            def representation(self, module, on_basis, side="left", *args, **kwargs):
+            def representation(self, module, on_basis, side='left', *args, **kwargs):
                 r"""
                 Return a representation of ``self`` on ``module`` with
                 the action of the semigroup given by ``on_basis``.
@@ -1059,11 +1055,12 @@ class Semigroups(CategoryWithAxiom):
                   ``g`` is an element of the semigroup and ``m`` is an element of the
                   indexing set for the basis, and returns the result of ``g`` acting
                   on ``m``
-                - ``side`` -- (default: ``"left"``) whether this is a
-                  ``"left"`` or ``"right"`` representation
+                - ``side`` -- (default: ``'left'``) whether this is a
+                  ``'left'`` or ``'right'`` representation
 
                 EXAMPLES::
 
+                    sage: # needs sage.groups
                     sage: G = groups.permutation.Dihedral(5)
                     sage: CFM = CombinatorialFreeModule(GF(2), [1, 2, 3, 4, 5])
                     sage: A = G.algebra(GF(2))
