@@ -67,7 +67,9 @@ class QuiverMutationTypeFactory(SageObject):
             _mutation_type_error(data)
 
         # check for reducible types
-        if all(type(data_component) in [list, tuple, QuiverMutationType_Irreducible] for data_component in data):
+        if all(isinstance(data_component, (list, tuple,
+                                           QuiverMutationType_Irreducible))
+               for data_component in data):
             if len(data) == 1:
                 return QuiverMutationType(data[0])
             else:
@@ -680,11 +682,11 @@ class QuiverMutationType_abstract(UniqueRepresentation, SageObject):
 
         INPUT:
 
-        - ``circular`` -- (default: ``False``) if ``True``, the
-          circular plot is chosen, otherwise >>spring<< is used.
+        - ``circular`` -- boolean (default: ``False``); if ``True``, the
+          circular plot is chosen, otherwise >>spring<< is used
 
-        - ``directed`` -- (default: ``True``) if ``True``, the
-          directed version is shown, otherwise the undirected.
+        - ``directed`` -- boolean (default: ``True``); if ``True``, the
+          directed version is shown, otherwise the undirected
 
         EXAMPLES::
 
@@ -700,15 +702,15 @@ class QuiverMutationType_abstract(UniqueRepresentation, SageObject):
 
         INPUT:
 
-        - ``circular`` -- (default:``False``) if ``True``, the
-          circular plot is chosen, otherwise >>spring<< is used.
+        - ``circular`` -- boolean (default: ``False``); if ``True``, the
+          circular plot is chosen, otherwise >>spring<< is used
 
-        - ``directed`` -- (default: ``True``) if ``True``, the
-          directed version is shown, otherwise the undirected.
+        - ``directed`` -- boolean (default: ``True``); if ``True``, the
+          directed version is shown, otherwise the undirected
 
         TESTS::
 
-            sage: QMT = QuiverMutationType(['A',5])
+            sage: QMT = QuiverMutationType(['A', 5])
             sage: QMT.show()                    # long time                             # needs sage.plot sage.symbolic
         """
         self.plot(circular=circular, directed=directed).show()
@@ -1973,8 +1975,8 @@ class QuiverMutationType_Reducible(QuiverMutationType_abstract):
 
         INPUT:
 
-        - ``data`` -- a list each of whose entries is a
-          QuiverMutationType_Irreducible
+        - ``data`` -- list; each of whose entries is a
+          :class:`QuiverMutationType_Irreducible`
 
         EXAMPLES::
 
@@ -1983,7 +1985,7 @@ class QuiverMutationType_Reducible(QuiverMutationType_abstract):
         """
         data = args
         if len(data) < 2 or not all(isinstance(comp, QuiverMutationType_Irreducible) for comp in data):
-            return _mutation_type_error(data)
+            _mutation_type_error(data)
 
         # _info is initialized
         self._info = {}
@@ -2287,7 +2289,7 @@ def _save_data_dig6(n, types='ClassicalExceptional', verbose=False):
 def save_quiver_data(n, up_to=True, types='ClassicalExceptional', verbose=True):
     r"""
     Save mutation classes of certain quivers of ranks up to and equal
-    to ``n`` or equal to ``n`` to
+    to `n` or equal to `n` to
     ``DOT_SAGE/cluster_algebra_quiver/mutation_classes_n.dig6``.
 
     This data will then be used to determine quiver mutation types.
@@ -2295,16 +2297,16 @@ def save_quiver_data(n, up_to=True, types='ClassicalExceptional', verbose=True):
     INPUT:
 
     - ``n`` -- the rank (or the upper limit on the rank) of the mutation
-      classes that are being saved.
+      classes that are being saved
 
-    - ``up_to`` -- (default:``True``) if ``True``, saves data for
-      ranks smaller than or equal to ``n``. If ``False``, saves data
-      for rank exactly ``n``.
+    - ``up_to`` -- (default: ``True``) if ``True``, saves data for
+      ranks smaller than or equal to `n`; if ``False``, saves data
+      for rank exactly `n`
 
-    - ``types`` -- (default:'ClassicalExceptional') if all, saves data
+    - ``types`` -- (default: ``'ClassicalExceptional'``) if all, saves data
       for both exceptional mutation-finite quivers and for classical
-      quiver. The input 'Exceptional' or 'Classical' is also allowed
-      to save only part of this data.
+      quiver; the input 'Exceptional' or 'Classical' is also allowed
+      to save only part of this data
 
     TESTS::
 
