@@ -164,27 +164,24 @@ Functions and classes
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 from __future__ import annotations
-from typing import Iterator
+from collections.abc import Iterator
 
 from sage.arith.misc import bernoulli, factorial
 from sage.rings.integer_ring import ZZ
 from sage.rings.rational_field import QQ
 from sage.rings.integer import Integer
-from sage.rings.infinity import infinity
 from sage.rings.polynomial.polynomial_element import Polynomial
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
 from sage.misc.misc_c import prod
 from sage.misc.cachefunc import cached_function
 from sage.structure.sage_object import SageObject
-from sage.structure.parent import Parent
 from sage.misc.lazy_import import lazy_import
-from sage.misc.lazy_attribute import lazy_attribute
 from .combinat_cython import _stirling_number2
 from sage.misc.inherit_comparison import InheritComparisonClasscallMetaclass
 from sage.structure.element import Element
 
 lazy_import('sage.interfaces.maxima_lib', 'maxima')
-lazy_import('sage.libs.pari.all', 'pari')
+lazy_import('sage.libs.pari', 'pari')
 lazy_import('sage.misc.prandom', 'randint')
 
 
@@ -197,17 +194,17 @@ def bell_number(n, algorithm='flint', **options) -> Integer:
 
     INPUT:
 
-    - ``n`` -- a positive integer
+    - ``n`` -- positive integer
 
-    - ``algorithm`` -- (Default: ``'flint'``) any one of the following:
+    - ``algorithm`` -- (default: ``'flint'``) any one of the following:
 
-      - ``'dobinski'`` -- Use Dobinski's formula implemented in Sage
+      - ``'dobinski'`` -- use Dobinski's formula implemented in Sage
 
-      - ``'flint'`` -- Wrap FLINT's ``arith_bell_number``
+      - ``'flint'`` -- wrap FLINT's ``arith_bell_number``
 
-      - ``'gap'`` -- Wrap GAP's ``Bell``
+      - ``'gap'`` -- wrap GAP's ``Bell``
 
-      - ``'mpmath'`` -- Wrap mpmath's ``bell``
+      - ``'mpmath'`` -- wrap mpmath's ``bell``
 
     .. WARNING::
 
@@ -466,9 +463,7 @@ def catalan_number(n):
 
     - ``n`` -- integer
 
-    OUTPUT:
-
-    integer
+    OUTPUT: integer
 
     EXAMPLES::
 
@@ -505,13 +500,11 @@ def narayana_number(n: Integer, k: Integer) -> Integer:
 
     INPUT:
 
-    - ``n`` -- an integer
+    - ``n`` -- integer
 
-    - ``k`` -- an integer between ``0`` and ``n - 1``
+    - ``k`` -- integer between ``0`` and ``n - 1``
 
-    OUTPUT:
-
-    an integer
+    OUTPUT: integer
 
     EXAMPLES::
 
@@ -537,13 +530,13 @@ def euler_number(n, algorithm='flint') -> Integer:
 
     INPUT:
 
-    - ``n`` -- a positive integer
+    - ``n`` -- positive integer
 
-    - ``algorithm`` -- (Default: ``'flint'``) any one of the following:
+    - ``algorithm`` -- (default: ``'flint'``) any one of the following:
 
-      - ``'maxima'`` -- Wraps Maxima's ``euler``.
+      - ``'maxima'`` -- wraps Maxima's ``euler``
 
-      - ``'flint'`` -- Wrap FLINT's ``arith_euler_number``
+      - ``'flint'`` -- wrap FLINT's ``arith_euler_number``
 
     EXAMPLES::
 
@@ -593,11 +586,9 @@ def eulerian_number(n, k, algorithm='recursive') -> Integer:
 
     - ``k`` -- integer between ``0`` and ``n - 1``
 
-    - ``algorithm`` -- ``"recursive"`` (default) or ``"formula"``
+    - ``algorithm`` -- ``'recursive'`` (default) or ``'formula'``
 
-    OUTPUT:
-
-    an integer
+    OUTPUT: integer
 
     .. SEEALSO:: :func:`eulerian_polynomial`
 
@@ -637,13 +628,11 @@ def eulerian_polynomial(n, algorithm='derivative'):
 
     INPUT:
 
-    - ``n`` -- an integer
+    - ``n`` -- integer
 
-    - ``algorithm`` -- ``"derivative"`` (default) or ``"coeffs"``
+    - ``algorithm`` -- ``'derivative'`` (default) or ``'coeffs'``
 
-    OUTPUT:
-
-    polynomial in one variable ``t``
+    OUTPUT: polynomial in one variable ``t``
 
     .. SEEALSO:: :func:`eulerian_number`
 
@@ -679,7 +668,7 @@ def eulerian_polynomial(n, algorithm='derivative'):
         return R([eulerian_number(n, k, "formula") for k in range(n)])
 
 
-def fibonacci(n, algorithm="pari") -> Integer:
+def fibonacci(n, algorithm='pari') -> Integer:
     """
     Return the `n`-th Fibonacci number.
 
@@ -691,12 +680,12 @@ def fibonacci(n, algorithm="pari") -> Integer:
 
     INPUT:
 
-    - ``algorithm`` -- a string:
+    - ``algorithm`` -- string; one of
 
-      * ``"pari"`` -- (default) use the PARI C library's
+      * ``'pari'`` -- (default) use the PARI C library's
         :pari:`fibo` function
 
-      * ``"gap"`` -- use GAP's Fibonacci function
+      * ``'gap'`` -- use GAP's Fibonacci function
 
     .. NOTE::
 
@@ -750,9 +739,9 @@ def lucas_number1(n, P, Q):
 
     INPUT:
 
-    -  ``n`` -- integer
+    - ``n`` -- integer
 
-    -  ``P, Q`` -- integer or rational numbers
+    - ``P``, ``Q`` -- integer or rational numbers
 
     OUTPUT: integer or rational number
 
@@ -817,11 +806,9 @@ def lucas_number2(n, P, Q):
 
     INPUT:
 
+    - ``n`` -- integer
 
-    -  ``n`` -- integer
-
-    -  ``P, Q`` -- integer or rational numbers
-
+    - ``P``, ``Q`` -- integer or rational numbers
 
     OUTPUT: integer or rational number
 
@@ -857,7 +844,7 @@ def lucas_number2(n, P, Q):
     return libgap.Lucas(P, Q, n)[1].sage()
 
 
-def stirling_number1(n, k, algorithm="gap") -> Integer:
+def stirling_number1(n, k, algorithm='gap') -> Integer:
     r"""
     Return the `n`-th Stirling number `S_1(n,k)` of the first kind.
 
@@ -871,8 +858,8 @@ def stirling_number1(n, k, algorithm="gap") -> Integer:
     - ``k`` -- nonnegative machine-size integer
     - ``algorithm``:
 
-      * ``"gap"`` (default) -- use GAP's ``Stirling1`` function
-      * ``"flint"`` -- use flint's ``arith_stirling_number_1u`` function
+      * ``'gap'`` -- default; use GAP's ``Stirling1`` function
+      * ``'flint'`` -- use flint's ``arith_stirling_number_1u`` function
 
     EXAMPLES::
 
@@ -893,7 +880,7 @@ def stirling_number1(n, k, algorithm="gap") -> Integer:
         sage: stirling_number1(10,5, algorithm='flint')                                 # needs sage.libs.flint
         269325
 
-        sage: s_sage = stirling_number1(50,3, algorithm="mutta")
+        sage: s_sage = stirling_number1(50,3, algorithm='mutta')
         Traceback (most recent call last):
         ...
         ValueError: unknown algorithm: mutta
@@ -921,14 +908,14 @@ def stirling_number2(n, k, algorithm=None) -> Integer:
 
     INPUT:
 
-    -  ``n`` -- nonnegative machine-size integer
-    -  ``k`` -- nonnegative machine-size integer
+    - ``n`` -- nonnegative machine-size integer
+    - ``k`` -- nonnegative machine-size integer
     - ``algorithm``:
 
-      * ``None`` (default) -- use native implementation
-      * ``"flint"`` -- use flint's ``arith_stirling_number_2`` function
-      * ``"gap"`` -- use GAP's ``Stirling2`` function
-      * ``"maxima"`` -- use Maxima's ``stirling2`` function
+      * ``None`` -- default; use native implementation
+      * ``'flint'`` -- use flint's ``arith_stirling_number_2`` function
+      * ``'gap'`` -- use GAP's ``Stirling2`` function
+      * ``'maxima'`` -- use Maxima's ``stirling2`` function
 
     EXAMPLES:
 
@@ -1016,10 +1003,10 @@ def stirling_number2(n, k, algorithm=None) -> Integer:
         ....:         if not (s_sage == s_flint and s_sage == s_gap):
         ....:             print("Error with n<200")
 
-        sage: stirling_number2(20, 3, algorithm="maxima")                               # needs sage.symbolic
+        sage: stirling_number2(20, 3, algorithm='maxima')                               # needs sage.symbolic
         580606446
 
-        sage: s_sage = stirling_number2(5, 3, algorithm="namba")
+        sage: s_sage = stirling_number2(5, 3, algorithm='namba')
         Traceback (most recent call last):
         ...
         ValueError: unknown algorithm: namba
@@ -1060,7 +1047,7 @@ def polygonal_number(s, n):
 
     - ``n`` -- integer; the index of the returned `s`-gonal number
 
-    OUTPUT: an integer
+    OUTPUT: integer
 
     EXAMPLES:
 
@@ -1142,12 +1129,12 @@ class CombinatorialObject(SageObject):
 
         INPUT:
 
-        -  ``l`` -- a list or any object that can be converted to a
-           list by calling ``list()``.
+        - ``l`` -- list or any object that can be converted to a
+          list by calling ``list()``
 
-        - ``copy`` -- (boolean, default ``True``) if ``False``, then
+        - ``copy`` -- boolean (default: ``True``); if ``False``, then
           ``l`` must be a ``list``, which is assigned to ``self._list``
-          without copying.
+          without copying
 
         EXAMPLES::
 
@@ -1386,7 +1373,7 @@ class CombinatorialObject(SageObject):
 
     def __bool__(self) -> bool:
         """
-        Return ``True`` if ``self`` is non-zero.
+        Return ``True`` if ``self`` is nonzero.
 
         We consider a list to be zero if it has length zero.
 
@@ -1425,7 +1412,6 @@ class CombinatorialObject(SageObject):
                 sage: b = Bar([4])
                 sage: not b
                 False
-
         """
         return bool(self._list)
 
@@ -1507,10 +1493,10 @@ class CombinatorialElement(CombinatorialObject, Element,
 
     INPUT:
 
-    -  ``parent`` -- the :class:`Parent` class for this element.
+    - ``parent`` -- the :class:`Parent` class for this element
 
-    -  ``lst`` -- a list or any object that can be converted to a
-       list by calling ``list()``.
+    - ``lst`` -- list or any object that can be converted to a
+      list by calling ``list()``
 
     EXAMPLES::
 
@@ -1582,6 +1568,7 @@ class CombinatorialElement(CombinatorialObject, Element,
 #####################################################
 # combinatorial sets/lists
 
+
 def tuples(S, k, algorithm='itertools'):
     r"""
     Return a list of all `k`-tuples of elements of a given set ``S``.
@@ -1660,7 +1647,7 @@ def _tuples_native(S, k):
     Return a list of all `k`-tuples of elements of a given set ``S``.
 
     This is a helper method used in :meth:`tuples`. It returns the
-    same as ``tuples(S, k, algorithm="native")``.
+    same as ``tuples(S, k, algorithm='native')``.
 
     EXAMPLES::
 
@@ -1711,16 +1698,16 @@ def number_of_tuples(S, k, algorithm='naive') -> Integer:
         sage: S = [1,2,3,4,5]
         sage: number_of_tuples(S,2)
         25
-        sage: number_of_tuples(S,2, algorithm="gap")                                    # needs sage.libs.gap
+        sage: number_of_tuples(S,2, algorithm='gap')                                    # needs sage.libs.gap
         25
         sage: S = [1,1,2,3,4,5]
         sage: number_of_tuples(S,2)
         25
-        sage: number_of_tuples(S,2, algorithm="gap")                                    # needs sage.libs.gap
+        sage: number_of_tuples(S,2, algorithm='gap')                                    # needs sage.libs.gap
         25
         sage: number_of_tuples(S,0)
         1
-        sage: number_of_tuples(S,0, algorithm="gap")                                    # needs sage.libs.gap
+        sage: number_of_tuples(S,0, algorithm='gap')                                    # needs sage.libs.gap
         1
     """
     if algorithm == 'naive':
@@ -1827,16 +1814,16 @@ def number_of_unordered_tuples(S, k, algorithm='naive') -> Integer:
         sage: S = [1,2,3,4,5]
         sage: number_of_unordered_tuples(S,2)
         15
-        sage: number_of_unordered_tuples(S,2, algorithm="gap")                          # needs sage.libs.gap
+        sage: number_of_unordered_tuples(S,2, algorithm='gap')                          # needs sage.libs.gap
         15
         sage: S = [1,1,2,3,4,5]
         sage: number_of_unordered_tuples(S,2)
         15
-        sage: number_of_unordered_tuples(S,2, algorithm="gap")                          # needs sage.libs.gap
+        sage: number_of_unordered_tuples(S,2, algorithm='gap')                          # needs sage.libs.gap
         15
         sage: number_of_unordered_tuples(S,0)
         1
-        sage: number_of_unordered_tuples(S,0, algorithm="gap")                          # needs sage.libs.gap
+        sage: number_of_unordered_tuples(S,0, algorithm='gap')                          # needs sage.libs.gap
         1
     """
     if algorithm == 'naive':
@@ -1971,7 +1958,7 @@ def bell_polynomial(n: Integer, k=None, ordinary=False):
 
     - ``k`` -- (optional) if specified, returns the partial Bell
       polynomial, otherwise returns the complete Bell polynomial
-    - ``ordinary`` -- (default: ``False``) if ``True``, returns the
+    - ``ordinary`` -- boolean (default: ``False``); if ``True``, returns the
       (partial) ordinary Bell polynomial, otherwise returns
       the (partial) exponential Bell polynomial
 
@@ -2107,13 +2094,12 @@ def fibonacci_sequence(start, stop=None, algorithm=None) -> Iterator:
 
     INPUT:
 
-    -  ``start`` -- starting value
+    - ``start`` -- starting value
 
-    -  ``stop`` -- stopping value
+    - ``stop`` -- stopping value
 
-    -  ``algorithm`` -- (default: ``None``) passed on to
-       fibonacci function (or not passed on if None, i.e., use the
-       default)
+    - ``algorithm`` -- (default: ``None``) passed on to fibonacci function (or
+      not passed on if ``None``, i.e., use the default)
 
     EXAMPLES::
 
@@ -2268,7 +2254,7 @@ def bernoulli_polynomial(x, n: Integer):
         if n < 0:
             raise TypeError
     except TypeError:
-        raise ValueError("the second argument must be a non-negative integer")
+        raise ValueError("the second argument must be a nonnegative integer")
 
     if n == 0:
         return x**0   # result should be in the parent of x
