@@ -1,3 +1,4 @@
+# sage.doctest: needs sage.combinat sage.modules
 r"""
 Affine factorization crystal of type `A`
 """
@@ -9,6 +10,7 @@ Affine factorization crystal of type `A`
 #******************************************************************************
 
 from sage.misc.lazy_attribute import lazy_attribute
+from sage.misc.lazy_import import lazy_import
 from sage.structure.parent import Parent
 from sage.structure.element_wrapper import ElementWrapper
 from sage.structure.unique_representation import UniqueRepresentation
@@ -17,9 +19,10 @@ from sage.categories.crystals import CrystalMorphism
 from sage.categories.enumerated_sets import EnumeratedSets
 from sage.categories.homset import Hom
 from sage.combinat.root_system.cartan_type import CartanType
-from sage.combinat.root_system.weyl_group import WeylGroup
 from sage.combinat.rsk import RSK
 
+lazy_import('sage.combinat.root_system.weyl_group', 'WeylGroup')
+
 
 class AffineFactorizationCrystal(UniqueRepresentation, Parent):
     r"""
@@ -250,12 +253,12 @@ class AffineFactorizationCrystal(UniqueRepresentation, Parent):
             k = self.parent().k
             n = self.parent().n
             a = min(b[0])
-            left = [j for j in (self.value[n-i-1]).reduced_word() if j != (a+x)%(k+1)]
-            right = [(j-x)%(k+1) for j in (self.value[n-i]).reduced_word()]
-            m = max([j for j in range(a) if (j+x)%(k+1) not in left])
+            left = [j for j in (self.value[n-i-1]).reduced_word() if j != (a+x) % (k+1)]
+            right = [(j-x) % (k+1) for j in (self.value[n-i]).reduced_word()]
+            m = max([j for j in range(a) if (j+x) % (k+1) not in left])
             right += [m+1]
             right.sort(reverse=True)
-            right = [(j+x)%(k+1) for j in right]
+            right = [(j+x) % (k+1) for j in right]
             t = [self.value[j] for j in range(n-i-1)] + [W.from_reduced_word(left)] + [W.from_reduced_word(right)] + [self.value[j] for j in range(n-i+1,n)]
             return self.parent()(tuple(t))
 
@@ -284,12 +287,12 @@ class AffineFactorizationCrystal(UniqueRepresentation, Parent):
             k = self.parent().k
             n = self.parent().n
             a = max(b[1])
-            right = [j for j in (self.value[n-i]).reduced_word() if j != (a+x)%(k+1)]
-            left = [(j-x)%(k+1) for j in (self.value[n-i-1]).reduced_word()]
-            m = min([j for j in range(a+1,k+2) if (j+x)%(k+1) not in right])
+            right = [j for j in (self.value[n-i]).reduced_word() if j != (a+x) % (k+1)]
+            left = [(j-x) % (k+1) for j in (self.value[n-i-1]).reduced_word()]
+            m = min([j for j in range(a+1,k+2) if (j+x) % (k+1) not in right])
             left += [m-1]
             left.sort(reverse=True)
-            left = [(j+x)%(k+1) for j in left]
+            left = [(j+x) % (k+1) for j in left]
             t = [self.value[j] for j in range(n-i-1)] + [W.from_reduced_word(left)] + [W.from_reduced_word(right)] + [self.value[j] for j in range(n-i+1,n)]
             return self.parent()(tuple(t))
 
@@ -311,18 +314,18 @@ class AffineFactorizationCrystal(UniqueRepresentation, Parent):
             k = self.parent().k
             right = (self.value[n-i]).reduced_word()
             left = (self.value[n-i-1]).reduced_word()
-            right_n = [(j-x)%(k+1) for j in right]
-            left_n = [(j-x)%(k+1) for j in left]
+            right_n = [(j-x) % (k+1) for j in right]
+            left_n = [(j-x) % (k+1) for j in left]
             left_unbracketed = []
             while left_n:
                 m = max(left_n)
                 left_n.remove(m)
-                l = [j for j in right_n if j>m]
+                l = [j for j in right_n if j > m]
                 if l:
                     right_n.remove(min(l))
                 else:
                     left_unbracketed += [m]
-            return [[j for j in left_unbracketed],[j for j in right_n]]
+            return [list(left_unbracketed), list(right_n)]
 
         def to_tableau(self):
             """
@@ -363,7 +366,7 @@ class AffineFactorizationCrystal(UniqueRepresentation, Parent):
 
 def affine_factorizations(w, l, weight=None):
     r"""
-    Return all factorizations of ``w`` into ``l`` factors or of weight ``weight``.
+    Return all factorizations of `w` into `l` factors or of weight ``weight``.
 
     INPUT:
 
@@ -371,7 +374,8 @@ def affine_factorizations(w, l, weight=None):
 
     - ``l`` -- nonnegative integer
 
-    - ``weight`` -- (default: None) tuple of nonnegative integers specifying the length of the factors
+    - ``weight`` -- (default: ``None``) tuple of nonnegative integers
+      specifying the length of the factors
 
     EXAMPLES::
 
@@ -428,7 +432,7 @@ def affine_factorizations(w, l, weight=None):
        [[1, 1, 1, s1, s2*s1, s3*s2*s1]]
     """
     if weight is None:
-        if l==0:
+        if l == 0:
             if w.is_one():
                 return [[]]
             else:
@@ -438,7 +442,7 @@ def affine_factorizations(w, l, weight=None):
     else:
         if l != len(weight):
             return []
-        if l==0:
+        if l == 0:
             if w.is_one():
                 return [[]]
             else:
@@ -472,16 +476,16 @@ class FactorizationToTableaux(CrystalMorphism):
         """
         p = []
         q = []
-        for i,factor in enumerate(reversed(x.value)):
+        for i, factor in enumerate(reversed(x.value)):
             word = factor.reduced_word()
-            p += [i+1]*len(word)
+            p += [i + 1] * len(word)
             # We sort for those pesky commutative elements
             # The word is most likely in reverse order to begin with
             q += sorted(reversed(word))
         C = self.codomain()
         return C(RSK(p, q, insertion=RSK.rules.EG)[1])
 
-    def is_isomorphism(self):
+    def is_isomorphism(self) -> bool:
         """
         Return ``True`` as this is an isomorphism.
 
