@@ -21,7 +21,7 @@ design from this database, we include extra information:
 REFERENCES:
 
 .. [1] La Jolla Covering Repository,
-  https://ljcr.dmgordon.org/cover.html
+  https://dmgordon.org/cover
 
 .. [2] Daniel M. Gordon and Douglas R. Stinson, *Coverings*,
   Chapter 1 in: Charles J. Colbourn and Jeffrey H. Dinitz,
@@ -63,11 +63,11 @@ def schonheim(v, k, t):
 
     INPUT:
 
-    - ``v`` -- integer, size of point set
+    - ``v`` -- integer; size of point set
 
-    - ``k`` -- integer, cardinality of each block
+    - ``k`` -- integer; cardinality of each block
 
-    - ``t`` -- integer, cardinality of sets being covered
+    - ``t`` -- integer; cardinality of sets being covered
 
     OUTPUT:
 
@@ -95,11 +95,11 @@ def trivial_covering_design(v, k, t):
 
     INPUT:
 
-    - ``v`` -- integer, size of point set
+    - ``v`` -- integer; size of point set
 
-    - ``k`` -- integer, cardinality of each block
+    - ``k`` -- integer; cardinality of each block
 
-    - ``t`` -- integer, cardinality of sets being covered
+    - ``t`` -- integer; cardinality of sets being covered
 
     OUTPUT:
 
@@ -141,7 +141,6 @@ def trivial_covering_design(v, k, t):
           `k` does not divide `v`.
 
         * anything else: Just use every `k`-subset of `[0, 1,..., v-1]`.
-
     """
     if t == 0:  # single block [0, ..., k-1]
         blk = list(range(k))
@@ -171,13 +170,13 @@ class CoveringDesign(SageObject):
 
     - ``v``, ``k``, ``t`` -- integer parameters of the covering design
 
-    - ``size`` (integer)
+    - ``size`` -- integer
 
-    - ``points`` -- list of points (default points are `[0, ..., v-1]`)
+    - ``points`` -- list of points (default: `[0, ..., v-1]`)
 
     - ``blocks``
 
-    - ``low_bd`` (integer) -- lower bound for such a design
+    - ``low_bd`` -- integer; lower bound for such a design
 
     - ``method``, ``creator``, ``timestamp`` -- database information
     """
@@ -335,7 +334,7 @@ class CoveringDesign(SageObject):
 
     def k(self):
         """
-        Return `k`, the size of blocks of the covering design
+        Return `k`, the size of blocks of the covering design.
 
         EXAMPLES::
 
@@ -366,7 +365,7 @@ class CoveringDesign(SageObject):
 
     def size(self):
         """
-        Return the number of blocks in the covering design
+        Return the number of blocks in the covering design.
 
         EXAMPLES::
 
@@ -418,7 +417,7 @@ class CoveringDesign(SageObject):
 
     def creator(self):
         """
-        Return the creator of the covering design
+        Return the creator of the covering design.
 
         This field is optional, and is used in a database to give
         attribution for the covering design It can refer to the person
@@ -437,7 +436,7 @@ class CoveringDesign(SageObject):
 
     def timestamp(self):
         """
-        Return the time that the covering was submitted to the database
+        Return the time that the covering was submitted to the database.
 
         EXAMPLES::
 
@@ -467,7 +466,6 @@ class CoveringDesign(SageObject):
             sage: D.blocks()
             [[0, 1, 2], [0, 3, 4], [0, 5, 6], [1, 3, 5],
             [1, 4, 6], [2, 3, 6], [2, 4, 5]]
-
         """
         return self.__incidence_structure
 
@@ -481,13 +479,13 @@ def best_known_covering_design_www(v, k, t, verbose=False):
 
     INPUT:
 
-    - ``v`` -- integer, the size of the point set for the design
+    - ``v`` -- integer; the size of the point set for the design
 
-    - ``k`` -- integer, the number of points per block
+    - ``k`` -- integer; the number of points per block
 
-    - ``t`` -- integer, the size of sets covered by the blocks
+    - ``t`` -- integer; the size of sets covered by the blocks
 
-    - ``verbose`` -- bool (default: ``False``), print verbose message
+    - ``verbose`` -- boolean (default: ``False``); print verbose message
 
     OUTPUT:
 
@@ -511,14 +509,14 @@ def best_known_covering_design_www(v, k, t, verbose=False):
         2  3  6
         2  4  5
 
-    A :class:`ValueError` is raised if the ``(v, k, t)`` parameters are not
+    A :exc:`ValueError` is raised if the ``(v, k, t)`` parameters are not
     found in the database.
     """
     v = int(v)
     k = int(k)
     t = int(t)
     param = "?v=%s&k=%s&t=%s" % (v, k, t)
-    url = "https://ljcr.dmgordon.org/cover/get_cover.php" + param
+    url = "https://ljcr.dmgordon.org/get_cover.php" + param
     if verbose:
         print("Looking up the bounds at %s" % url)
 
