@@ -1,4 +1,4 @@
-# sage.doctest: needs sage.rings.finite_rings
+# sage.doctest: needs sage.rings.finite_rings sage.schemes
 r"""
 Orthogonal arrays (OA)
 
@@ -35,6 +35,7 @@ This module defines the following functions:
     :meth:`TD_product` | Return the product of two transversal designs.
     :meth:`OA_find_disjoint_blocks` | Return `x` disjoint blocks contained in a given `OA(k,n)`.
     :meth:`OA_relabel` | Return a relabelled version of the OA.
+    :meth:`OA_standard_label` | Return a version of the OA relabelled to symbols `(0,\dots,n-1)`.
     :meth:`OA_from_quasi_difference_matrix` | Return an Orthogonal Array from a Quasi-Difference matrix
     :meth:`OA_from_Vmt` | Return an Orthogonal Array from a `V(m,t)`
     :meth:`OA_from_PBD` | Return an `OA(k,n)` from a PBD
@@ -43,14 +44,12 @@ This module defines the following functions:
     :meth:`QDM_from_Vmt` | Return a QDM a `V(m,t)`
 
 
-
 REFERENCES:
 
 -- [CD1996]_
 
 Functions
 ---------
-
 """
 
 from sage.categories.sets_cat import EmptySetError
@@ -82,37 +81,34 @@ def transversal_design(k, n, resolvable=False, check=True, existence=False):
 
     INPUT:
 
-    - `n,k` -- integers. If ``k is None`` it is set to the largest value
-      available.
+    - ``n``, ``k`` -- integers; if ``k is None`` it is set to the largest value
+      available
 
-    - ``resolvable`` (boolean) -- set to ``True`` if you want the design to be
+    - ``resolvable`` -- boolean; set to ``True`` if you want the design to be
       resolvable (see
       :meth:`sage.combinat.designs.incidence_structures.IncidenceStructure.is_resolvable`). The
       `n` classes of the resolvable design are obtained as the first `n` blocks,
       then the next `n` blocks, etc ... Set to ``False`` by default.
 
-    - ``check`` -- (boolean) Whether to check that output is correct before
-      returning it. As this is expected to be useless (but we are cautious
-      guys), you may want to disable it whenever you want speed. Set to
-      ``True`` by default.
+    - ``check`` -- boolean (default: ``True``); whether to check that output is
+      correct before returning it. As this is expected to be useless, you may
+      want to disable it whenever you want speed.
 
-    - ``existence`` (boolean) -- instead of building the design, return:
+    - ``existence`` -- boolean; instead of building the design, return:
 
         - ``True`` -- meaning that Sage knows how to build the design
 
         - ``Unknown`` -- meaning that Sage does not know how to build the
-          design, but that the design may exist (see :mod:`sage.misc.unknown`).
+          design, but that the design may exist (see :mod:`sage.misc.unknown`)
 
-        - ``False`` -- meaning that the design does not exist.
+        - ``False`` -- meaning that the design does not exist
 
       .. NOTE::
 
           When ``k=None`` and ``existence=True`` the function returns an
           integer, i.e. the largest `k` such that we can build a `TD(k,n)`.
 
-    OUTPUT:
-
-    The kind of output depends on the input:
+    OUTPUT: the kind of output depends on the input:
 
     - if ``existence=False`` (the default) then the output is a list of lists
       that represent a `TD(k,n)` with
@@ -189,7 +185,7 @@ def transversal_design(k, n, resolvable=False, check=True, existence=False):
         Unknown
 
     If you ask for a transversal design that Sage is not able to build then an
-    ``EmptySetError`` or a ``NotImplementedError`` is raised::
+    :exc:`EmptySetError` or a :exc:`NotImplementedError` is raised::
 
         sage: designs.transversal_design(47, 100)
         Traceback (most recent call last):
@@ -241,7 +237,7 @@ def transversal_design(k, n, resolvable=False, check=True, existence=False):
     For small values of the parameter ``n`` we check the coherence of the
     function :func:`transversal_design`::
 
-        sage: for n in range(2,25):                               # long time -- 15 secs
+        sage: for n in range(2,25):                               # long time (15s)
         ....:     i = 2
         ....:     while designs.transversal_design(i, n, existence=True) is True:
         ....:         i += 1
@@ -374,18 +370,18 @@ def transversal_design(k, n, resolvable=False, check=True, existence=False):
 
 class TransversalDesign(GroupDivisibleDesign):
     r"""
-    Class for Transversal Designs
+    Class for Transversal Designs.
 
     INPUT:
 
     - ``blocks`` -- collection of blocks
 
-    - ``k,n`` (integers) -- parameters of the transversal design. They can be
-      set to ``None`` (default) in which case their value is determined by the
-      blocks.
+    - ``k``, ``n`` -- integers; parameters of the transversal design. They can
+      be set to ``None`` (default) in which case their value is determined by
+      the blocks.
 
-    - ``check`` (boolean) -- whether to check that the design is indeed a
-      transversal design with the right parameters. Set to ``True`` by default.
+    - ``check`` -- boolean (default: ``True``); whether to check that the
+      design is indeed a transversal design with the right parameters
 
     EXAMPLES::
 
@@ -396,9 +392,9 @@ class TransversalDesign(GroupDivisibleDesign):
         sage: designs.transversal_design(None,36)
         Transversal Design TD(10,36)
     """
-    def __init__(self, blocks, k=None,n=None,check=True,**kwds):
+    def __init__(self, blocks, k=None, n=None, check=True, **kwds):
         r"""
-        Constructor of the class
+        Constructor of the class.
 
         EXAMPLES::
 
@@ -408,9 +404,9 @@ class TransversalDesign(GroupDivisibleDesign):
         from math import sqrt
         if k is None:
             if blocks:
-                k=len(blocks[0])
+                k = len(blocks[0])
             else:
-                k=0
+                k = 0
         if n is None:
             n = round(sqrt(len(blocks)))
 
@@ -429,7 +425,7 @@ class TransversalDesign(GroupDivisibleDesign):
 
     def __repr__(self):
         r"""
-        Returns a string describing the transversal design.
+        Return a string describing the transversal design.
 
         EXAMPLES::
 
@@ -454,10 +450,10 @@ def is_transversal_design(B, k, n, verbose=False):
 
     - ``B`` -- the list of blocks
 
-    - ``k, n`` -- integers
+    - ``k``, ``n`` -- integers
 
-    - ``verbose`` (boolean) -- whether to display information about what is
-      going wrong.
+    - ``verbose`` -- boolean; whether to display information about what is
+      going wrong
 
     .. NOTE::
 
@@ -474,11 +470,12 @@ def is_transversal_design(B, k, n, verbose=False):
         sage: is_transversal_design(TD, 4, 4)
         False
     """
-    return is_orthogonal_array([[x%n for x in R] for R in B],k,n,verbose=verbose)
+    return is_orthogonal_array([[x % n for x in R] for R in B],k,n,verbose=verbose)
 
-def wilson_construction(OA,k,r,m,u,check=True,explain_construction=False):
+
+def wilson_construction(OA, k, r, m, u, check=True, explain_construction=False):
     r"""
-    Returns a `OA(k,rm+\sum_i u_i)` from a truncated `OA(k+s,r)` by Wilson's
+    Return a `OA(k,rm+\sum_i u_i)` from a truncated `OA(k+s,r)` by Wilson's
     construction.
 
     **Simple form:**
@@ -516,9 +513,9 @@ def wilson_construction(OA,k,r,m,u,check=True,explain_construction=False):
       of a block are represented by ``None`` values. If ``OA=None``, it is
       defined as a truncated orthogonal arrays with `k+s` columns.
 
-    - ``k,r,m`` (integers)
+    - ``k``, ``r``, ``m`` -- integers
 
-    - ``u`` (list) -- two cases depending on the form to use:
+    - ``u`` -- list; two cases depending on the form to use:
 
         - Simple form: a list of length `s` such that column ``k+i`` has size
           ``u[i]``. The untruncated points of column ``k+i`` are assumed to be
@@ -531,13 +528,12 @@ def wilson_construction(OA,k,r,m,u,check=True,explain_construction=False):
           represent `H_{i0}`, the next `|H_{i1}|` points represent `H_{i1}`,
           etc...
 
-    - ``explain_construction`` (boolean) -- return a string describing
-      the construction.
+    - ``explain_construction`` -- boolean; return a string describing
+      the construction
 
-    - ``check`` (boolean) -- whether to check that output is correct before
-      returning it. As this is expected to be useless (but we are cautious
-      guys), you may want to disable it whenever you want speed. Set to ``True``
-      by default.
+    - ``check`` -- boolean (default: ``True``); whether to check that output is
+      correct before returning it. As this is expected to be useless, you may
+      want to disable it whenever you want speed.
 
     REFERENCE:
 
@@ -614,7 +610,7 @@ def wilson_construction(OA,k,r,m,u,check=True,explain_construction=False):
         master_design = OA
 
     for c in u:
-        assert all(m_ij>=0 and h_size>=0 for m_ij,h_size in c)
+        assert all(m_ij >= 0 and h_size >= 0 for m_ij,h_size in c)
         assert sum(h_size for m_ij,h_size in c) <= r
 
     # Associates a point ij from a truncated column k+i to
@@ -623,7 +619,7 @@ def wilson_construction(OA,k,r,m,u,check=True,explain_construction=False):
     # - its corresponding set of points in the final design.
     point_to_mij = []
     point_to_point_set = []
-    n=r*m
+    n = r*m
     for i,partition in enumerate(u):
         column_i_point_to_mij = []
         column_i_point_to_point_set = []
@@ -631,7 +627,7 @@ def wilson_construction(OA,k,r,m,u,check=True,explain_construction=False):
             for _ in range(h_size):
                 column_i_point_to_mij.append(mij)
                 column_i_point_to_point_set.append(list(range(n,n+mij)))
-                n+=mij
+                n += mij
         point_to_mij.append(column_i_point_to_mij)
         point_to_point_set.append(column_i_point_to_point_set)
 
@@ -681,7 +677,8 @@ def wilson_construction(OA,k,r,m,u,check=True,explain_construction=False):
 
     return OA
 
-def TD_product(k,TD1,n1,TD2,n2, check=True):
+
+def TD_product(k, TD1, n1, TD2, n2, check=True):
     r"""
     Return the product of two transversal designs.
 
@@ -697,14 +694,13 @@ def TD_product(k,TD1,n1,TD2,n2, check=True):
 
     INPUT:
 
-    - ``TD1, TD2`` -- transversal designs.
+    - ``TD1``, ``TD2`` -- transversal designs
 
-    - ``k,n1,n2`` (integers) -- see above.
+    - ``k``, ``n1``, ``n2`` -- integers
 
-    - ``check`` (boolean) -- Whether to check that output is correct before
-      returning it. As this is expected to be useless (but we are cautious
-      guys), you may want to disable it whenever you want speed. Set to ``True``
-      by default.
+    - ``check`` -- boolean (default: ``True``); whether to check that output is
+      correct before returning it. As this is expected to be useless, you may
+      want to disable it whenever you want speed.
 
     .. NOTE::
 
@@ -729,7 +725,8 @@ def TD_product(k,TD1,n1,TD2,n2, check=True):
 
     return TD
 
-def orthogonal_array(k,n,t=2,resolvable=False, check=True,existence=False,explain_construction=False):
+
+def orthogonal_array(k, n, t=2, resolvable=False, check=True, existence=False, explain_construction=False):
     r"""
     Return an orthogonal array of parameters `k,n,t`.
 
@@ -750,43 +747,40 @@ def orthogonal_array(k,n,t=2,resolvable=False, check=True,existence=False,explai
 
     INPUT:
 
-    - ``k`` -- (integer) number of columns. If ``k=None`` it is set to the
+    - ``k`` -- integer; number of columns. If ``k`` is ``None`` it is set to the
       largest value available.
 
-    - ``n`` -- (integer) number of symbols
+    - ``n`` -- integer; number of symbols
 
-    - ``t`` -- (integer; default: 2) -- strength of the array
+    - ``t`` -- integer (default: 2); strength of the array
 
-    - ``resolvable`` (boolean) -- set to ``True`` if you want the design to be
-      resolvable. The `n` classes of the resolvable design are obtained as the
-      first `n` blocks, then the next `n` blocks, etc ... Set to ``False`` by
-      default.
+    - ``resolvable`` -- boolean (default: ``False``); set to ``True`` if you
+      want the design to be resolvable. The `n` classes of the resolvable
+      design are obtained as the first `n` blocks, then the next `n` blocks,
+      etc.
 
-    - ``check`` -- (boolean) Whether to check that output is correct before
-      returning it. As this is expected to be useless (but we are cautious
-      guys), you may want to disable it whenever you want speed. Set to
-      ``True`` by default.
+    - ``check`` -- boolean (default: ``True``); whether to check that output is
+      correct before returning it. As this is expected to be useless, you may
+      want to disable it whenever you want speed.
 
-    - ``existence`` (boolean) -- instead of building the design, return:
+    - ``existence`` -- boolean; instead of building the design, return:
 
         - ``True`` -- meaning that Sage knows how to build the design
 
         - ``Unknown`` -- meaning that Sage does not know how to build the
-          design, but that the design may exist (see :mod:`sage.misc.unknown`).
+          design, but that the design may exist (see :mod:`sage.misc.unknown`)
 
-        - ``False`` -- meaning that the design does not exist.
+        - ``False`` -- meaning that the design does not exist
 
       .. NOTE::
 
           When ``k=None`` and ``existence=True`` the function returns an
           integer, i.e. the largest `k` such that we can build a `OA(k,n)`.
 
-    - ``explain_construction`` (boolean) -- return a string describing
-      the construction.
+    - ``explain_construction`` -- boolean; return a string describing
+      the construction
 
-    OUTPUT:
-
-    The kind of output depends on the input:
+    OUTPUT: the kind of output depends on the input:
 
     - if ``existence=False`` (the default) then the output is a list of lists
       that represent an orthogonal array with parameters ``k`` and ``n``
@@ -833,11 +827,11 @@ def orthogonal_array(k,n,t=2,resolvable=False, check=True,existence=False,explai
         True
         sage: _ = designs.orthogonal_arrays.build(t,5,t)
     """
-    assert n>=0, "n(={}) must be nonnegative".format(n)
+    assert n >= 0, "n(={}) must be nonnegative".format(n)
 
     # A resolvable OA(k,n) is an OA(k+1,n)
     if resolvable:
-        assert t==2, "resolvable designs are only handled when t=2"
+        assert t == 2, "resolvable designs are only handled when t=2"
         if existence and k is not None:
             return orthogonal_array(k+1,n,existence=True)
         if k is None:
@@ -910,7 +904,7 @@ def orthogonal_array(k,n,t=2,resolvable=False, check=True,existence=False,explai
             return True
         if explain_construction:
             return "Cyclic latin square"
-        return [[i,j,(i+j)%n] for i in range(n) for j in range(n)]
+        return [[i,j,(i+j) % n] for i in range(n) for j in range(n)]
 
     # projective spaces are equivalent to OA(n+1,n,2)
     elif (projective_plane(n, existence=True) is True or
@@ -961,13 +955,13 @@ def orthogonal_array(k,n,t=2,resolvable=False, check=True,existence=False,explai
 
     # Constructions from the database III (Quasi-difference matrices)
     elif (may_be_available and
-          (n,1) in QDM     and
-          any(kk>=k and mu<=lmbda and (orthogonal_array(k,u,existence=True) is True) for (_,lmbda,mu,u),(kk,_) in QDM[n,1].items())):
+          (n, 1) in QDM and
+          any(kk >= k and mu <= lmbda and (orthogonal_array(k,u,existence=True) is True) for (_,lmbda,mu,u),(kk,_) in QDM[n,1].items())):
         _OA_cache_set(k,n,True)
 
-        for (nn,lmbda,mu,u),(kk,f) in QDM[n,1].items():
-            if (kk>=k     and
-                mu<=lmbda and
+        for (nn, lmbda, mu, u), (kk, f) in QDM[n,1].items():
+            if (kk >= k and
+                mu <= lmbda and
                 (orthogonal_array(k,u,existence=True) is True)):
                 if existence:
                     return True
@@ -1010,15 +1004,16 @@ def orthogonal_array(k,n,t=2,resolvable=False, check=True,existence=False,explai
 
     return OA
 
-def largest_available_k(n,t=2):
+
+def largest_available_k(n, t=2):
     r"""
     Return the largest `k` such that Sage can build an `OA(k,n)`.
 
     INPUT:
 
-    - ``n`` (integer)
+    - ``n`` -- integer
 
-    - ``t`` -- (integer; default: 2) -- strength of the array
+    - ``t`` -- integer (default: 2); strength of the array
 
     EXAMPLES::
 
@@ -1038,9 +1033,9 @@ def largest_available_k(n,t=2):
         ValueError: n(=-1) was expected to be >=0
     """
     from .block_design import projective_plane
-    if n<0:
+    if n < 0:
         raise ValueError("n(={}) was expected to be >=0".format(n))
-    if t<0:
+    if t < 0:
         raise ValueError("t(={}) was expected to be >=0".format(t))
     if n == 0 or n == 1:
         from sage.rings.infinity import Infinity
@@ -1049,17 +1044,18 @@ def largest_available_k(n,t=2):
         if projective_plane(n,existence=True) is True:
             return n+1
         else:
-            k=1
+            k = 1
             while _OA_cache_construction_available(k+1,n) is True:
-                k=k+1
+                k = k+1
     else:
-        k=t-1
+        k = t-1
 
     while orthogonal_array(k+1,n,t,existence=True) is True:
         k += 1
     return k
 
-def incomplete_orthogonal_array(k,n,holes,resolvable=False, existence=False):
+
+def incomplete_orthogonal_array(k, n, holes, resolvable=False, existence=False):
     r"""
     Return an `OA(k,n)-\sum_{1\leq i\leq x} OA(k,s_i)`.
 
@@ -1076,22 +1072,22 @@ def incomplete_orthogonal_array(k,n,holes,resolvable=False, existence=False):
 
     INPUT:
 
-    - ``k,n`` (integers)
+    - ``k``, ``n`` -- integers
 
-    - ``holes`` (list of integers) -- respective sizes of the holes to be found.
+    - ``holes`` -- list of integers respective sizes of the holes to be found
 
-    - ``resolvable`` (boolean) -- set to ``True`` if you want the design to be
-      resolvable. The classes of the resolvable design are obtained as the first
-      `n` blocks, then the next `n` blocks, etc ... Set to ``False`` by default.
+    - ``resolvable`` -- boolean (default: ``False``); set to ``True`` if you
+      want the design to be resolvable. The classes of the resolvable design
+      are obtained as the first `n` blocks, then the next `n` blocks, etc.
 
-    - ``existence`` (boolean) -- instead of building the design, return:
+    - ``existence`` -- boolean; instead of building the design, return:
 
         - ``True`` -- meaning that Sage knows how to build the design
 
         - ``Unknown`` -- meaning that Sage does not know how to build the
-          design, but that the design may exist (see :mod:`sage.misc.unknown`).
+          design, but that the design may exist (see :mod:`sage.misc.unknown`)
 
-        - ``False`` -- meaning that the design does not exist.
+        - ``False`` -- meaning that the design does not exist
 
     .. NOTE::
 
@@ -1221,10 +1217,10 @@ def incomplete_orthogonal_array(k,n,holes,resolvable=False, existence=False):
     """
     from sage.combinat.designs.database import QDM
     for h in holes:
-        if h<0:
+        if h < 0:
             raise ValueError("Holes must have size >=0, but {} was in the list").format(h)
 
-    holes = [h for h in holes if h>0]
+    holes = [h for h in holes if h > 0]
 
     if not holes:
         return orthogonal_array(k,n,existence=existence,resolvable=resolvable)
@@ -1240,14 +1236,14 @@ def incomplete_orthogonal_array(k,n,holes,resolvable=False, existence=False):
         raise EmptySetError("The total size of holes must be smaller or equal than the size of the ground set")
 
     if (max_hole == 1 and
-        resolvable    and
+        resolvable and
         sum_of_holes != n):
         if existence:
             return False
-        raise EmptySetError("There is no resolvable incomplete OA({},{}) whose holes' sizes sum to {}<n(={})".format(k,n,sum_of_holes,n))
+        raise EmptySetError("There is no resolvable incomplete OA({},{}) whose holes' sizes sum to {}<n(={})".format(k, n, sum_of_holes, n))
 
     # resolvable OA(k,n)-n.OA(k,1) ==> equivalent to OA(k+1,n)
-    if max_hole==1 and resolvable:
+    if max_hole == 1 and resolvable:
         if existence:
             return orthogonal_array(k+1,n,existence=True)
 
@@ -1267,7 +1263,7 @@ def incomplete_orthogonal_array(k,n,holes,resolvable=False, existence=False):
         return OA[:-n]
 
     # Easy case
-    elif max_hole==1 and number_of_holes <= 1:
+    elif max_hole == 1 and number_of_holes <= 1:
         if existence:
             return orthogonal_array(k,n,existence=True)
         OA = orthogonal_array(k,n)
@@ -1299,7 +1295,7 @@ def incomplete_orthogonal_array(k,n,holes,resolvable=False, existence=False):
         # place the first hole of size 1
         i = holes.index(1)
         for h1 in IOA:
-            if all(x<n-max_hole for x in h1):
+            if all(x < n-max_hole for x in h1):
                 break
         holes[i] = [h1]
         IOA.remove(h1)
@@ -1308,7 +1304,7 @@ def incomplete_orthogonal_array(k,n,holes,resolvable=False, existence=False):
         if number_of_holes == 3:
             i = holes.index(1)
             for h2 in IOA:
-                if all(h1[j] != x and x<n-max_hole for j,x in enumerate(h2)):
+                if all(h1[j] != x and x < n-max_hole for j,x in enumerate(h2)):
                     break
             holes[i] = [h2]
             IOA.remove(h2)
@@ -1327,21 +1323,21 @@ def incomplete_orthogonal_array(k,n,holes,resolvable=False, existence=False):
         IOA = OA_relabel(IOA,k,n,matrix=holes)
         return IOA
 
-    elif max_hole==1 and number_of_holes >= 2 and k == n+1:
+    elif max_hole == 1 and number_of_holes >= 2 and k == n+1:
         if existence:
             return False
         raise EmptySetError(("There is no OA(n+1,n) - {}.OA(n+1,1) as all blocks "
                              "intersect in a projective plane.").format(number_of_holes))
 
     # Holes of size 1 from OA(k+1,n)
-    elif max_hole==1 and orthogonal_array(k+1,n,existence=True) is True:
+    elif max_hole == 1 and orthogonal_array(k+1,n,existence=True) is True:
         if existence:
             return True
         OA = orthogonal_array(k+1,n)
         independent_set = [B[:-1] for B in OA if B[-1] == 0][:number_of_holes]
         OA = [B[:-1] for B in OA]
 
-    elif max_hole==1 and orthogonal_array(k,n,existence=True) is True:
+    elif max_hole == 1 and orthogonal_array(k,n,existence=True) is True:
         OA = orthogonal_array(k,n)
         try:
             independent_set = OA_find_disjoint_blocks(OA,k,n,number_of_holes)
@@ -1353,7 +1349,7 @@ def incomplete_orthogonal_array(k,n,holes,resolvable=False, existence=False):
             return True
         independent_set = OA_find_disjoint_blocks(OA,k,n,number_of_holes)
 
-    elif max_hole==1 and not orthogonal_array(k,n,existence=True) is True:
+    elif max_hole == 1 and orthogonal_array(k,n,existence=True) is not True:
         return orthogonal_array(k,n,existence=existence)
 
     # From a quasi-difference matrix
@@ -1370,11 +1366,11 @@ def incomplete_orthogonal_array(k,n,holes,resolvable=False, existence=False):
     # Equal holes [h,h,...] with h>1 through OA product construction
     #
     # (i.e. OA(k,n1)-x.OA(k,1) and OA(k,n2) ==> OA(k,n1.n2)-x.OA(k,n2) )
-    elif (min_hole > 1                                and
-          max_hole == min_hole                        and
-          n%min_hole == 0                             and # h divides n
-          orthogonal_array(k,min_hole,existence=True) and # OA(k,h)
-          incomplete_orthogonal_array(k,n//min_hole,[1]*number_of_holes,existence=True)): # OA(k,n/h)-x.OA(k,1)
+    elif (min_hole > 1 and
+          max_hole == min_hole and
+          n % min_hole == 0 and  # h divides n
+          orthogonal_array(k,min_hole,existence=True) and  # OA(k,h)
+          incomplete_orthogonal_array(k,n//min_hole,[1]*number_of_holes,existence=True)):  # OA(k,n/h)-x.OA(k,1)
         if existence:
             return True
         h = min_hole
@@ -1401,6 +1397,7 @@ def incomplete_orthogonal_array(k,n,holes,resolvable=False, existence=False):
 
     return OA
 
+
 def OA_find_disjoint_blocks(OA, k, n, x,
                             *, solver=None, integrality_tolerance=1e-3):
     r"""
@@ -1414,9 +1411,9 @@ def OA_find_disjoint_blocks(OA, k, n, x,
 
     - ``OA`` -- an orthogonal array
 
-    - ``k``, ``n``, ``x`` (integers)
+    - ``k``, ``n``, ``x`` -- integers
 
-    - ``solver`` -- (default: ``None``) Specify a Mixed Integer Linear
+    - ``solver`` -- (default: ``None``) specify a Mixed Integer Linear
       Programming (MILP) solver to be used. If set to ``None``, the default one
       is used. For more information on MILP solvers and which default solver is
       used, see the method :meth:`solve
@@ -1425,7 +1422,7 @@ def OA_find_disjoint_blocks(OA, k, n, x,
       <sage.numerical.mip.MixedIntegerLinearProgram>`.
 
     - ``integrality_tolerance`` -- parameter for use with MILP solvers over an
-      inexact base ring; see :meth:`MixedIntegerLinearProgram.get_values`.
+      inexact base ring; see :meth:`MixedIntegerLinearProgram.get_values`
 
     .. SEEALSO::
 
@@ -1469,18 +1466,19 @@ def OA_find_disjoint_blocks(OA, k, n, x,
     independent_set = [OA[i] for i,v in b.items() if v]
     return independent_set
 
-def OA_relabel(OA,k,n,blocks=tuple(),matrix=None):
+
+def OA_relabel(OA, k, n, blocks=tuple(), matrix=None, symbol_list=None):
     r"""
     Return a relabelled version of the OA.
 
     INPUT:
 
     - ``OA`` -- an OA, or rather a list of blocks of length `k`, each
-      of which contains integers from `0` to `n-1`.
+      of which contains integers from `0` to `n-1`
 
-    - ``k,n`` (integers)
+    - ``k``, ``n`` -- integers
 
-    - ``blocks`` (list of blocks) -- relabels the integers of the OA
+    - ``blocks`` -- list of blocks; relabels the integers of the OA
       from `[0..n-1]` into `[0..n-1]` in such a way that the `i`
       blocks from ``block`` are respectively relabeled as
       ``[n-i,...,n-i]``, ..., ``[n-1,...,n-1]``. Thus, the blocks from
@@ -1498,6 +1496,11 @@ def OA_relabel(OA,k,n,blocks=tuple(),matrix=None):
 
       If set to ``None`` (default) no such relabelling is performed.
 
+    - ``symbol_list`` -- list of the desired symbols for the
+      relabelled OA. If this is not ``None``, the same relabelling is
+      done on all blocks such that the index of an element in
+      symbol_list is its preimage in the relabelling map.
+
       .. NOTE::
 
           A ``None`` coordinate in one block remains a ``None``
@@ -1516,6 +1519,10 @@ def OA_relabel(OA,k,n,blocks=tuple(),matrix=None):
         sage: is_transversal_design(TD,3,2)
         True
 
+        sage: OA = designs.orthogonal_arrays.build(3,2)
+        sage: OA_relabel(OA, 3, 2, symbol_list=['A', 'B'])
+        [['A', 'A', 'A'], ['A', 'B', 'B'], ['B', 'A', 'B'], ['B', 'B', 'A']]
+
     Making sure that ``[2,2,2,2]`` is a block of `OA(4,3)`. We do this
     by relabelling block ``[0,0,0,0]`` which belongs to the design::
 
@@ -1530,11 +1537,10 @@ def OA_relabel(OA,k,n,blocks=tuple(),matrix=None):
         Traceback (most recent call last):
         ...
         RuntimeError: Two block have the same coordinate for one of the k dimensions
-
     """
     if blocks:
         l = []
-        for i,B in enumerate(zip(*blocks)): # the blocks are disjoint
+        for i, B in enumerate(zip(*blocks)):  # the blocks are disjoint
             if len(B) != len(set(B)):
                 raise RuntimeError("Two block have the same coordinate for one of the k dimensions")
 
@@ -1545,9 +1551,38 @@ def OA_relabel(OA,k,n,blocks=tuple(),matrix=None):
     if matrix:
         OA = [[matrix[i][j] if j is not None else None for i,j in enumerate(R)] for R in OA]
 
+    if symbol_list:
+        mapping = dict(enumerate(symbol_list))
+        OA = [[mapping[element] for element in row] for row in OA]
     return OA
 
-def OA_n_times_2_pow_c_from_matrix(k,c,G,A,Y,check=True):
+
+def OA_standard_label(OA):
+    r"""
+    Return the inputted OA with entries relabelled as integers [0,...,n-1].
+
+    INPUT:
+
+    - ``OA`` -- list of lists with symbols as entries that are not
+      necessarily integers
+
+    EXAMPLES::
+
+        sage: from sage.combinat.designs.orthogonal_arrays import OA_standard_label
+        sage: C = [['a', 'a', 'a', 'b'],
+        ....:      ['a', 'a', 'b', 'a'],
+        ....:      ['a', 'b', 'a', 'a'],
+        ....:      ['b', 'a', 'a', 'a'],
+        ....:      ['b', 'b', 'b', 'b']]
+        sage: OA_standard_label(C)
+        [[0, 0, 0, 1], [0, 0, 1, 0], [0, 1, 0, 0], [1, 0, 0, 0], [1, 1, 1, 1]]
+    """
+    symbol_list = sorted({x for l in OA for x in l})
+    mapping = {symbol: index for index, symbol in enumerate(symbol_list)}
+    return [[mapping[element] for element in row] for row in OA]
+
+
+def OA_n_times_2_pow_c_from_matrix(k, c, G, A, Y, check=True):
     r"""
     Return an `OA(k, |G| \cdot 2^c)` from a constrained `(G,k-1,2)`-difference
     matrix.
@@ -1579,7 +1614,7 @@ def OA_n_times_2_pow_c_from_matrix(k,c,G,A,Y,check=True):
 
     INPUT:
 
-    - ``k,c`` (integers) -- integers
+    - ``k``, ``c`` -- integers
 
     - ``G`` -- an additive Abelian group
 
@@ -1587,10 +1622,9 @@ def OA_n_times_2_pow_c_from_matrix(k,c,G,A,Y,check=True):
 
     - ``Y`` -- a vector with entries in `GF(2^c)`
 
-    - ``check`` -- (boolean) Whether to check that output is correct before
-      returning it. As this is expected to be useless (but we are cautious
-      guys), you may want to disable it whenever you want speed. Set to
-      ``True`` by default.
+    - ``check`` -- boolean (default: ``True``); whether to check that output is
+      correct before returning it. As this is expected to be useless, you may
+      want to disable it whenever you want speed.
 
     .. NOTE::
 
@@ -1705,9 +1739,10 @@ def OA_n_times_2_pow_c_from_matrix(k,c,G,A,Y,check=True):
     Mb = [[e+GG((G.zero(),x*v)) for v in H for e in R] for x, R in zip(Y, A)]
     return OA_from_quasi_difference_matrix(list(zip(*Mb)),GG,add_col=True)
 
-def OA_from_quasi_difference_matrix(M,G,add_col=True,fill_hole=True):
+
+def OA_from_quasi_difference_matrix(M, G, add_col=True, fill_hole=True):
     r"""
-    Return an Orthogonal Array from a Quasi-Difference matrix
+    Return an Orthogonal Array from a Quasi-Difference matrix.
 
     **Difference Matrices**
 
@@ -1771,10 +1806,10 @@ def OA_from_quasi_difference_matrix(M,G,add_col=True,fill_hole=True):
 
     - ``G`` -- a group
 
-    - ``add_col`` (boolean) -- whether to add a column to the final OA equal to
-      `(x_1,\dots,x_g,x_1,\dots,x_g,\dots)` where `G=\{x_1,\dots,x_g\}`.
+    - ``add_col`` -- boolean; whether to add a column to the final OA equal to
+      `(x_1,\dots,x_g,x_1,\dots,x_g,\dots)` where `G=\{x_1,\dots,x_g\}`
 
-    - ``fill_hole`` (boolean) -- whether to return the incomplete orthogonal
+    - ``fill_hole`` -- boolean; whether to return the incomplete orthogonal
       array, or complete it with the `OA(k,u)` (default). When ``fill_hole is
       None``, no block of the incomplete OA contains more than one value `\geq
       |G|`.
@@ -1824,15 +1859,16 @@ def OA_from_quasi_difference_matrix(M,G,add_col=True,fill_hole=True):
 
     return new_M
 
-def OA_from_Vmt(m,t,V):
+
+def OA_from_Vmt(m, t, V):
     r"""
-    Return an Orthogonal Array from a `V(m,t)`
+    Return an Orthogonal Array from a `V(m,t)`.
 
     INPUT:
 
-    - ``m,t`` (integers)
+    - ``m``, ``t`` -- integers
 
-    - ``V`` -- the vector `V(m,t)`.
+    - ``V`` -- the vector `V(m,t)`
 
     .. SEEALSO::
 
@@ -1848,9 +1884,9 @@ def OA_from_Vmt(m,t,V):
     return OA_from_quasi_difference_matrix(M,Fq,add_col=False)
 
 
-def QDM_from_Vmt(m,t,V):
+def QDM_from_Vmt(m, t, V):
     r"""
-    Return a QDM from a `V(m,t)`
+    Return a QDM from a `V(m,t)`.
 
     **Definition**
 
@@ -1881,9 +1917,9 @@ def QDM_from_Vmt(m,t,V):
 
     INPUT:
 
-    - ``m,t`` (integers)
+    - ``m``, ``t`` -- integers
 
-    - ``V`` -- the vector `V(m,t)`.
+    - ``V`` -- the vector `V(m,t)`
 
     .. SEEALSO::
 
@@ -1905,15 +1941,16 @@ def QDM_from_Vmt(m,t,V):
         for e in V:
             L.append(e*wm**i)
         for ii in range(m+2):
-            M.append(L[-ii:]+L[:-ii]) # cyclic shift
+            M.append(L[-ii:]+L[:-ii])  # cyclic shift
 
     M.append([0]*(m+2))
 
     return Fq, M
 
-def OA_from_PBD(k,n,PBD, check=True):
+
+def OA_from_PBD(k, n, PBD, check=True):
     r"""
-    Return an `OA(k,n)` from a PBD
+    Return an `OA(k,n)` from a PBD.
 
     **Construction**
 
@@ -1933,9 +1970,9 @@ def OA_from_PBD(k,n,PBD, check=True):
 
     INPUT:
 
-    - ``k,n`` (integers)
+    - ``k``, ``n`` -- integers
 
-    - ``PBD`` -- a PBD on `0,...,n-1`.
+    - ``PBD`` -- a PBD on `0, \ldots, n-1`
 
     EXAMPLES:
 
@@ -1993,7 +2030,8 @@ def OA_from_PBD(k,n,PBD, check=True):
 
     return OA
 
-def OA_from_wider_OA(OA,k):
+
+def OA_from_wider_OA(OA, k):
     r"""
     Return the first `k` columns of `OA`.
 
@@ -2001,9 +2039,9 @@ def OA_from_wider_OA(OA,k):
 
     INPUT:
 
-    - ``OA`` -- an orthogonal array.
+    - ``OA`` -- an orthogonal array
 
-    - ``k`` (integer)
+    - ``k`` -- integer
 
     EXAMPLES::
 
@@ -2011,13 +2049,13 @@ def OA_from_wider_OA(OA,k):
         sage: OA_from_wider_OA(designs.orthogonal_arrays.build(6,20,2),1)[:5]
         [(19,), (19,), (19,), (19,), (19,)]
         sage: _ = designs.orthogonal_arrays.build(5,46) # indirect doctest
-
     """
     if len(OA[0]) == k:
         return OA
     return [L[:k] for L in OA]
 
-class OAMainFunctions():
+
+class OAMainFunctions:
     r"""
     Functions related to orthogonal arrays.
 
@@ -2066,8 +2104,8 @@ class OAMainFunctions():
         6
 
     If you ask for an orthogonal array that does not exist, then you will
-    either obtain an ``EmptySetError`` (if it knows that such an orthogonal array
-    does not exist) or a ``NotImplementedError``::
+    either obtain an :exc:`EmptySetError` (if it knows that such an orthogonal
+    array does not exist) or a :exc:`NotImplementedError`::
 
         sage: designs.orthogonal_arrays.build(4,2)
         Traceback (most recent call last):
@@ -2078,7 +2116,7 @@ class OAMainFunctions():
         ...
         NotImplementedError: I don't know how to build an OA(12,20)!
     """
-    def __init__(self,*args,**kwds):
+    def __init__(self, *args, **kwds):
         r"""
         There is nothing here.
 
@@ -2094,13 +2132,13 @@ class OAMainFunctions():
     largest_available_k = staticmethod(largest_available_k)
 
     @staticmethod
-    def explain_construction(k,n,t=2):
+    def explain_construction(k, n, t=2):
         r"""
-        Return a string describing how to builds an `OA(k,n)`
+        Return a string describing how to builds an `OA(k,n)`.
 
         INPUT:
 
-        - ``k,n,t`` (integers) -- parameters of the orthogonal array.
+        - ``k``, ``n``, ``t`` -- integers; parameters of the orthogonal array
 
         EXAMPLES::
 
@@ -2112,9 +2150,9 @@ class OAMainFunctions():
         return orthogonal_array(k,n,t,explain_construction=True)
 
     @staticmethod
-    def build(k,n,t=2,resolvable=False):
+    def build(k, n, t=2, resolvable=False):
         r"""
-        Return an `OA(k,n)` of strength `t`
+        Return an `OA(k,n)` of strength `t`.
 
         An orthogonal array of parameters `k,n,t` is a matrix with `k`
         columns filled with integers from `[n]` in such a way that for any
@@ -2129,12 +2167,12 @@ class OAMainFunctions():
 
         INPUT:
 
-        - ``k,n,t`` (integers) -- parameters of the orthogonal array.
+        - ``k``, ``n``, ``t`` -- integers; parameters of the orthogonal array
 
-        - ``resolvable`` (boolean) -- set to ``True`` if you want the design to be
-          resolvable. The `n` classes of the resolvable design are obtained as the
-          first `n` blocks, then the next `n` blocks, etc ... Set to ``False`` by
-          default.
+        - ``resolvable`` -- boolean (default: ``False``); set to ``True`` if
+          you want the design to be resolvable. The `n` classes of the
+          resolvable design are obtained as the first `n` blocks, then the next
+          `n` blocks, etc.
 
         EXAMPLES::
 
@@ -2149,18 +2187,17 @@ class OAMainFunctions():
              [1, 0, 2],
              [2, 2, 0]]
             sage: OA_7_50 = designs.orthogonal_arrays.build(7,50)      # indirect doctest
-
         """
         return orthogonal_array(k,n,t,resolvable=resolvable)
 
     @staticmethod
-    def exists(k,n,t=2):
+    def exists(k, n, t=2):
         r"""
-        Return the existence status of an `OA(k,n)`
+        Return the existence status of an `OA(k,n)`.
 
         INPUT:
 
-        - ``k,n,t`` (integers) -- parameters of the orthogonal array.
+        - ``k``, ``n``, ``t`` -- integers; parameters of the orthogonal array
 
         .. WARNING::
 
@@ -2183,13 +2220,13 @@ class OAMainFunctions():
         return orthogonal_array(k,n,t,existence=True)
 
     @staticmethod
-    def is_available(k,n,t=2):
+    def is_available(k, n, t=2):
         r"""
         Return whether Sage can build an `OA(k,n)`.
 
         INPUT:
 
-        - ``k,n,t`` (integers) -- parameters of the orthogonal array.
+        - ``k``, ``n``, ``t`` -- integers; parameters of the orthogonal array
 
         .. SEEALSO::
 
