@@ -23,21 +23,24 @@ AUTHORS:
 # (at your option) any later version.
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
+from itertools import product
 
 from sage.categories.infinite_enumerated_sets import InfiniteEnumeratedSets
 from sage.combinat.composition import Composition
 from sage.combinat.partition import Partition
 from sage.combinat.permutation import Permutations
-from sage.combinat.tableau import Tableau
-from sage.combinat.tiling import Polyomino
 from sage.combinat.skew_partition import SkewPartition
 from sage.combinat.skew_tableau import SkewTableaux
-from sage.matrix.matrix_dense import Matrix_dense
-from sage.matrix.matrix_sparse import Matrix_sparse
+from sage.combinat.tableau import Tableau
+from sage.misc.cachefunc import cached_method
 from sage.misc.inherit_comparison import InheritComparisonClasscallMetaclass
-from sage.structure.unique_representation import UniqueRepresentation
+from sage.misc.lazy_import import lazy_import
+from sage.structure.element import Matrix
 from sage.structure.list_clone import ClonableArray
 from sage.structure.parent import Parent
+from sage.structure.unique_representation import UniqueRepresentation
+
+lazy_import('sage.combinat.tiling', 'Polyomino')
 
 
 class Diagram(ClonableArray, metaclass=InheritComparisonClasscallMetaclass):
@@ -334,12 +337,9 @@ class Diagram(ClonableArray, metaclass=InheritComparisonClasscallMetaclass):
 
         lr = r'\def\lr#1{\multicolumn{1}{|@{\hspace{.6ex}}c@{\hspace{.6ex}}|}{\raisebox{-.3ex}{$#1$}}}'
 
-        array = []
-        for i in range(self._n_rows):
-            row = []
-            for j in range(self._n_cols):
-                row.append("\\phantom{x}" if (i, j) in self else None)
-            array.append(row)
+        array = [[("\\phantom{x}" if (i, j) in self else None)
+                  for j in range(self._n_cols)]
+                 for i in range(self._n_rows)]
 
         def end_line(r):
             # give the line ending to row ``r``
@@ -479,7 +479,7 @@ class Diagram(ClonableArray, metaclass=InheritComparisonClasscallMetaclass):
             sage: D = Diagram([(0,0), (0,-3), (2,2), (2,4)])
             Traceback (most recent call last):
             ...
-            ValueError: diagrams must be indexed by non-negative integers
+            ValueError: diagrams must be indexed by nonnegative integers
 
         The next example fails because one cell is indexed by rational
         numbers::
@@ -487,12 +487,12 @@ class Diagram(ClonableArray, metaclass=InheritComparisonClasscallMetaclass):
             sage: D = Diagram([(0,0), (0,3), (2/3,2), (2,4)])
             Traceback (most recent call last):
             ...
-            ValueError: diagrams must be indexed by non-negative integers
+            ValueError: diagrams must be indexed by nonnegative integers
         """
         from sage.sets.non_negative_integers import NonNegativeIntegers
         NN = NonNegativeIntegers()
         if not all(i in NN for c in self._cells for i in c):
-            raise ValueError("diagrams must be indexed by non-negative integers")
+            raise ValueError("diagrams must be indexed by nonnegative integers")
 
     def specht_module(self, base_ring=None):
         r"""
@@ -535,6 +535,28 @@ class Diagram(ClonableArray, metaclass=InheritComparisonClasscallMetaclass):
         from sage.combinat.specht_module import specht_module_rank
         return specht_module_rank(self, base_ring)
 
+    @cached_method
+    def essential_set(self):
+        r"""
+        Return the essential set of ``self`` as defined by Fulton.
+
+        Let `D` be a diagram. Then the *essential set* of `D` are the
+        cells `(i, j) \in D` such that `(i+1, j) \notin D` and
+        `(i, j+1) \notin D`; that is, the maximally southwest elements
+        in each connected component of `D`.
+
+        EXAMPLES::
+
+            sage: w = Permutation([2, 1, 5, 4, 3])
+            sage: D = w.rothe_diagram()
+            sage: D.essential_set()
+            ((0, 0), (2, 3), (3, 2))
+        """
+        ret = [c for c in self._cells if (c[0]+1, c[1]) not in self._cells
+               and (c[0], c[1]+1) not in self._cells]
+        ret.sort()
+        return tuple(ret)
+
 
 class Diagrams(UniqueRepresentation, Parent):
     r"""
@@ -551,7 +573,6 @@ class Diagrams(UniqueRepresentation, Parent):
         sage: D = Dgms([(0,0), (0,3), (2,2), (2,4)])
         sage: D.parent()
         Combinatorial diagrams
-
     """
 
     def __init__(self, category=None):
@@ -692,7 +713,7 @@ class Diagrams(UniqueRepresentation, Parent):
             return self.from_polyomino(cells)
         if isinstance(cells, Composition):
             return self.from_composition(cells)
-        if isinstance(cells, (Matrix_dense, Matrix_sparse)):
+        if isinstance(cells, Matrix):
             return self.from_zero_one_matrix(cells)
 
         return self.element_class(self, cells, n_rows, n_cols, check)
@@ -889,7 +910,7 @@ class NorthwestDiagram(Diagram, metaclass=InheritComparisonClasscallMetaclass):
             sage: NorthwestDiagram([(0,1/2)])
             Traceback (most recent call last):
             ...
-            ValueError: diagrams must be indexed by non-negative integers
+            ValueError: diagrams must be indexed by nonnegative integers
         """
         from itertools import combinations
         Diagram.check(self)
@@ -1200,7 +1221,7 @@ class NorthwestDiagrams(Diagrams):
         Combinatorial northwest diagrams
 
     Additionally, there are natural constructions of a northwest diagram
-    given the data of a permutation (Rothe diagrams are the protypical example
+    given the data of a permutation (Rothe diagrams are the prototypical example
     of northwest diagrams), or the data of a partition of an integer, or a
     skew partition.
 
@@ -1224,7 +1245,7 @@ class NorthwestDiagrams(Diagrams):
     To turn a Ferrers diagram into a northwest diagram, we may call
     :meth:`from_partition`. This will return a Ferrer's diagram in the
     set of all northwest diagrams. For many use-cases it is probably better
-    to get Ferrer's diagrams by the corresponding method on partitons, namely
+    to get Ferrer's diagrams by the corresponding method on partitions, namely
     :meth:`sage.combinat.partitions.Partitions.ferrers_diagram`::
 
         sage: mu = Partition([7,3,1,1])
@@ -1523,8 +1544,7 @@ def RotheDiagram(w):
 
     N = w.size()
     winv = w.inverse()
-    from sage.misc.mrange import cartesian_product_iterator
-    cells = [c for c in cartesian_product_iterator((range(N), range(N)))
+    cells = [c for c in product(range(N), range(N))
              if c[0] + 1 < winv(c[1] + 1) and c[1] + 1 < w(c[0] + 1)]
 
     return NorthwestDiagram(cells, n_rows=N, n_cols=N, check=False)
