@@ -37,7 +37,7 @@ def _int_or_half_int(k):
 
     OUTPUT:
 
-    If ``k`` is not in `1/2 \ZZ`, then this raises a :class:`ValueError`.
+    If ``k`` is not in `1/2 \ZZ`, then this raises a :exc:`ValueError`.
     Otherwise, we return the pair:
 
     - boolean; ``True`` if ``k`` is an integer and ``False`` if a half integer
@@ -364,9 +364,7 @@ class SetPartitionsSk_k(SetPartitionsAk_k):
             True
         """
         for p in Permutations(self.k):
-            res = []
-            for i in range(self.k):
-                res.append(Set([i + 1, -p[i]]))
+            res = [Set([i, -pi]) for i, pi in enumerate(p, start=1)]
             yield self.element_class(self, res)
 
 
@@ -433,10 +431,7 @@ class SetPartitionsSkhalf_k(SetPartitionsAkhalf_k):
              {{1, -3}, {2, -2}, {4, -4}, {3, -1}}]
         """
         for p in Permutations(self.k):
-            res = []
-            for i in range(self.k):
-                res.append(Set([i + 1, -p[i]]))
-
+            res = [Set([i, -pi]) for i, pi in enumerate(p, start=1)]
             res.append(Set([self.k + 1, -self.k - 1]))
             yield self.element_class(self, res)
 
@@ -851,7 +846,6 @@ def SetPartitionsPk(k):
         {{-1}, {-2}, {2}, {3, -3}, {1}}
         sage: P2p5.random_element() #random
         {{1, 2, 3, -3}, {-1, -2}}
-
     """
     is_int, k = _int_or_half_int(k)
     if not is_int:
@@ -1579,7 +1573,7 @@ class PartitionAlgebra_ak(PartitionAlgebra_generic):
             name = "Partition algebra A_%s(%s)" % (k, n)
         cclass = SetPartitionsAk(k)
         self._element_class = PartitionAlgebraElement_ak
-        PartitionAlgebra_generic.__init__(self, R, cclass, n, k, name=name, prefix="A")
+        PartitionAlgebra_generic.__init__(self, R, cclass, n, k, name=name, prefix='A')
 
 
 class PartitionAlgebraElement_bk(PartitionAlgebraElement_generic):
@@ -1600,7 +1594,7 @@ class PartitionAlgebra_bk(PartitionAlgebra_generic):
             name = "Partition algebra B_%s(%s)" % (k, n)
         cclass = SetPartitionsBk(k)
         self._element_class = PartitionAlgebraElement_bk
-        PartitionAlgebra_generic.__init__(self, R, cclass, n, k, name=name, prefix="B")
+        PartitionAlgebra_generic.__init__(self, R, cclass, n, k, name=name, prefix='B')
 
 
 class PartitionAlgebraElement_sk(PartitionAlgebraElement_generic):
@@ -1621,7 +1615,7 @@ class PartitionAlgebra_sk(PartitionAlgebra_generic):
             name = "Partition algebra S_%s(%s)" % (k, n)
         cclass = SetPartitionsSk(k)
         self._element_class = PartitionAlgebraElement_sk
-        PartitionAlgebra_generic.__init__(self, R, cclass, n, k, name=name, prefix="S")
+        PartitionAlgebra_generic.__init__(self, R, cclass, n, k, name=name, prefix='S')
 
 
 class PartitionAlgebraElement_pk(PartitionAlgebraElement_generic):
@@ -1642,7 +1636,7 @@ class PartitionAlgebra_pk(PartitionAlgebra_generic):
             name = "Partition algebra P_%s(%s)" % (k, n)
         cclass = SetPartitionsPk(k)
         self._element_class = PartitionAlgebraElement_pk
-        PartitionAlgebra_generic.__init__(self, R, cclass, n, k, name=name, prefix="P")
+        PartitionAlgebra_generic.__init__(self, R, cclass, n, k, name=name, prefix='P')
 
 
 class PartitionAlgebraElement_tk(PartitionAlgebraElement_generic):
@@ -1663,7 +1657,7 @@ class PartitionAlgebra_tk(PartitionAlgebra_generic):
             name = "Partition algebra T_%s(%s)" % (k, n)
         cclass = SetPartitionsTk(k)
         self._element_class = PartitionAlgebraElement_tk
-        PartitionAlgebra_generic.__init__(self, R, cclass, n, k, name=name, prefix="T")
+        PartitionAlgebra_generic.__init__(self, R, cclass, n, k, name=name, prefix='T')
 
 
 class PartitionAlgebraElement_rk(PartitionAlgebraElement_generic):
@@ -1684,7 +1678,7 @@ class PartitionAlgebra_rk(PartitionAlgebra_generic):
             name = "Partition algebra R_%s(%s)" % (k, n)
         cclass = SetPartitionsRk(k)
         self._element_class = PartitionAlgebraElement_rk
-        PartitionAlgebra_generic.__init__(self, R, cclass, n, k, name=name, prefix="R")
+        PartitionAlgebra_generic.__init__(self, R, cclass, n, k, name=name, prefix='R')
 
 
 class PartitionAlgebraElement_prk(PartitionAlgebraElement_generic):
@@ -1705,7 +1699,7 @@ class PartitionAlgebra_prk(PartitionAlgebra_generic):
             name = "Partition algebra PR_%s(%s)" % (k, n)
         cclass = SetPartitionsPRk(k)
         self._element_class = PartitionAlgebraElement_prk
-        PartitionAlgebra_generic.__init__(self, R, cclass, n, k, name=name, prefix="PR")
+        PartitionAlgebra_generic.__init__(self, R, cclass, n, k, name=name, prefix='PR')
 
 
 ##########################################################
@@ -1942,15 +1936,15 @@ def to_set_partition(l, k=None):
         to_be_added -= spart
         sp.append(spart)
 
-    for singleton in to_be_added:
-        sp.append(Set([singleton]))
+    sp.extend(Set([singleton])
+              for singleton in to_be_added)
 
     return Set(sp)
 
 
 def identity(k):
-    """
-    Return the identity set partition 1, -1, ..., k, -k
+    r"""
+    Return the identity set partition `1, -1, \ldots, k, -k`.
 
     EXAMPLES::
 
