@@ -43,7 +43,7 @@ class AmbientSpace(ambient_space.AmbientSpace):
             sage: R = RootSystem(['A', [4,2]])
             sage: AL = R.ambient_space(); AL
             Ambient space of the Root system of type ['A', [4, 2]]
-            sage: TestSuite(AL).run(skip="_test_norm_of_simple_roots")
+            sage: TestSuite(AL).run(skip='_test_norm_of_simple_roots')
         """
         ct = root_system.cartan_type()
         if index_set is None:
@@ -378,7 +378,7 @@ class AmbientSpace(ambient_space.AmbientSpace):
         def has_descent(self, i, positive=False):
             """
             Test if ``self`` has a descent at position `i`, that is
-            if ``self`` is on the strict negative side of the `i^{th}`
+            if ``self`` is on the strict negative side of the `i`-th
             simple reflection hyperplane.
 
             If ``positive`` is ``True``, tests if it is on the strict
@@ -710,7 +710,7 @@ class CartanType(SuperCartanType_standard):
         from . import type_relabel
         return type_relabel.CartanType(self, relabelling)
 
-    def _latex_draw_node(self, x, y, label, position="below=4pt"):
+    def _latex_draw_node(self, x, y, label, position='below=4pt'):
         r"""
         Draw (possibly marked [crossed out]) circular node ``i`` at the
         position ``(x,y)`` with node label ``label`` .
