@@ -44,7 +44,7 @@ from . import llt
 
 class SymmetricFunctions(UniqueRepresentation, Parent):
     r"""
-    The abstract algebra of commutative symmetric functions
+    The abstract algebra of commutative symmetric functions.
 
     .. rubric:: Symmetric Functions in Sage
 
@@ -135,7 +135,7 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
         sage: p[[]]
         p[]
 
-    .. note:: When elements are constructed using the ``p[something ]`` syntax ,
+    .. NOTE:: When elements are constructed using the ``p[something ]`` syntax ,
        an error will be raised if the input cannot be interpreted as a partition.
        This is *not* the case when ``p.basis()`` is used::
 
@@ -522,14 +522,14 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
     One can also use the Sage standard renaming idiom to get shorter outputs::
 
         sage: Sym = SymmetricFunctions(QQ)
-        sage: Sym.rename("Sym")
+        sage: Sym.rename('Sym')
         sage: Sym
         Sym
         sage: Sym.rename()
 
     And we name it back::
 
-        sage: Sym.rename("Symmetric Functions over Rational Field"); Sym
+        sage: Sym.rename('Symmetric Functions over Rational Field'); Sym
         Symmetric Functions over Rational Field
 
     .. rubric:: Other bases
@@ -845,7 +845,6 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
         - Devise a mechanism so that pickling bases of symmetric
           functions pickles the coercions which have a cache.
     """
-
     def __init__(self, R):
         r"""
         Initialization of ``self``.
@@ -863,7 +862,6 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
             sage: Sym1 = SymmetricFunctions(FiniteField(23))
             sage: Sym2 = SymmetricFunctions(Integers(23))
             sage: TestSuite(Sym).run()
-
         """
         # change the line below to assert(R in Rings()) once MRO issues from #15536, #15475 are resolved
         assert R in Fields() or R in Rings()  # side effect of this statement assures MRO exists for R
@@ -898,7 +896,7 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
 
     def schur(self):
         r"""
-        The Schur basis of the Symmetric Functions
+        The Schur basis of the Symmetric Functions.
 
         EXAMPLES::
 
@@ -911,7 +909,7 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
 
     def powersum(self):
         r"""
-        The power sum basis of the Symmetric Functions
+        The power sum basis of the Symmetric Functions.
 
         EXAMPLES::
 
@@ -924,7 +922,7 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
 
     def complete(self):
         r"""
-        The complete basis of the Symmetric Functions
+        The complete basis of the Symmetric Functions.
 
         EXAMPLES::
 
@@ -937,7 +935,7 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
 
     def elementary(self):
         r"""
-        The elementary basis of the Symmetric Functions
+        The elementary basis of the Symmetric Functions.
 
         EXAMPLES::
 
@@ -949,7 +947,7 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
 
     def monomial(self):
         r"""
-        The monomial basis of the Symmetric Functions
+        The monomial basis of the Symmetric Functions.
 
         EXAMPLES::
 
@@ -1220,7 +1218,7 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
 
     def macdonald(self, q='q', t='t'):
         r"""
-        Returns the entry point for the various Macdonald bases.
+        Return the entry point for the various Macdonald bases.
 
         INPUT:
 
@@ -1267,7 +1265,7 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
 
     def hall_littlewood(self, t='t'):
         """
-        Returns the entry point for the various Hall-Littlewood bases.
+        Return the entry point for the various Hall-Littlewood bases.
 
         INPUT:
 
@@ -1299,7 +1297,7 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
 
     def jack(self, t='t'):
         """
-        Returns the entry point for the various Jack bases.
+        Return the entry point for the various Jack bases.
 
         INPUT:
 
@@ -1325,7 +1323,7 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
 
     def zonal(self):
         """
-        The zonal basis of the Symmetric Functions
+        The zonal basis of the Symmetric Functions.
 
         EXAMPLES::
 
@@ -1340,7 +1338,7 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``k`` -- a positive integer indicating the level
+        - ``k`` -- positive integer indicating the level
         - ``t`` -- a parameter (default: `t`)
 
         LLT polynomials in `hspin` and `hcospin` bases.
@@ -1360,7 +1358,7 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
 
     def from_polynomial(self, f):
         """
-        Converts a symmetric polynomial ``f`` to a symmetric function.
+        Convert a symmetric polynomial ``f`` to a symmetric function.
 
         INPUT:
 
@@ -1422,7 +1420,7 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
 
     def __init_extra__(self):
         """
-        Sets up the coercions between the different bases
+        Set up the coercions between the different bases.
 
         EXAMPLES::
 
@@ -1438,7 +1436,6 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
             2*s[] + 2*s[1] - 3*s[1, 1] + 3*s[2]
             sage: f(p.an_element()) == p.an_element()
             True
-
         """
         #powersum   = self.powersum  ()
         #complete   = self.complete  ()
@@ -1472,8 +1469,8 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``k`` -- a positive integer
-        - ``t`` a formal parameter; `t=1` yields a subring
+        - ``k`` -- positive integer
+        - ``t`` -- a formal parameter; `t=1` yields a subring
 
         The subspace of the ring of symmetric functions spanned by
         `\{ s_{\lambda}[X/(1-t)] \}_{\lambda_1\le k} = \{ s_{\lambda}^{(k)}[X,t]\}_{\lambda_1 \le k}`
@@ -1503,7 +1500,7 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
 
     def kschur(self, k, t='t'):
         r"""
-        Returns the `k`-Schur functions.
+        Return the `k`-Schur functions.
 
         EXAMPLES::
 
@@ -1543,7 +1540,7 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
 
     def khomogeneous(self, k):
         r"""
-        Returns the homogeneous symmetric functions in the `k`-bounded subspace.
+        Return the homogeneous symmetric functions in the `k`-bounded subspace.
 
         EXAMPLES::
 
@@ -1558,11 +1555,11 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
 
     def kBoundedQuotient(self, k, t='t'):
         r"""
-        Returns the `k`-bounded quotient space of the ring of symmetric functions.
+        Return the `k`-bounded quotient space of the ring of symmetric functions.
 
         INPUT:
 
-        - ``k`` -- a positive integer
+        - ``k`` -- positive integer
 
         The quotient of the ring of symmetric functions ...
 
@@ -1593,7 +1590,7 @@ class SymmetricaConversionOnBasis:
         INPUT:
 
         - ``t`` -- a function taking a monomial in CombinatorialFreeModule(QQ, Partitions()),
-           and returning a (partition, coefficient) list.
+          and returning a (partition, coefficient) list
 
         - ``domain``, ``codomain`` -- parents
 
@@ -1606,7 +1603,7 @@ class SymmetricaConversionOnBasis:
 
             sage: Sym = SymmetricFunctions(QQ['x'])
             sage: p = Sym.p(); s = Sym.s()
-            sage: def t(x) : [(p,c)] = x; return [ (p,2*c), (p.conjugate(), c) ]
+            sage: def t(x) : [(p, c)] = x; return [ (p, 2*c), (p.conjugate(), c) ]
             sage: f = sage.combinat.sf.sf.SymmetricaConversionOnBasis(t, p, s)
             sage: f(Partition([3,1]))
             s[2, 1, 1] + 2*s[3, 1]
