@@ -239,9 +239,7 @@ class SymmetricFunctionAlgebra_witt(multiplicative.SymmetricFunctionAlgebra_mult
 
         - ``lam`` -- a partition
 
-        OUTPUT:
-
-        - the expansion of ``h[lam]`` in the Witt basis ``self``
+        OUTPUT: the expansion of ``h[lam]`` in the Witt basis ``self``
 
         EXAMPLES::
 
@@ -318,9 +316,7 @@ class SymmetricFunctionAlgebra_witt(multiplicative.SymmetricFunctionAlgebra_mult
 
         - ``lam`` -- a partition
 
-        OUTPUT:
-
-        - the expansion of ``e[lam]`` in the Witt basis ``self``
+        OUTPUT: the expansion of ``e[lam]`` in the Witt basis ``self``
 
         EXAMPLES::
 
@@ -395,9 +391,7 @@ class SymmetricFunctionAlgebra_witt(multiplicative.SymmetricFunctionAlgebra_mult
 
         - ``lam`` -- a partition
 
-        OUTPUT:
-
-        - the expansion of ``p[lam]`` in the Witt basis ``self``
+        OUTPUT: the expansion of ``p[lam]`` in the Witt basis ``self``
 
         EXAMPLES::
 
@@ -561,7 +555,7 @@ class SymmetricFunctionAlgebra_witt(multiplicative.SymmetricFunctionAlgebra_mult
 
         INPUT:
 
-        - ``n`` -- a positive integer
+        - ``n`` -- positive integer
 
         OUTPUT:
 
