@@ -35,8 +35,8 @@ class Latte_count(Executable):
             sage: isinstance(Latte_count(), Latte_count)
             True
         """
-        Executable.__init__(self, "latte-count", executable="latte-count",
-                            spkg="latte_int",
+        Executable.__init__(self, 'latte-count', executable="latte-count",
+                            spkg='latte_int',
                             url=LATTE_URL)
 
 
@@ -52,8 +52,8 @@ class Latte_integrate(Executable):
             sage: isinstance(Latte_integrate(), Latte_integrate)
             True
         """
-        Executable.__init__(self, "integrate", executable="integrate",
-                            spkg="latte_int",
+        Executable.__init__(self, 'integrate', executable='integrate',
+                            spkg='latte_int',
                             url=LATTE_URL)
 
 
@@ -76,9 +76,9 @@ class Latte(JoinFeature):
             sage: isinstance(Latte(), Latte)
             True
         """
-        JoinFeature.__init__(self, "latte_int",
+        JoinFeature.__init__(self, 'latte_int',
                              (Latte_count(), Latte_integrate()),
-                             description="LattE")
+                             description='LattE')
 
 
 def all_features():
