@@ -82,7 +82,7 @@ lazy_import('sage.symbolic.ring', 'SR')
 class PiecewiseFunction(BuiltinFunction):
     def __init__(self):
         """
-        Piecewise function
+        Piecewise function.
 
         EXAMPLES::
 
@@ -96,24 +96,24 @@ class PiecewiseFunction(BuiltinFunction):
             1/2*y^2
         """
         BuiltinFunction.__init__(self, "piecewise",
-                                 latex_name="piecewise",
+                                 latex_name='piecewise',
                                  conversions=dict(), nargs=2)
 
     def __call__(self, function_pieces, **kwds):
         r"""
-        Piecewise functions
+        Piecewise functions.
 
         INPUT:
 
-        - ``function_pieces`` -- a list of pairs consisting of a
-          domain and a symbolic function.
+        - ``function_pieces`` -- list of pairs consisting of a
+          domain and a symbolic function
 
-        - ``var=x`` -- a symbolic variable or ``None`` (default). The
-          real variable in which the function is piecewise in.
+        - ``var=x`` -- a symbolic variable or ``None`` (default); the
+          real variable in which the function is piecewise in
 
         OUTPUT:
 
-        A piecewise-defined function. A :class:`ValueError` will be raised
+        A piecewise-defined function. A :exc:`ValueError` will be raised
         if the domains of the pieces are not pairwise disjoint.
 
         EXAMPLES::
@@ -166,11 +166,9 @@ class PiecewiseFunction(BuiltinFunction):
 
     def _print_(self, parameters, variable):
         """
-        Return a string representation
+        Return a string representation.
 
-        OUTPUT:
-
-        String.
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -179,15 +177,15 @@ class PiecewiseFunction(BuiltinFunction):
             'piecewise(x|-->-x on (-2, 0), x|-->x on [0, 4]; x)'
         """
         s = 'piecewise('
-        args = []
-        for domain, func in parameters:
-            args.append('{0}|-->{1} on {2}'.format(str(variable), str(func), str(domain)))
-        s += ', '.join(args) + '; {0})'.format(str(variable))
+        # NOTE : could use ⟼ instead of |-->
+        args = (f'{variable}|-->{func} on {domain}'
+                for domain, func in parameters)
+        s += ', '.join(args) + f'; {variable})'
         return s
 
     def _subs_(self, subs_map, options, parameters, x):
         """
-        Callback from Pynac `subs()`
+        Callback from Pynac ``subs()``.
 
         EXAMPLES:
 
@@ -211,39 +209,43 @@ class PiecewiseFunction(BuiltinFunction):
             piecewise(x|-->-x^y on (-2, 0), x|-->x - y on [0, 2]; x)
             sage: p.subs(y=sin(y))
             piecewise(x|-->-x^sin(y) on (-2, 0), x|-->x - sin(y) on [0, 2]; x)
+
+        One can change the variable as follows::
+
+            sage: p = piecewise([((-2, 0), -x), ([0, 4], x)], var=x)
+            sage: y = SR.var('y')
+            sage: p(y)
+            piecewise(y|-->-y on (-2, 0), y|-->y on [0, 4]; y)
         """
         point = subs_map.apply_to(x, 0)
-        if ((point.is_numeric() or point.is_constant()) and (point.is_real())):
+
+        if point.is_symbol():  # avoid to compare with x (see #37925)
+            new_params = [(domain, subs_map.apply_to(func, 0))
+                          for domain, func in parameters]
+            return piecewise(new_params, var=point)
+
+        if (point.is_numeric() or point.is_constant()) and point.is_real():
             if hasattr(point, 'pyobject'):
                 # unwrap any numeric values
                 point = point.pyobject()
-        elif point == x:  # this comparison may be very slow (see #37925)
-            # substitution only in auxiliary variables
-            new_params = []
             for domain, func in parameters:
-                new_params.append((domain, subs_map.apply_to(func, 0)))
-            return piecewise(new_params, var=x)
-        else:
-            raise ValueError('substituting the piecewise variable must result in real number')
+                if domain.contains(point):
+                    return subs_map.apply_to(func, 0)
+            raise ValueError(f'point {point} is not in the domain')
 
-        for domain, func in parameters:
-            if domain.contains(point):
-                return subs_map.apply_to(func, 0)
-        raise ValueError('point {} is not in the domain'.format(point))
+        raise ValueError('substitution not allowed')
 
     @staticmethod
     def in_operands(ex):
         """
         Return whether a symbolic expression contains a piecewise
-        function as operand
+        function as operand.
 
         INPUT:
 
-        - ``ex`` -- a symbolic expression.
+        - ``ex`` -- a symbolic expression
 
-        OUTPUT:
-
-        Boolean
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -257,20 +259,22 @@ class PiecewiseFunction(BuiltinFunction):
             False
         """
         def is_piecewise(ex):
-            result = ex.operator() is piecewise
+            if ex.operator() is piecewise:
+                return True
             for op in ex.operands():
-                result = result or is_piecewise(op)
-            return result
+                if is_piecewise(op):
+                    return True
+            return False
         return is_piecewise(ex)
 
     @staticmethod
     def simplify(ex):
         """
-        Combine piecewise operands into single piecewise function
+        Combine piecewise operands into single piecewise function.
 
         OUTPUT:
 
-        A piecewise function whose operands are not piecewiese if
+        A piecewise function whose operands are not piecewise if
         possible, that is, as long as the piecewise variable is the same.
 
         EXAMPLES::
@@ -315,7 +319,7 @@ class PiecewiseFunction(BuiltinFunction):
                           for domain, func in parameters],
                          var=variable)
 
-    class EvaluationMethods():
+    class EvaluationMethods:
 
         def __pow__(self, parameters, variable, n):
             """
@@ -340,11 +344,11 @@ class PiecewiseFunction(BuiltinFunction):
         def expression_at(self, parameters, variable, point):
             """
             Return the expression defining the piecewise function at
-            ``value``
+            ``value``.
 
             INPUT:
 
-            - ``point`` -- a real number.
+            - ``point`` -- a real number
 
             OUTPUT:
 
@@ -373,7 +377,7 @@ class PiecewiseFunction(BuiltinFunction):
 
         def domains(self, parameters, variable):
             """
-            Return the individual domains
+            Return the individual domains.
 
             See also :meth:`~expressions`.
 
@@ -393,7 +397,7 @@ class PiecewiseFunction(BuiltinFunction):
 
         def domain(self, parameters, variable):
             """
-            Return the domain
+            Return the domain.
 
             OUTPUT:
 
@@ -414,11 +418,9 @@ class PiecewiseFunction(BuiltinFunction):
 
         def __len__(self, parameters, variable):
             """
-            Return the number of "pieces"
+            Return the number of "pieces".
 
-            OUTPUT:
-
-            Integer.
+            OUTPUT: integer
 
             EXAMPLES::
 
@@ -431,13 +433,11 @@ class PiecewiseFunction(BuiltinFunction):
 
         def expressions(self, parameters, variable):
             """
-            Return the individual domains
+            Return the individual domains.
 
             See also :meth:`~domains`.
 
-            OUTPUT:
-
-            The collection of expressions of the component functions.
+            OUTPUT: the collection of expressions of the component functions
 
             EXAMPLES::
 
@@ -450,7 +450,7 @@ class PiecewiseFunction(BuiltinFunction):
 
         def items(self, parameters, variable):
             """
-            Iterate over the pieces of the piecewise function
+            Iterate over the pieces of the piecewise function.
 
             .. NOTE::
 
@@ -476,7 +476,7 @@ class PiecewiseFunction(BuiltinFunction):
 
         def __call__(self, parameters, variable, value=None, **kwds):
             """
-            Call the piecewise function
+            Call the piecewise function.
 
             EXAMPLES::
 
@@ -501,7 +501,7 @@ class PiecewiseFunction(BuiltinFunction):
 
         def _fast_callable_(self, parameters, variable, etb):
             """
-            Override the ``fast_callable``
+            Override the ``fast_callable``.
 
             OUTPUT:
 
@@ -522,7 +522,7 @@ class PiecewiseFunction(BuiltinFunction):
 
         def restriction(self, parameters, variable, restricted_domain):
             """
-            Restrict the domain
+            Restrict the domain.
 
             INPUT:
 
@@ -530,9 +530,7 @@ class PiecewiseFunction(BuiltinFunction):
               :class:`~sage.sets.real_set.RealSet` or something that
               defines one.
 
-            OUTPUT:
-
-            A new piecewise function obtained by restricting the domain.
+            OUTPUT: a new piecewise function obtained by restricting the domain
 
             EXAMPLES::
 
@@ -550,7 +548,7 @@ class PiecewiseFunction(BuiltinFunction):
 
         def extension(self, parameters, variable, extension, extension_domain=None):
             """
-            Extend the function
+            Extend the function.
 
             INPUT:
 
@@ -602,8 +600,10 @@ class PiecewiseFunction(BuiltinFunction):
                 sage: bool(h == f)
                 True
             """
-            result = [(domain, func) for domain,func in parameters
+            result = [(domain, func) for domain, func in parameters
                       if func != 0]
+            if len(result) == len(self):
+                return self
             return piecewise(result, var=variable)
 
         def pieces(self, parameters, variable):
@@ -622,12 +622,10 @@ class PiecewiseFunction(BuiltinFunction):
                 (piecewise(x|-->-x on (-1, 0); x),
                  piecewise(x|-->x on [0, 1]; x))
             """
-            result = []
-            for domain, func in parameters:
-                result.append(piecewise([(domain, func)], var=variable))
-            return tuple(result)
+            return tuple(piecewise([(domain, func)], var=variable)
+                         for domain, func in parameters)
 
-        def end_points(self, parameters, variable):
+        def end_points(self, parameters, variable) -> list:
             """
             Return a list of all interval endpoints for this function.
 
@@ -675,39 +673,40 @@ class PiecewiseFunction(BuiltinFunction):
             funcs = []
             contains_lower = False
             contains_upper = False
-            for i in range(len(points)-1):
+            for i in range(len(points) - 1):
+                a, b = points[i], points[i + 1]
                 try:
-                    contains_lower = (self.domain().contains(points[i]) or
-                        other.domain().contains(points[i])) and not contains_upper
-                    contains_upper = (self.domain().contains(points[i+1]) or
-                        other.domain().contains(points[i+1]))
+                    contains_lower = (self.domain().contains(a) or
+                        other.domain().contains(a)) and not contains_upper
+                    contains_upper = (self.domain().contains(b) or
+                        other.domain().contains(b))
                     if contains_lower:
                         if contains_upper:
-                            rs = RealSet.closed(points[i],points[i+1])
+                            rs = RealSet.closed(a, b)
                         else:
-                            rs = RealSet.closed_open(points[i],points[i+1])
+                            rs = RealSet.closed_open(a, b)
                     else:
                         if contains_upper:
-                            rs = RealSet.open_closed(points[i],points[i+1])
+                            rs = RealSet.open_closed(a, b)
                         else:
-                            rs = RealSet.open(points[i],points[i+1])
-                    point = (points[i+1] + points[i])/2
+                            rs = RealSet.open(a, b)
+                    point = (b + a) / 2
                 except ValueError:
-                    if points[i] == minus_infinity and points[i+1] == infinity:
+                    if a == minus_infinity and b == infinity:
                         rs = RealSet.open(minus_infinity, infinity)
                         point = 0
-                    elif points[i] == minus_infinity:
+                    elif a == minus_infinity:
                         if contains_lower:
-                            rs = RealSet.unbounded_below_closed(points[i+1])
+                            rs = RealSet.unbounded_below_closed(b)
                         else:
-                            rs = RealSet.unbounded_below_open(points[i+1])
-                        point = points[i+1]-1
-                    elif points[i+1] == infinity:
+                            rs = RealSet.unbounded_below_open(b)
+                        point = b - 1
+                    elif b == infinity:
                         if contains_upper:
-                            rs = RealSet.unbounded_above_closed(points[i])
+                            rs = RealSet.unbounded_above_closed(a)
                         else:
-                            rs = RealSet.unbounded_above_open(points[i])
-                        point = points[i]+1
+                            rs = RealSet.unbounded_above_open(a)
+                        point = a + 1
                     else:
                         raise
                 try:
@@ -837,10 +836,11 @@ class PiecewiseFunction(BuiltinFunction):
 
             Check that the algorithm keyword can be used::
 
+                sage: # needs sage.libs.giac
                 sage: ex = piecewise([([0, 1], 1), ((1, oo), 1/x**2)])
-                sage: integral(ex, x, 0, 100, algorithm='giac')
+                sage: integral(ex, x, 0, 100, algorithm='sympy')
                 199/100
-                sage: integral(ex, x, algorithm='giac')
+                sage: integral(ex, x, algorithm='sympy')
                 piecewise(x|-->x on [0, 1], x|-->-1/x + 2 on (1, +oo); x)
             """
             if a is not None and b is not None:
@@ -880,7 +880,7 @@ class PiecewiseFunction(BuiltinFunction):
                     else:
                         try:
                             assume(start < x)
-                        except ValueError: # Assumption is redundant
+                        except ValueError:  # Assumption is redundant
                             pass
                         fun_integrated = fun.integral(x, start, x, **kwds) + area
                         forget(start < x)
@@ -984,6 +984,17 @@ class PiecewiseFunction(BuiltinFunction):
                           x|-->-x + 6 on (3, 4],
                           x|-->-2*x + 10 on (4, 5]; x)
 
+            Some unbounded but convergent cases now work::
+
+                sage: p = piecewise([[(2,oo),exp(-x)]])
+                sage: q = piecewise([[[2,3],x]])
+                sage: p.convolution(q)
+                piecewise(x|-->(x - 3)*e^(-2) - e^(-x + 2) on (4, 5]; x)
+                sage: q.convolution(p)
+                piecewise(x|-->(x - 3)*e^(-2) - e^(-x + 2) on (4, 5]; x)
+
+            TESTS:
+
             Check that the bugs raised in :issue:`12123` are fixed::
 
                 sage: f = piecewise([[(-2, 2), 2]])
@@ -1002,44 +1013,61 @@ class PiecewiseFunction(BuiltinFunction):
             from sage.symbolic.integration.integral import definite_integral
             f = self
             g = other
-            if len(f.end_points())*len(g.end_points()) == 0:
+            if not f.end_points() or not g.end_points():
                 raise ValueError('one of the piecewise functions is nowhere defined')
             fd, f0 = parameters[0]
             gd, g0 = next(other.items())
-            if len(f) == 1 and len(g) == 1:
-                f = f.unextend_zero()
-                g = g.unextend_zero()
+            if len(f) == 1 == len(g):
                 a1 = fd[0].lower()
                 a2 = fd[0].upper()
                 b1 = gd[0].lower()
                 b2 = gd[0].upper()
-                with SR.temp_var() as tt:
-                    with SR.temp_var() as uu:
-                        i1 = f0.subs({variable: uu})
-                        i2 = g0.subs({variable: tt-uu})
-                        fg1 = definite_integral(i1*i2, uu, a1, tt-b1).subs({tt:variable})
-                        fg2 = definite_integral(i1*i2, uu, tt-b2, tt-b1).subs({tt:variable})
-                        fg3 = definite_integral(i1*i2, uu, tt-b2, a2).subs({tt:variable})
-                        fg4 = definite_integral(i1*i2, uu, a1, a2).subs({tt:variable})
-                if a1-b1 < a2-b2:
-                    if a2+b1 != a1+b2:
-                        h = piecewise([[(a1+b1,a1+b2),fg1],[(a1+b2,a2+b1),fg2],[(a2+b1,a2+b2),fg3]])
-                    else:
-                        h = piecewise([[(a1+b1,a1+b2),fg1],[(a1+b2,a2+b2),fg3]])
-                else:
-                    if a1+b2 != a2+b1:
-                        h = piecewise([[(a1+b1,a2+b1),fg1],[(a2+b1,a1+b2),fg4],[(a1+b2,a2+b2),fg3]])
-                    else:
-                        h = piecewise([[(a1+b1,a2+b1),fg1],[(a2+b1,a2+b2),fg3]])
-                return (piecewise([[(minus_infinity,infinity),0]]).piecewise_add(h)).unextend_zero()
+                a1b1 = a1 + b1
+                a2b2 = a2 + b2
+                delta_a = a2 - a1
+                delta_b = b2 - b1
 
-            if len(f) > 1 or len(g) > 1:
-                z = piecewise([[(0,0),0]])
-                for fpiece in f.pieces():
-                    for gpiece in g.pieces():
-                        h = gpiece.convolution(fpiece)
-                        z = z.piecewise_add(h)
-                return z.unextend_zero()
+                # this fails in some unbounded cases:
+                a1b2 = a1 + b2
+                a2b1 = a2 + b1
+
+                todo = []
+                if delta_a > delta_b:
+                    if a1b2 is not minus_infinity:
+                        todo.append((a1b1, a1b2, a1, variable - b1))
+                    todo.append((a1b2, a2b1, variable - b2, variable - b1))
+                    if a2b1 is not infinity:
+                        todo.append((a2b1, a2b2, variable - b2, a2))
+                elif delta_a < delta_b:
+                    if a2b1 is not minus_infinity:
+                        todo.append((a1b1, a2b1, a1, variable - b1))
+                    todo.append((a2b1, a1b2, a1, a2))
+                    if a1b2 is not infinity:
+                        todo.append((a1b2, a2b2, variable - b2, a2))
+                else:
+                    if a2b1 is not minus_infinity:
+                        todo.append((a1b1, a2b1, a1, variable - b1))
+                        todo.append((a2b1, a2b2, variable - b2, a2))
+
+                if not todo:
+                    raise ValueError("no domain of integration")
+
+                with SR.temp_var() as uu:
+                    i1 = f0.subs({variable: uu})
+                    i2 = g0.subs({variable: variable - uu})
+                    expr = i1 * i2
+                    h = piecewise([[(start, stop),
+                                    definite_integral(expr, uu, mini, maxi)]
+                                   for start, stop, mini, maxi in todo])
+                flat_zero = piecewise([[(minus_infinity, infinity), 0]])
+                return (flat_zero.piecewise_add(h)).unextend_zero()  # why ?
+
+            z = piecewise([[(0, 0), 0]])
+            for fpiece in f.pieces():
+                for gpiece in g.pieces():
+                    h = gpiece.convolution(fpiece)
+                    z = z.piecewise_add(h)
+            return z.unextend_zero()
 
         def trapezoid(self, parameters, variable, N):
             """
@@ -1079,8 +1107,8 @@ class PiecewiseFunction(BuiltinFunction):
             """
             def func(x0, x1):
                 f0, f1 = self(x0), self(x1)
-                return [[(x0,x1), f0 + (f1-f0) * (x1-x0)**(-1)
-                    * (self.default_variable()-x0)]]
+                return [[(x0, x1), f0 + (f1-f0) * (x1-x0)**(-1)
+                         * (self.default_variable()-x0)]]
             rsum = []
             for domain, f in parameters:
                 for interval in domain:
@@ -1100,9 +1128,9 @@ class PiecewiseFunction(BuiltinFunction):
 
             INPUT:
 
-            -  ``x`` -- variable of ``self``
+            - ``x`` -- variable of ``self``
 
-            -  ``s`` -- variable of Laplace transform.
+            - ``s`` -- variable of Laplace transform
 
             We assume that a piecewise function is 0 outside of its domain and
             that the left-most endpoint of the domain is 0.
@@ -1134,17 +1162,17 @@ class PiecewiseFunction(BuiltinFunction):
                 (s + 1)*e^(-s)/s^2 + 2*e^(-s)/s - 1/s^2
             """
             from sage.symbolic.assumptions import assume, forget
-            from sage.functions.log import exp
 
             x = SR.var(x)
             s = SR.var(s)
             assume(s > 0)
+            exp_sx = (-s * x).exp()
             result = 0
             for domain, f in parameters:
                 for interval in domain:
                     a = interval.lower()
                     b = interval.upper()
-                    result += (SR(f)*exp(-s*x)).integral(x,a,b)
+                    result += (SR(f) * exp_sx).integral(x, a, b)
             forget(s > 0)
             return result
 
@@ -1171,15 +1199,13 @@ class PiecewiseFunction(BuiltinFunction):
 
             INPUT:
 
-            - ``n`` -- a non-negative integer
+            - ``n`` -- nonnegative integer
 
             - ``L`` -- (default: ``None``) the half-period of `f`; if none
               is provided, `L` is assumed to be the half-width of the domain
               of ``self``
 
-            OUTPUT:
-
-            - the Fourier coefficient `a_n`, as defined above
+            OUTPUT: the Fourier coefficient `a_n`, as defined above
 
             EXAMPLES:
 
@@ -1224,7 +1250,6 @@ class PiecewiseFunction(BuiltinFunction):
                 sage: f = piecewise([[(-pi, pi/2), f1], [(pi/2, pi), f2]])
                 sage: f.fourier_series_cosine_coefficient(5, pi)
                 -3/5/pi
-
             """
             from sage.functions.trig import cos
             from sage.symbolic.constants import pi
@@ -1243,7 +1268,7 @@ class PiecewiseFunction(BuiltinFunction):
                     a = interval.lower()
                     b = interval.upper()
                     result += (f*cos(pi*variable*n/L)).integrate(variable, a, b)
-            return SR(result/L0).simplify_trig()
+            return SR(result / L0).simplify_trig()
 
         def fourier_series_sine_coefficient(self, parameters, variable,
                                             n, L=None):
@@ -1266,15 +1291,13 @@ class PiecewiseFunction(BuiltinFunction):
 
             INPUT:
 
-            - ``n`` -- a non-negative integer
+            - ``n`` -- nonnegative integer
 
             - ``L`` -- (default: ``None``) the half-period of `f`; if none
               is provided, `L` is assumed to be the half-width of the domain
               of ``self``
 
-            OUTPUT:
-
-            - the Fourier coefficient `b_n`, as defined above
+            OUTPUT: the Fourier coefficient `b_n`, as defined above
 
             EXAMPLES:
 
@@ -1315,7 +1338,6 @@ class PiecewiseFunction(BuiltinFunction):
                 4/pi
                 sage: f2.fourier_series_sine_coefficient(6)
                 4/3/pi
-
             """
             from sage.functions.trig import sin
             from sage.symbolic.constants import pi
@@ -1339,7 +1361,7 @@ class PiecewiseFunction(BuiltinFunction):
         def fourier_series_partial_sum(self, parameters, variable, N,
                                        L=None):
             r"""
-            Returns the partial sum up to a given order of the Fourier series
+            Return the partial sum up to a given order of the Fourier series
             of the periodic function `f` extending the piecewise-defined
             function ``self``.
 
@@ -1359,7 +1381,7 @@ class PiecewiseFunction(BuiltinFunction):
 
             INPUT:
 
-            - ``N`` -- a positive integer; the order of the partial sum
+            - ``N`` -- positive integer; the order of the partial sum
 
             - ``L`` -- (default: ``None``) the half-period of `f`; if none
               is provided, `L` is assumed to be the half-width of the domain
@@ -1404,7 +1426,6 @@ class PiecewiseFunction(BuiltinFunction):
                 sage: f.fourier_series_partial_sum(5)
                 -2*cos(2*pi*x)/pi^2 + 4/25*sin(5*pi*x)/pi^2
                  - 4/9*sin(3*pi*x)/pi^2 + 4*sin(pi*x)/pi^2 + 1/4
-
             """
             from sage.symbolic.constants import pi
             from sage.functions.trig import cos, sin
@@ -1451,16 +1472,18 @@ class PiecewiseFunction(BuiltinFunction):
 
             EXAMPLES::
 
+                sage: # needs giac
                 sage: ex = piecewise([((0, 1), pi), ([1, 2], x)])
-                sage: f = ex._giac_(); f                                                # needs sage.libs.giac
+                sage: f = ex._giac_(); f
                 piecewise(((sageVARx>0) and (1>sageVARx)),pi,((sageVARx>=1) and (2>=sageVARx)),sageVARx)
-                sage: f.diff(x)                                                         # needs sage.libs.giac
+                sage: f.diff(x)
                 piecewise(((sageVARx>0) and (1>sageVARx)),0,((sageVARx>=1) and (2>=sageVARx)),1)
 
-                sage: ex = piecewise([((-100, -2), 1/x), ((1, +oo), cos(x))])           # needs sage.libs.giac
-                sage: g = ex._giac_(); g                                                # needs sage.libs.giac
+                sage: # needs giac
+                sage: ex = piecewise([((-100, -2), 1/x), ((1, +oo), cos(x))])
+                sage: g = ex._giac_(); g
                 piecewise(((sageVARx>-100) and ((-2)>sageVARx)),1/sageVARx,sageVARx>1,cos(sageVARx))
-                sage: g.diff(x)                                                         # needs sage.libs.giac
+                sage: g.diff(x)
                 piecewise(((sageVARx>-100) and ((-2)>sageVARx)),-1/sageVARx^2,sageVARx>1,-sin(sageVARx))
 
             TESTS::
