@@ -61,7 +61,7 @@ class AbstractArgument(MultiplicativeGroupElement):
 
     - ``element`` -- an element of parent's base
 
-    - ``normalize`` -- a boolean (default: ``True``)
+    - ``normalize`` -- boolean (default: ``True``)
     """
 
     def __init__(self, parent, element, normalize=True):
@@ -108,7 +108,7 @@ class AbstractArgument(MultiplicativeGroupElement):
     @staticmethod
     def _normalize_(element):
         r"""
-        Normalizes the given element.
+        Normalize the given element.
 
         INPUT:
 
@@ -396,13 +396,13 @@ class UnitCirclePoint(AbstractArgument):
 
     - ``exponent`` -- a number (of a subset of the reals)
 
-    - ``normalize`` -- a boolean (default: ``True``)
+    - ``normalize`` -- boolean (default: ``True``)
     """
 
     @staticmethod
     def _normalize_(exponent):
         r"""
-        Normalizes the given exponent so that it is in `[0,1)`.
+        Normalize the given exponent so that it is in `[0,1)`.
 
         INPUT:
 
@@ -1006,7 +1006,7 @@ class RootsOfUnityGroup(UnitCircleGroup):
             Rational Field
         """
         from sage.rings.rational_field import QQ
-        return super().__init__(base=QQ, category=category)
+        super().__init__(base=QQ, category=category)
 
     def _repr_(self):
         r"""
@@ -1043,7 +1043,7 @@ class ArgumentByElement(AbstractArgument):
 
     - ``element`` -- a nonzero element of the parent's base
 
-    - ``normalize`` -- a boolean (default: ``True``)
+    - ``normalize`` -- boolean (default: ``True``)
     """
 
     def __init__(self, parent, element, normalize=True):
@@ -1064,7 +1064,7 @@ class ArgumentByElement(AbstractArgument):
     @staticmethod
     def _normalize_(element):
         r"""
-        Normalizes the given element.
+        Normalize the given element.
 
         This is the identity for :class:`ArgumentByElement`.
 
@@ -1380,7 +1380,7 @@ class Sign(AbstractArgument):
 
     - ``element`` -- a nonzero element of the parent's base
 
-    - ``normalize`` -- a boolean (default: ``True``)
+    - ``normalize`` -- boolean (default: ``True``)
     """
 
     def __init__(self, parent, element, normalize=True):
@@ -1402,7 +1402,7 @@ class Sign(AbstractArgument):
     @staticmethod
     def _normalize_(element):
         r"""
-        Normalizes the given element.
+        Normalize the given element.
 
         This is the identity for :class:`Sign`.
 
@@ -1461,9 +1461,22 @@ class Sign(AbstractArgument):
             1
             sage: S(-1)^3  # indirect doctest
             -1
+
+        Check that the results may live in other parents too::
+
+            sage: x = SR.var('x')
+            sage: elem = S(-1)^x; elem  # indirect doctest
+            (-1)^x
+            sage: elem.parent()
+            Symbolic Ring
+
         """
+        result = self._element_ ** exponent
         P = self.parent()
-        return P.element_class(P, self._element_ ** exponent)
+        try:
+            return P.element_class(P, result)
+        except (ValueError, TypeError):
+            return result
 
     def __invert__(self):
         r"""
@@ -1613,7 +1626,7 @@ class SignGroup(AbstractArgumentGroup):
             sage: S.base()  # indirect doctest
             <class 'int'>
         """
-        return super().__init__(base=int, category=category)
+        super().__init__(base=int, category=category)
 
     def _repr_(self):
         r"""
@@ -1697,7 +1710,7 @@ class ArgumentGroupFactory(UniqueFactory):
       The factory will analyze ``data`` and interpret it as
       ``specification`` or ``domain``.
 
-    - ``specification`` -- a string
+    - ``specification`` -- string
 
       The following is possible:
 
@@ -1713,12 +1726,12 @@ class ArgumentGroupFactory(UniqueFactory):
         a string representing a SageMath parent which is interpreted as
         ``domain``
 
-    - ``domain`` -- a SageMath parent representing a subset of the complex plane.
-      An instance of :class:`ArgumentByElementGroup` will be created with the given
-      ``domain``.
+    - ``domain`` -- a SageMath parent representing a subset of the complex plane;
+      an instance of :class:`ArgumentByElementGroup` will be created with the given
+      ``domain``
 
-    - ``exponents`` -- a SageMath parent representing a subset of the reals.
-      An instance of :class`UnitCircleGroup` will be created with the given
+    - ``exponents`` -- a SageMath parent representing a subset of the reals;
+      an instance of :class`UnitCircleGroup` will be created with the given
       ``exponents``
 
     Exactly one of ``data``, ``specification``, ``exponents`` has to be provided.
