@@ -817,8 +817,8 @@ class InterfaceElement(Element):
             sage: S = singular.ring(0, ('x'))
             sage: loads(dumps(S))
             polynomial ring, over a field, global ordering
-            //   coefficients: QQ
-            //   number of vars : 1
+            // coefficients: QQ...
+            // number of vars : 1
             //        block   1 : ordering lp
             //                  : names    x
             //        block   2 : ordering C
@@ -880,7 +880,7 @@ class InterfaceElement(Element):
 
         Special care has to be taken with strings. Since for example `r("abc")` will be
         interpreted as the R-command abc (not a string in R), we have to reduce to
-        `"'abc'"` instead. That is dependant on the Elements `is_string` function to
+        `"'abc'"` instead. That is dependant on the Elements ``is_string`` function to
         be implemented correctly. This has gone wrong in the past and remained uncaught
         by the doctests because the original identifier was reused. This test makes sure
         that does not happen again::
