@@ -50,7 +50,7 @@ AUTHORS:
 #                  https://www.gnu.org/licenses/
 #
 ##########################################################################
-
+import os
 import random
 
 from .expect import Expect, ExpectElement, ExpectFunction, FunctionElement, gc_disabled
@@ -82,7 +82,7 @@ class Lisp(Expect):
                         prompt='> ',
 
                         # This is the command that starts up your program
-                        command="ecl",
+                        command='ecl',
 
                         server=server,
                         server_tmpdir=server_tmpdir,
@@ -124,10 +124,10 @@ class Lisp(Expect):
             self._synchronize()
             code = str(code)
             code = code.strip()
-            code = code.replace('\n',' ')
+            code = code.replace('\n', ' ')
             x = []
             for L in code.split('\n'):
-                if L != '':
+                if L:
                     try:
                         s = self.__in_seq + 1
                         M = self._eval_line(L, wait_for_prompt=self._prompt)
@@ -136,14 +136,14 @@ class Lisp(Expect):
                         x.append(M.strip())
                         self.__in_seq = s
                     except TypeError as s:
-                        return 'error evaluating "%s":\n%s'%(code,s)
+                        return 'error evaluating "%s":\n%s' % (code, s)
             return '\n'.join(x)
 
-    def _an_element_impl(self):
+    def _an_element_(self):
         """
         EXAMPLES::
 
-            sage: lisp._an_element_impl()
+            sage: lisp._an_element_()
             0
         """
         return self(0)
@@ -165,10 +165,10 @@ class Lisp(Expect):
             sage: lisp.eval('x')
             '2'
         """
-        cmd = '(setq %s %s)'%(var, value)
+        cmd = '(setq %s %s)' % (var, value)
         out = self.eval(cmd)
         if '***' in out:
-            raise TypeError("Error executing code in Sage\nCODE:\n\t%s\nSAGE ERROR:\n\t%s"%(cmd, out))
+            raise TypeError("Error executing code in Sage\nCODE:\n\t%s\nSAGE ERROR:\n\t%s" % (cmd, out))
 
     def get(self, var):
         """
@@ -201,8 +201,8 @@ class Lisp(Expect):
             self._start()
             E = self._expect
         r = random.randrange(2147483647)
-        s = str(r+1)
-        cmd = "(+ 1 %s)"%r
+        s = str(r + 1)
+        cmd = "(+ 1 %s)" % r
         E.sendline(cmd)
         E.expect(s)
         E.expect(self._prompt)
@@ -231,7 +231,7 @@ class Lisp(Expect):
 
             sage: lisp._function_class()
             <class 'sage.interfaces.lisp.LispFunction'>
-         """
+        """
         return LispFunction
 
     def _quit_string(self):
@@ -291,7 +291,7 @@ class Lisp(Expect):
 
     def version(self):
         """
-        Returns the version of Lisp being used.
+        Return the version of Lisp being used.
 
         EXAMPLES::
 
@@ -342,9 +342,9 @@ class Lisp(Expect):
 
     def _equality_symbol(self):
         """
-        We raise a NotImplementedError when _equality_symbol is called since
-        equality testing in Lisp does not use infix notation and cannot be
-        done the same way as in the other interfaces.
+        We raise a :exc:`NotImplementedError` when ``_equality_symbol`` is
+        called since equality testing in Lisp does not use infix notation and
+        cannot be done the same way as in the other interfaces.
 
         EXAMPLES::
 
@@ -354,7 +354,7 @@ class Lisp(Expect):
             NotImplementedError: ...
         """
         raise NotImplementedError("We should never reach here in the Lisp interface. " +
-                                    "Please report this as a bug.")
+                                  "Please report this as a bug.")
 
     def help(self, command):
         """
@@ -369,8 +369,8 @@ class Lisp(Expect):
 
     def function_call(self, function, args=None, kwds=None):
         """
-        Calls the Lisp function with given args and kwds.
-        For Lisp functions, the kwds are ignored.
+        Call the Lisp function with given ``args`` and ``kwds``.
+        For Lisp functions, the ``kwds`` are ignored.
 
         EXAMPLES::
 
@@ -404,15 +404,14 @@ class LispElement(RingElement, ExpectElement):
             False
             sage: two == 2
             True
-
         """
         P = self._check_valid()
         if parent(other) is not P:
             other = P(other)
 
-        if P.eval('(= %s %s)'%(self.name(), other.name())) == P._true_symbol():
+        if P.eval('(= %s %s)' % (self.name(), other.name())) == P._true_symbol():
             return rich_to_bool(op, 0)
-        elif P.eval('(< %s %s)'%(self.name(), other.name())) == P._true_symbol():
+        elif P.eval('(< %s %s)' % (self.name(), other.name())) == P._true_symbol():
             return rich_to_bool(op, -1)
         else:
             return rich_to_bool(op, 1)
@@ -454,7 +453,7 @@ class LispElement(RingElement, ExpectElement):
             -1
         """
         P = self._check_valid()
-        return P.new('(- %s %s)'%(self._name, right._name))
+        return P.new('(- %s %s)' % (self._name, right._name))
 
     def _mul_(self, right):
         """
@@ -465,7 +464,7 @@ class LispElement(RingElement, ExpectElement):
             2
         """
         P = self._check_valid()
-        return P.new('(* %s %s)'%(self._name, right._name))
+        return P.new('(* %s %s)' % (self._name, right._name))
 
     def _div_(self, right):
         """
@@ -476,7 +475,7 @@ class LispElement(RingElement, ExpectElement):
             1/2
         """
         P = self._check_valid()
-        return P.new('(/ %s %s)'%(self._name, right._name))
+        return P.new('(/ %s %s)' % (self._name, right._name))
 
     def __pow__(self, n):
         """
@@ -537,9 +536,11 @@ def is_LispElement(x):
 
     return isinstance(x, LispElement)
 
+
 # An instance
 lisp = Lisp()
 
+
 def reduce_load_Lisp():
     """
     EXAMPLES::
@@ -550,7 +551,7 @@ def reduce_load_Lisp():
     """
     return lisp
 
-import os
+
 def lisp_console():
     """
     Spawn a new Lisp command-line session.
