@@ -35,7 +35,7 @@ directly, but falls back to the string based conversion used by the
 classical Maxima Pexpect interface in case no new implementation has been made.
 
 This interface is the one used for calculus by Sage
-and is accessible as `maxima_calculus`::
+and is accessible as ``maxima_calculus``::
 
     sage: maxima_calculus
     Maxima_lib
@@ -80,8 +80,8 @@ The output is parseable (i. e. :issue:`31796` is fixed)::
 TESTS:
 
 Check our workaround for a race in ecl works, see :issue:`26968`.
-We use a temporary `MAXIMA_USERDIR` so it's empty; we place it
-in `DOT_SAGE` since we expect it to have more latency than `/tmp`.
+We use a temporary ``MAXIMA_USERDIR`` so it's empty; we place it
+in ``DOT_SAGE`` since we expect it to have more latency than ``/tmp``.
 
     sage: import tempfile, subprocess
     sage: tmpdir = tempfile.TemporaryDirectory(dir=DOT_SAGE)
