@@ -1,3 +1,4 @@
+# sage.doctest: optional - scipy
 r"""
 Helper functions for plotting the geometric representation of matroids
 
@@ -19,8 +20,9 @@ AUTHORS:
     via an optimization that gives aesthetically pleasing point placement (in
     some sense. This is not yet implemented).    One can then use
     ``createline`` function to produce sequence of ``100`` points on a smooth
-    curve containing the points in the specified line which inturn uses
-    ``scipy.interpolate.splprep`` and ``scipy.interpolate.splev``.  Then one
+    curve containing the points in the specified line which in turn uses
+    :func:`scipy:scipy.interpolate.splprep` and
+    :func:`scipy:scipy.interpolate.splev`.  Then one
     can use sage's graphics primitives ``line``, ``point``, ``text`` and
     ``points`` to produce graphics object containing points (ground set
     elements) and lines (for a rank 3 matroid, these are flats of rank 2 of
@@ -40,7 +42,6 @@ AUTHORS:
                              'plot_lineorders':<list of lists>}
 
 
-
 REFERENCES
 ==========
 
@@ -50,15 +51,15 @@ REFERENCES
 EXAMPLES::
 
     sage: from sage.matroids import matroids_plot_helpers
-    sage: M1=Matroid(ring=GF(2), matrix=[[1, 0, 0, 0, 1, 1, 1,0,1,0,1],
-    ....: [0, 1, 0, 1, 0, 1, 1,0,0,1,0], [0, 0, 1, 1, 1, 0, 1,0,0,0,0]])
-    sage: pos_dict= {0: (0, 0),  1: (2, 0),  2: (1, 2),  3: (1.5, 1.0),
-    ....: 4: (0.5, 1.0),  5: (1.0, 0.0), 6: (1.0, 0.666666666666667),
-    ....: 7: (3,3), 8: (4,0), 9: (-1,1), 10: (-2,-2)}
-    sage: M1._cached_info={'plot_positions': pos_dict, 'plot_lineorders': None}
-    sage: matroids_plot_helpers.geomrep(M1, sp=True)
+    sage: M1 = Matroid(ring=GF(2), matrix=[[1, 0, 0, 0, 1, 1, 1,0,1,0,1],
+    ....:                                  [0, 1, 0, 1, 0, 1, 1,0,0,1,0],
+    ....:                                  [0, 0, 1, 1, 1, 0, 1,0,0,0,0]])
+    sage: pos_dict = {0: (0, 0),  1: (2, 0),  2: (1, 2),  3: (1.5, 1.0),
+    ....:             4: (0.5, 1.0),  5: (1.0, 0.0), 6: (1.0, 0.666666666666667),
+    ....:             7: (3,3), 8: (4,0), 9: (-1,1), 10: (-2,-2)}
+    sage: M1._cached_info = {'plot_positions': pos_dict, 'plot_lineorders': None}
+    sage: matroids_plot_helpers.geomrep(M1, sp=True)                                    # needs sage.plot sage.rings.finite_rings
     Graphics object consisting of 22 graphics primitives
-
 """
 # *****************************************************************************
 #       Copyright (C) 2013 Jayant Apte <jayant91089@gmail.com>
@@ -87,24 +88,21 @@ def it(M, B1, nB1, lps):
 
     INPUT:
 
-    - ``M`` -- A matroid.
-    - ``B1``-- A list of groundset elements of ``M`` that corresponds to a
-      basis of matroid ``M``.
-    - ``nB1``-- A list of elements in the ground set of M that corresponds to
-      ``M.simplify.groundset() \ B1``.
-    - ``lps``-- A list of elements in the ground set of matroid M that are
-      loops.
+    - ``M`` -- matroid
+    - ``B1`` -- list of groundset elements of ``M`` that corresponds to a
+      basis of matroid ``M``
+    - ``nB1`` -- list of elements in the ground set of M that corresponds to
+      ``M.simplify.groundset() \ B1``
+    - ``lps`` -- list of elements in the ground set of matroid M that are loops
 
-    OUTPUT:
-
-    A tuple containing 4 elements in this order:
+    OUTPUT: a tuple containing 4 elements in this order:
 
     1. A dictionary containing 2-tuple (x,y) coordinates with
        ``M.simplify.groundset()`` elements that can be placed on the sides of
        the triangle as keys.
     2. A list of 3 lists of elements of ``M.simplify.groundset()`` that can
        be placed on the 3 sides of the triangle.
-    3. A list of elements of `M.simplify.groundset()`` that cane be placed
+    3. A list of elements of ``M.simplify.groundset()`` that cane be placed
        inside the triangle in the geometric representation.
     4. A list of lists of elements of ``M.simplify.groundset()`` that
        correspond to lines in the geometric representation other than the sides
@@ -170,11 +168,13 @@ def it(M, B1, nB1, lps):
             # loop over L1,L2,L3
             cc = interval*j
             pts[i[j-1]] = (cc*pt1[0]+(1-cc)*pt2[0], cc*pt1[1]+(1-cc)*pt2[1])
-    trilines = [list(set(x)) for x in lines if len(x) >= 3]
-    curvedlines = [list(set(list(x)).difference(set(lps)))
-                   for x in M.flats(2) if set(list(x)) not in trilines if
-                   len(list(x)) >= 3]
-    nontripts = [i for i in nB1 if i not in pts.keys()]
+    trilines = [set(x) for x in lines if len(x) >= 3]
+    set_lps = set(lps)
+    curvedlines = [list(sx.difference(set_lps))
+                   for x in M.flats(2) if (sx := set(x)) not in trilines
+                   and len(list(x)) >= 3]
+    nontripts = [i for i in nB1 if i not in pts]
+    trilines = [list(s) for s in trilines]
     return pts, trilines, nontripts, curvedlines
 
 
@@ -184,12 +184,10 @@ def trigrid(tripts):
 
     INPUT:
 
-    - ``tripts`` -- A list of 3 lists of the form [x,y] where x and y are the
-      Cartesian coordinates of a point.
+    - ``tripts`` -- list of 3 lists of the form [x,y] where x and y are the
+      Cartesian coordinates of a point
 
-    OUTPUT:
-
-    A list of lists containing 4 points in following order:
+    OUTPUT: list of lists containing 4 points in following order:
 
     - 1. Barycenter of 3 input points.
     - 2,3,4. Barycenters of 1. with 3 different 2-subsets of input points
@@ -208,15 +206,14 @@ def trigrid(tripts):
     .. NOTE::
 
             This method does NOT do any checks.
-
     """
     pairs = [[0, 1], [1, 2], [0, 2]]
-    cpt = list((float(tripts[0][0]+tripts[1][0]+tripts[2][0])/3,
-               float(tripts[0][1]+tripts[1][1]+tripts[2][1])/3))
+    cpt = [float(tripts[0][0] + tripts[1][0] + tripts[2][0]) / 3,
+           float(tripts[0][1] + tripts[1][1] + tripts[2][1]) / 3]
     grid = [cpt]
-    for p in pairs:
-        pt = list((float(tripts[p[0]][0]+tripts[p[1]][0]+cpt[0])/3,
-                  float(tripts[p[0]][1]+tripts[p[1]][1]+cpt[1])/3))
+    for p, q in pairs:
+        pt = [float(tripts[p][0] + tripts[q][0] + cpt[0]) / 3,
+              float(tripts[p][1] + tripts[q][1] + cpt[1]) / 3]
         grid.append(pt)
     return grid
 
@@ -228,12 +225,12 @@ def addnontripts(tripts_labels, nontripts_labels, ptsdict):
 
     INPUT:
 
-    - ``tripts`` -- A list of 3 ground set elements that are to be placed on
-      vertices of the triangle.
-    - ``ptsdict`` -- A dictionary (at least) containing ground set elements in
-      ``tripts`` as keys and their (x,y) position as values.
-    - ``nontripts``-- A list of ground set elements whose corresponding points
-      are to be placed inside the triangle.
+    - ``tripts`` -- list of 3 ground set elements that are to be placed on
+      vertices of the triangle
+    - ``ptsdict`` -- dictionary (at least) containing ground set elements in
+      ``tripts`` as keys and their (x,y) position as values
+    - ``nontripts`` -- list of ground set elements whose corresponding points
+      are to be placed inside the triangle
 
     OUTPUT:
 
@@ -264,7 +261,6 @@ def addnontripts(tripts_labels, nontripts_labels, ptsdict):
     .. NOTE::
 
             This method does NOT do any checks.
-
     """
     tripts = [list(ptsdict[p]) for p in tripts_labels]
     pairs = [[0, 1], [1, 2], [0, 2]]
@@ -296,18 +292,16 @@ def createline(ptsdict, ll, lineorders2=None):
 
     INPUT:
 
-    - ``ptsdict`` -- A dictionary containing keys and their (x,y) position as
-      values.
-    - ``ll`` -- A list of keys in ``ptsdict`` through which a line is to be
-      drawn.
-    - ``lineorders2``-- (optional) A list of ordered lists of keys in
+    - ``ptsdict`` -- dictionary containing keys and their (x,y) position as
+      values
+    - ``ll`` -- list of keys in ``ptsdict`` through which a line is to be
+      drawn
+    - ``lineorders2`` -- (optional) list of ordered lists of keys in
       ``ptsdict`` such that if ll is setwise same as any of these then points
       corresponding to values of the keys will be traversed in that order thus
-      overriding internal order deciding heuristic.
+      overriding internal order deciding heuristic
 
-    OUTPUT:
-
-    A tuple containing 4 elements in this order:
+    OUTPUT: a tuple containing 4 elements in this order:
 
     1. Ordered list of x-coordinates of values of keys in ``ll`` specified in
        ptsdict.
@@ -321,27 +315,26 @@ def createline(ptsdict, ll, lineorders2=None):
     EXAMPLES::
 
         sage: from sage.matroids import matroids_plot_helpers
-        sage: ptsdict={'a':(1,3),'b':(2,1),'c':(4,5),'d':(5,2)}
-        sage: x,y,x_i,y_i=matroids_plot_helpers.createline(ptsdict,
+        sage: ptsdict = {'a':(1,3),'b':(2,1),'c':(4,5),'d':(5,2)}
+        sage: x,y,x_i,y_i = matroids_plot_helpers.createline(ptsdict,
         ....: ['a','b','c','d'])
         sage: [len(x), len(y), len(x_i), len(y_i)]
         [4, 4, 100, 100]
-        sage: G = line(zip(x_i, y_i),color='black',thickness=3,zorder=1)
-        sage: G+=points(zip(x, y), color='black', size=300,zorder=2)
-        sage: G.show()
-        sage: x,y,x_i,y_i=matroids_plot_helpers.createline(ptsdict,
+        sage: G = line(zip(x_i, y_i), color='black', thickness=3, zorder=1)             # needs sage.plot
+        sage: G += points(zip(x, y), color='black', size=300, zorder=2)                 # needs sage.plot
+        sage: G.show()                                                                  # needs sage.plot
+        sage: x,y,x_i,y_i = matroids_plot_helpers.createline(ptsdict,
         ....: ['a','b','c','d'],lineorders2=[['b','a','c','d'],
         ....: ['p','q','r','s']])
         sage: [len(x), len(y), len(x_i), len(y_i)]
         [4, 4, 100, 100]
-        sage: G = line(zip(x_i, y_i),color='black',thickness=3,zorder=1)
-        sage: G+=points(zip(x, y), color='black', size=300,zorder=2)
-        sage: G.show()
+        sage: G = line(zip(x_i, y_i), color='black', thickness=3, zorder=1)             # needs sage.plot
+        sage: G += points(zip(x, y), color='black', size=300, zorder=2)                 # needs sage.plot
+        sage: G.show()                                                                  # needs sage.plot
 
     .. NOTE::
 
             This method does NOT do any checks.
-
     """
     x, lo = line_hasorder(ll, lineorders2)
     flip = False
@@ -380,17 +373,15 @@ def slp(M1, pos_dict=None, B=None):
 
     INPUT:
 
-    - ``M1`` -- A matroid.
-    - ``pos_dict`` -- (optional) A dictionary containing non loopy elements of
-      ``M`` as keys and their (x,y) positions.
-      as keys. While simplifying the matroid, all except one element in a
-      parallel class that is also specified in ``pos_dict`` will be retained.
-    - ``B`` -- (optional) A basis of M1 that has been chosen for placement on
-      vertices of triangle.
+    - ``M1`` -- matroid
+    - ``pos_dict`` -- (optional) dictionary containing non loopy elements of
+      ``M`` as keys and their (x,y) positions as keys. While simplifying the
+      matroid, all except one element in a parallel class that is also
+      specified in ``pos_dict`` will be retained.
+    - ``B`` -- (optional) a basis of M1 that has been chosen for placement on
+      vertices of triangle
 
-    OUTPUT:
-
-    A tuple containing 3 elements in this order:
+    OUTPUT: a tuple containing 3 elements in this order:
 
     1. Simple matroid corresponding to ``M1``.
     2. Loops of matroid ``M1``.
@@ -401,27 +392,28 @@ def slp(M1, pos_dict=None, B=None):
 
         sage: from sage.matroids import matroids_plot_helpers
         sage: from sage.matroids.advanced import setprint
-        sage: M1=Matroid(ring=GF(2), matrix=[[1, 0, 0, 0, 1, 1, 1,0,1,0,1],
-        ....: [0, 1, 0, 1, 0, 1, 1,0,0,1,0],[0, 0, 1, 1, 1, 0, 1,0,0,0,0]])
-        sage: [M,L,P]=matroids_plot_helpers.slp(M1)
-        sage: M.is_simple()
+        sage: M1 = Matroid(ring=GF(2), matrix=[[1, 0, 0, 0, 1, 1, 1,0,1,0,1],
+        ....:                                  [0, 1, 0, 1, 0, 1, 1,0,0,1,0],
+        ....:                                  [0, 0, 1, 1, 1, 0, 1,0,0,0,0]])
+        sage: [M,L,P] = matroids_plot_helpers.slp(M1)                                   # needs sage.rings.finite_rings
+        sage: M.is_simple()                                                             # needs sage.rings.finite_rings
         True
-        sage: setprint([L,P])
+        sage: setprint([L,P])                                                           # needs sage.rings.finite_rings
         [{10, 8, 9}, {7}]
-        sage: M1=Matroid(ring=GF(2), matrix=[[1, 0, 0, 0, 1, 1, 1,0,1,0,1],
-        ....: [0, 1, 0, 1, 0, 1, 1,0,0,1,0],[0, 0, 1, 1, 1, 0, 1,0,0,0,0]])
-        sage: posdict= {8: (0, 0),  1: (2, 0),  2: (1, 2),  3: (1.5, 1.0),
-        ....: 4: (0.5, 1.0),  5: (1.0, 0.0), 6: (1.0, 0.6666666666666666)}
-        sage: [M,L,P]=matroids_plot_helpers.slp(M1,pos_dict=posdict)
-        sage: M.is_simple()
+        sage: M1 = Matroid(ring=GF(2), matrix=[[1, 0, 0, 0, 1, 1, 1,0,1,0,1],
+        ....:                                  [0, 1, 0, 1, 0, 1, 1,0,0,1,0],
+        ....:                                  [0, 0, 1, 1, 1, 0, 1,0,0,0,0]])
+        sage: posdict = {8: (0, 0),  1: (2, 0),  2: (1, 2),  3: (1.5, 1.0),
+        ....:            4: (0.5, 1.0),  5: (1.0, 0.0), 6: (1.0, 0.6666666666666666)}
+        sage: [M,L,P] = matroids_plot_helpers.slp(M1, pos_dict=posdict)                 # needs sage.rings.finite_rings
+        sage: M.is_simple()                                                             # needs sage.rings.finite_rings
         True
-        sage: setprint([L,P])
+        sage: setprint([L,P])                                                           # needs sage.rings.finite_rings
         [{0, 10, 9}, {7}]
 
     .. NOTE::
 
             This method does NOT do any checks.
-
     """
     L = set(M1.loops())
     nP = L | set(M1.simplify().groundset())
@@ -460,21 +452,19 @@ def addlp(M, M1, L, P, ptsdict, G=None, limits=None):
 
     INPUT:
 
-    - ``M`` -- A matroid.
-    - ``M1`` -- A simple matroid corresponding to ``M``.
-    - ``L`` -- List of elements in ``M.groundset()`` that are loops of matroid
-      ``M``.
-    - ``P`` -- List of elements in ``M.groundset()`` not in
-      ``M.simplify.groundset()`` or ``L``.
-    - ``ptsdict`` -- A dictionary containing elements in ``M.groundset()`` not
-      necessarily containing elements of ``L``.
-    - ``G`` -- (optional) A sage graphics object to which loops and parallel
-      elements of matroid `M` added .
-    - ``limits``-- (optional) Current axes limits [xmin,xmax,ymin,ymax].
+    - ``M`` -- matroid
+    - ``M1`` -- a simple matroid corresponding to ``M``
+    - ``L`` -- list of elements in ``M.groundset()`` that are loops of matroid
+      ``M``
+    - ``P`` -- list of elements in ``M.groundset()`` not in
+      ``M.simplify.groundset()`` or ``L``
+    - ``ptsdict`` -- dictionary containing elements in ``M.groundset()`` not
+      necessarily containing elements of ``L``
+    - ``G`` -- (optional) a sage graphics object to which loops and parallel
+      elements of matroid `M` added
+    - ``limits`` -- (optional) current axes limits [xmin,xmax,ymin,ymax]
 
-    OUTPUT:
-
-    A 2-tuple containing:
+    OUTPUT: a 2-tuple containing:
 
     1. A sage graphics object containing loops and parallel elements of
        matroid ``M``
@@ -483,16 +473,16 @@ def addlp(M, M1, L, P, ptsdict, G=None, limits=None):
     EXAMPLES::
 
         sage: from sage.matroids import matroids_plot_helpers
-        sage: M=Matroid(ring=GF(2), matrix=[[1, 0, 0, 0, 1, 1, 1,0,1],
-        ....: [0, 1, 0, 1, 0, 1, 1,0,0],[0, 0, 1, 1, 1, 0, 1,0,0]])
-        sage: [M1,L,P]=matroids_plot_helpers.slp(M)
-        sage: G,lims=matroids_plot_helpers.addlp(M,M1,L,P,{0:(0,0)})
-        sage: G.show(axes=False)
+        sage: M = Matroid(ring=GF(2), matrix=[[1, 0, 0, 0, 1, 1, 1,0,1],
+        ....:                                 [0, 1, 0, 1, 0, 1, 1,0,0],
+        ....:                                 [0, 0, 1, 1, 1, 0, 1,0,0]])
+        sage: [M1,L,P] = matroids_plot_helpers.slp(M)                                   # needs sage.rings.finite_rings
+        sage: G, lims = matroids_plot_helpers.addlp(M,M1,L,P,{0:(0,0)})                 # needs sage.plot sage.rings.finite_rings
+        sage: G.show(axes=False)                                                        # needs sage.plot sage.rings.finite_rings
 
     .. NOTE::
 
             This method does NOT do any checks.
-
     """
     if G is None:
         G = Graphics()
@@ -563,18 +553,16 @@ def addlp(M, M1, L, P, ptsdict, G=None, limits=None):
 
 def line_hasorder(l, lodrs=None):
     """
-    Determine if an order is specified for a line
+    Determine if an order is specified for a line.
 
     INPUT:
 
-    - ``l`` -- A line specified as a list of ground set elements.
-    - ``lordrs`` -- (optional) A list of lists each specifying an order on
+    - ``l`` -- a line specified as a list of ground set elements
+    - ``lordrs`` -- (optional) list of lists each specifying an order on
       a subset of ground set elements that may or may not correspond to a
-      line in geometric representation.
+      line in geometric representation
 
-    OUTPUT:
-
-    A tuple containing 2 elements in this order:
+    OUTPUT: a tuple containing 2 elements in this order:
 
     1. A boolean indicating whether there is any list in ``lordrs`` that is
        setwise equal to ``l``.
@@ -611,10 +599,10 @@ def lineorders_union(lineorders1, lineorders2):
 
     INPUT:
 
-    - ``lineorders1`` -- A list of ordered lists specifying orders on subsets
-      of ground set.
-    - ``lineorders2`` -- A list of ordered lists specifying orders subsets of
-      ground set.
+    - ``lineorders1`` -- list of ordered lists specifying orders on subsets
+      of ground set
+    - ``lineorders2`` -- list of ordered lists specifying orders subsets of
+      ground set
 
     OUTPUT:
 
@@ -628,7 +616,6 @@ def lineorders_union(lineorders1, lineorders2):
         sage: matroids_plot_helpers.lineorders_union([['a','b','c'],
         ....: ['p','q','r'],['i','j','k','l']],[['r','p','q']])
         [['a', 'b', 'c'], ['p', 'q', 'r'], ['i', 'j', 'k', 'l']]
-
     """
     if lineorders1 is not None and lineorders2 is not None:
         lineorders = lineorders1
@@ -652,9 +639,9 @@ def posdict_is_sane(M1, pos_dict):
 
     INPUT:
 
-    - ``M1`` -- A matroid.
-    - ``posdict`` -- A dictionary mapping ground set elements to (x,y)
-      positions.
+    - ``M1`` -- matroid
+    - ``posdict`` -- dictionary mapping ground set elements to (x,y)
+      positions
 
     OUTPUT:
 
@@ -664,15 +651,16 @@ def posdict_is_sane(M1, pos_dict):
     EXAMPLES::
 
         sage: from sage.matroids import matroids_plot_helpers
-        sage: M1=Matroid(ring=GF(2), matrix=[[1, 0, 0, 0, 1, 1, 1,0,1,0,1],
-        ....: [0, 1, 0, 1, 0, 1, 1,0,0,1,0],[0, 0, 1, 1, 1, 0, 1,0,0,0,0]])
-        sage: pos_dict= {0: (0, 0),  1: (2, 0),  2: (1, 2),  3: (1.5, 1.0),
+        sage: M1 = Matroid(ring=GF(2), matrix=[[1, 0, 0, 0, 1, 1, 1,0,1,0,1],
+        ....:                                  [0, 1, 0, 1, 0, 1, 1,0,0,1,0],
+        ....:                                  [0, 0, 1, 1, 1, 0, 1,0,0,0,0]])
+        sage: pos_dict = {0: (0, 0),  1: (2, 0),  2: (1, 2),  3: (1.5, 1.0),
         ....: 4: (0.5, 1.0),  5: (1.0, 0.0), 6: (1.0, 0.6666666666666666)}
-        sage: matroids_plot_helpers.posdict_is_sane(M1,pos_dict)
+        sage: matroids_plot_helpers.posdict_is_sane(M1,pos_dict)                        # needs sage.rings.finite_rings
         True
-        sage: pos_dict= {1: (2, 0),  2: (1, 2),  3: (1.5, 1.0),
-        ....: 4: (0.5, 1.0), 5: (1.0, 0.0), 6: (1.0, 0.6666666666666666)}
-        sage: matroids_plot_helpers.posdict_is_sane(M1,pos_dict)
+        sage: pos_dict = {1: (2, 0),  2: (1, 2),  3: (1.5, 1.0),
+        ....:             4: (0.5, 1.0), 5: (1.0, 0.0), 6: (1.0, 0.6666666666666666)}
+        sage: matroids_plot_helpers.posdict_is_sane(M1,pos_dict)                        # needs sage.rings.finite_rings
         False
 
     .. NOTE::
@@ -701,13 +689,11 @@ def tracklims(lims, x_i=[], y_i=[]):
 
     INPUT:
 
-    - ``lims`` -- A list with 4 elements ``[xmin,xmax,ymin,ymax]``
-    - ``x_i`` -- New x values to track
-    - ``y_i`` -- New y values to track
+    - ``lims`` -- list with 4 elements ``[xmin,xmax,ymin,ymax]``
+    - ``x_i`` -- new x values to track
+    - ``y_i`` -- new y values to track
 
-    OUTPUT:
-
-    A list with 4 elements ``[xmin,xmax,ymin,ymax]``
+    OUTPUT: list with 4 elements ``[xmin,xmax,ymin,ymax]``
 
     EXAMPLES::
 
@@ -722,8 +708,8 @@ def tracklims(lims, x_i=[], y_i=[]):
     """
     if lims is not None and lims[0] is not None and lims[1] is not None and \
        lims[2] is not None and lims[3] is not None:
-        lims = [min(min(x_i), lims[0]), max(max(x_i), lims[1]),
-                min(min(y_i), lims[2]), max(max(y_i), lims[3])]
+        lims = [min(*x_i, lims[0]), max(*x_i, lims[1]),
+                min(*y_i, lims[2]), max(*y_i, lims[3])]
     else:
         lims = [min(x_i), max(x_i), min(y_i), max(y_i)]
     return lims
@@ -736,18 +722,18 @@ def geomrep(M1, B1=None, lineorders1=None, pd=None, sp=False):
 
     INPUT:
 
-    - ``M1`` -- A matroid.
-    - ``B1`` -- (optional) A list of elements in ``M1.groundset()`` that
+    - ``M1`` -- matroid
+    - ``B1`` -- (optional) list of elements in ``M1.groundset()`` that
       correspond to a basis of ``M1`` and will be placed as vertices of the
-      triangle in the geometric representation of ``M1``.
-    - ``lineorders1`` -- (optional) A list of ordered lists of elements of
+      triangle in the geometric representation of ``M1``
+    - ``lineorders1`` -- (optional) list of ordered lists of elements of
       ``M1.groundset()`` such that if a line in geometric representation is
       setwise same as any of these then points contained will be traversed in
-      that order thus overriding internal order deciding heuristic.
-    - ``pd`` - (optional) A dictionary mapping ground set elements to their
-      (x,y) positions.
-    - ``sp`` -- (optional) If True, a positioning dictionary and line orders
-      will be placed in ``M._cached_info``.
+      that order thus overriding internal order deciding heuristic
+    - ``pd`` -- (optional) dictionary mapping ground set elements to their
+      (x,y) positions
+    - ``sp`` -- (optional) if ``True``, a positioning dictionary and line orders
+      will be placed in ``M._cached_info``
 
     OUTPUT:
 
@@ -757,12 +743,12 @@ def geomrep(M1, B1=None, lineorders1=None, pd=None, sp=False):
     EXAMPLES::
 
         sage: from sage.matroids import matroids_plot_helpers
-        sage: M=matroids.named_matroids.P7()
-        sage: G=matroids_plot_helpers.geomrep(M)
-        sage: G.show(xmin=-2, xmax=3, ymin=-2, ymax=3)
-        sage: M=matroids.named_matroids.P7()
-        sage: G=matroids_plot_helpers.geomrep(M,lineorders1=[['f','e','d']])
-        sage: G.show(xmin=-2, xmax=3, ymin=-2, ymax=3)
+        sage: M = matroids.catalog.P7()
+        sage: G = matroids_plot_helpers.geomrep(M)                                      # needs sage.plot
+        sage: G.show(xmin=-2, xmax=3, ymin=-2, ymax=3)                                  # needs sage.plot
+        sage: M = matroids.catalog.P7()
+        sage: G = matroids_plot_helpers.geomrep(M, lineorders1=[['f','e','d']])         # needs sage.plot
+        sage: G.show(xmin=-2, xmax=3, ymin=-2, ymax=3)                                  # needs sage.plot
 
     .. NOTE::
 
@@ -817,11 +803,8 @@ def geomrep(M1, B1=None, lineorders1=None, pd=None, sp=False):
         lims = tracklims([None, None, None, None], [pnt[0] for pnt in pl],
                          [pnt[1] for pnt in pl])
     elif M.rank() == 2:
-        nB1 = list(set(list(M.groundset())) - set(B1))
-        bline = []
-        for j in nB1:
-            if M.is_dependent([j, B1[0], B1[1]]):
-                bline.append(j)
+        nB1 = set(M.groundset()) - set(B1)
+        bline = [j for j in nB1 if M.is_dependent([j, B1[0], B1[1]])]
         interval = len(bline)+1
         if M._cached_info is not None and \
            'plot_positions' in M._cached_info.keys() and \
@@ -871,13 +854,11 @@ def geomrep(M1, B1=None, lineorders1=None, pd=None, sp=False):
             trilines.extend(curvedlines)
         else:
             pts2 = M._cached_info['plot_positions']
-            trilines = [list(set(list(x)).difference(L | P))
-                        for x in M1.flats(2)
-                        if len(list(x)) >= 3]
+            trilines = [list(set(x).difference(L | P))
+                        for x in M1.flats(2) if len(list(x)) >= 3]
         pl = [list(x) for x in pts2.values()]
         lims = tracklims([None, None, None, None], [pt[0] for pt in pl],
                          [pt[1] for pt in pl])
-        j = 0
         for ll in trilines:
             if len(ll) >= 3:
                 ptsx, ptsy, x_i, y_i = createline(pts2, ll, lineorders1)
