@@ -76,17 +76,13 @@ class NumericalEigenforms(SageObject):
         sage: n.ap(2)  # abs tol 1e-12
         [3.0, -1.6180339887498947, 0.6180339887498968]
         sage: n.systems_of_eigenvalues(7)  # abs tol 2e-12
-        [
-        [-1.6180339887498947, 2.2360679774997894, -3.2360679774997894],
-        [0.6180339887498968, -2.236067977499788, 1.2360679774997936],
-        [3.0, 4.0, 6.0]
-        ]
+        [[-1.6180339887498947, 2.23606797749979, -3.2360679774997894],
+         [0.618033988749895, -2.236067977499788, 1.23606797749979],
+         [3.0, 4.0, 6.0]]
         sage: n.systems_of_abs(7)  # abs tol 2e-12
-        [
-        [0.6180339887498943, 2.2360679774997894, 1.2360679774997887],
-        [1.6180339887498947, 2.23606797749979, 3.2360679774997894],
-        [3.0, 4.0, 6.0]
-        ]
+        [[0.618033988749895, 2.236067977499788, 1.23606797749979],
+         [1.6180339887498947, 2.23606797749979, 3.2360679774997894],
+         [3.0, 4.0, 6.0]]
         sage: n.eigenvalues([2,3,5])  # rel tol 2e-12
         [[3.0, -1.6180339887498947, 0.6180339887498968],
          [4.0, 2.2360679774997894, -2.236067977499788],
@@ -443,13 +439,20 @@ class NumericalEigenforms(SageObject):
         EXAMPLES::
 
             sage: numerical_eigenforms(61).systems_of_eigenvalues(10)  # rel tol 1e-9
-            [
-            [-1.4811943040920152, 0.8060634335253695, 3.1563251746586642, 0.6751308705666477],
-            [-1.0, -2.0000000000000027, -3.000000000000003, 1.0000000000000044],
-            [0.3111078174659775, 2.903211925911551, -2.525427560843529, -3.214319743377552],
-            [2.170086486626034, -1.7092753594369208, -1.63089761381512, -0.46081112718908984],
-            [3.0, 4.0, 6.0, 8.0]
-            ]
+            [[-1.481194304092014,
+              0.8060634335253706,
+              3.156325174658664,
+              0.6751308705666462],
+             [-1.0, -2.0, -3.0, 1.0],
+             [0.311107817465981,
+              2.903211925911551,
+              -2.5254275608435184,
+              -3.214319743377534],
+             [2.1700864866260323,
+              -1.7092753594369237,
+              -1.6308976138151459,
+              -0.460811127189112],
+             [3.0, 4.0, 6.0, 8.0]]
         """
         P = prime_range(bound)
         e = self.eigenvalues(P)
@@ -470,13 +473,17 @@ class NumericalEigenforms(SageObject):
         EXAMPLES::
 
             sage: numerical_eigenforms(61).systems_of_abs(10)  # rel tol 1e-9
-            [
-            [0.3111078174659775, 2.903211925911551, 2.525427560843529, 3.214319743377552],
-            [1.0, 2.0000000000000027, 3.000000000000003, 1.0000000000000044],
-            [1.4811943040920152, 0.8060634335253695, 3.1563251746586642, 0.6751308705666477],
-            [2.170086486626034, 1.7092753594369208, 1.63089761381512, 0.46081112718908984],
-            [3.0, 4.0, 6.0, 8.0]
-            ]
+            [[0.311107817465981, 2.903211925911551, 2.5254275608435184, 3.214319743377534],
+             [1.0, 2.0, 3.0, 1.0],
+             [1.481194304092014,
+              0.8060634335253706,
+              3.156325174658664,
+              0.6751308705666462],
+             [2.1700864866260323,
+              1.7092753594369237,
+              1.6308976138151459,
+              0.460811127189112],
+             [3.0, 4.0, 6.0, 8.0]]
         """
         P = prime_range(bound)
         e = self.eigenvalues(P)
