@@ -79,7 +79,7 @@ You can also use the module action::
     sage: Sq(2) * x
     (Sq(4,1)+Sq(7))*g[0] + Sq(3,1)*g[1]
 
-Each non-zero element has a well-defined degree::
+Each nonzero element has a well-defined degree::
 
     sage: x.degree()
     5
@@ -306,7 +306,7 @@ class FreeGradedModule(CombinatorialFreeModule):
     - ``generator_degrees`` -- tuple of integers defining the number
       of generators of the module, and their degrees
 
-    - ``names`` -- optional, the names of the generators. If ``names``
+    - ``names`` -- (optional) the names of the generators. If ``names``
       is a comma-separated string like ``'a, b, c'``, then those will
       be the names. Otherwise, for example if ``names`` is ``abc``,
       then the names will be ``abc(d,i)``.
@@ -549,7 +549,7 @@ class FreeGradedModule(CombinatorialFreeModule):
 
         INPUT:
 
-        - ``coefficients`` -- a tuple of coefficient (i.e. elements of the
+        - ``coefficients`` -- tuple of coefficient (i.e. elements of the
           algebra for this module), an element of FreeGradedModule, or the
           zero integer constant
 
@@ -646,7 +646,7 @@ class FreeGradedModule(CombinatorialFreeModule):
 
         INPUT:
 
-        - ``n`` -- an integer
+        - ``n`` -- integer
 
         OUTPUT:
 
@@ -733,11 +733,9 @@ class FreeGradedModule(CombinatorialFreeModule):
         INPUT:
 
         - ``coordinates`` -- a sequence of elements of the ground ring
-        - ``n`` -- an integer
+        - ``n`` -- integer
 
-        OUTPUT:
-
-        A module element of degree ``n``.
+        OUTPUT: a module element of degree ``n``
 
         .. SEEALSO::
 
@@ -811,7 +809,7 @@ class FreeGradedModule(CombinatorialFreeModule):
 
         INPUT:
 
-        - ``n`` -- an integer degree
+        - ``n`` -- integer degree
 
         OUTPUT:
 
@@ -921,7 +919,7 @@ class FreeGradedModule(CombinatorialFreeModule):
 
         INPUT:
 
-        - ``t`` -- an integer
+        - ``t`` -- integer
 
         OUTPUT:
 
@@ -985,12 +983,12 @@ class FreeGradedModule(CombinatorialFreeModule):
 
         INPUT:
 
-        - ``k`` -- a non-negative integer
+        - ``k`` -- nonnegative integer
         - ``top_dim`` -- stop the computation at this degree. Ignored,
           for compatibility with
           :meth:`sage.modules.fp_graded.module.FPModule.resolution`.
-        - ``verbose`` -- (default: ``False``) a boolean to control if
-          log messages should be emitted
+        - ``verbose`` -- boolean (default: ``False``); controls whether log
+          messages should be emitted
 
         OUTPUT:
 
@@ -1026,7 +1024,7 @@ class FreeGradedModule(CombinatorialFreeModule):
              Module endomorphism of Free graded left module on 0 generators over The exterior algebra of rank 3 over Rational Field]
         """
         if k < 0:
-            raise ValueError('the length of the resolution must be non-negative')
+            raise ValueError('the length of the resolution must be nonnegative')
 
         # The first map \epsilon is the identity map
         ret_complex = [Hom(self, self).identity()]
@@ -1047,9 +1045,7 @@ class FreeGradedModule(CombinatorialFreeModule):
         r"""
         Return a minimal presentation of ``self``.
 
-        OUTPUT:
-
-        The identity morphism as ``self`` is free.
+        OUTPUT: the identity morphism as ``self`` is free
 
         EXAMPLES::
 
