@@ -89,7 +89,7 @@ class QuotientModuleWithBasis(CombinatorialFreeModule):
         TESTS::
 
             sage: from sage.modules.with_basis.subquotient import QuotientModuleWithBasis
-            sage: X = CombinatorialFreeModule(QQ, range(3), prefix="x"); x = X.basis()
+            sage: X = CombinatorialFreeModule(QQ, range(3), prefix='x'); x = X.basis()
             sage: I = X.submodule( (x[0]-x[1], x[1]-x[2]) )
             sage: Y = QuotientModuleWithBasis(I)
             sage: Y.print_options(prefix='y')
@@ -115,7 +115,7 @@ class QuotientModuleWithBasis(CombinatorialFreeModule):
 
         EXAMPLES::
 
-            sage: X = CombinatorialFreeModule(QQ, range(3), prefix="x"); x = X.basis()
+            sage: X = CombinatorialFreeModule(QQ, range(3), prefix='x'); x = X.basis()
             sage: Y = X.quotient_module((x[0]-x[1], x[1]-x[2]))
             sage: Y.ambient() is X
             True
@@ -132,7 +132,7 @@ class QuotientModuleWithBasis(CombinatorialFreeModule):
 
         EXAMPLES::
 
-            sage: X = CombinatorialFreeModule(QQ, range(3), prefix="x"); x = X.basis()
+            sage: X = CombinatorialFreeModule(QQ, range(3), prefix='x'); x = X.basis()
             sage: Y = X.quotient_module((x[0]-x[1], x[1]-x[2]));         y = Y.basis()
             sage: Y.lift(y[2])
             x[2]
@@ -150,7 +150,7 @@ class QuotientModuleWithBasis(CombinatorialFreeModule):
 
         EXAMPLES::
 
-            sage: X = CombinatorialFreeModule(QQ, range(3), prefix="x"); x = X.basis()
+            sage: X = CombinatorialFreeModule(QQ, range(3), prefix='x'); x = X.basis()
             sage: Y = X.quotient_module((x[0]-x[1], x[1]-x[2]));         y = Y.basis()
             sage: Y.print_options(prefix='y')
             sage: Y.retract(x[0])
@@ -231,7 +231,7 @@ class SubmoduleWithBasis(CombinatorialFreeModule):
         TESTS::
 
             sage: from sage.modules.with_basis.subquotient import SubmoduleWithBasis
-            sage: X = CombinatorialFreeModule(QQ, range(3), prefix="x"); x = X.basis()
+            sage: X = CombinatorialFreeModule(QQ, range(3), prefix='x'); x = X.basis()
             sage: ybas = (x[0]-x[1], x[1]-x[2])
             sage: Y = SubmoduleWithBasis(ybas, [0, 1, 2], X)
             sage: Y.print_options(prefix='y')
@@ -287,7 +287,7 @@ class SubmoduleWithBasis(CombinatorialFreeModule):
 
         EXAMPLES::
 
-            sage: X = CombinatorialFreeModule(QQ, range(3), prefix="x");             x = X.basis()
+            sage: X = CombinatorialFreeModule(QQ, range(3), prefix='x');             x = X.basis()
             sage: Y = X.submodule((x[0]-x[1], x[1]-x[2]), already_echelonized=True); y = Y.basis()
             sage: Y.lift
             Generic morphism:
@@ -300,10 +300,10 @@ class SubmoduleWithBasis(CombinatorialFreeModule):
         """
         return self.module_morphism(self.lift_on_basis,
                                     codomain=self._ambient,
-                                    triangular="lower",
+                                    triangular='lower',
                                     unitriangular=self._unitriangular,
                                     key=self._support_key,
-                                    inverse_on_support="compute")
+                                    inverse_on_support='compute')
 
     @lazy_attribute
     def reduce(self):
@@ -315,7 +315,7 @@ class SubmoduleWithBasis(CombinatorialFreeModule):
 
         EXAMPLES::
 
-            sage: X = CombinatorialFreeModule(QQ, range(3), prefix="x"); x = X.basis()
+            sage: X = CombinatorialFreeModule(QQ, range(3), prefix='x'); x = X.basis()
             sage: Y = X.submodule((x[0]-x[1], x[1]-x[2]), already_echelonized=True)
             sage: Y.reduce
             Generic endomorphism of Free module generated by {0, 1, 2} over Rational Field
@@ -338,7 +338,7 @@ class SubmoduleWithBasis(CombinatorialFreeModule):
 
         EXAMPLES::
 
-            sage: X = CombinatorialFreeModule(QQ, range(3), prefix="x"); x = X.basis()
+            sage: X = CombinatorialFreeModule(QQ, range(3), prefix='x'); x = X.basis()
             sage: Y = X.submodule((x[0]-x[1], x[1]-x[2]), already_echelonized=True)
             sage: Y.print_options(prefix='y')
             sage: Y.retract
@@ -661,7 +661,7 @@ class SubmoduleWithBasis(CombinatorialFreeModule):
 
         INPUT:
 
-        - ``gens`` -- a list or family of elements of ``self``
+        - ``gens`` -- list or family of elements of ``self``
 
         For additional optional arguments, see
         :meth:`ModulesWithBasis.ParentMethods.submodule`.
