@@ -1,11 +1,11 @@
 """
 Local Field Invariants
 
-This contains routines to compute local (p-adic) invariants of
+This contains routines to compute local (`p`-adic) invariants of
 quadratic forms over the rationals.
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2007 William Stein and Jonathan Hanke
 #       Copyright (C) 2015 Jeroen Demeyer <jdemeyer@cage.ugent.be>
 #
@@ -13,11 +13,11 @@ quadratic forms over the rationals.
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
 ###########################################################################
-# TO DO: Add routines for hasse invariants at all places, anisotropic
+# TO DO: Add routines for Hasse invariants at all places, anisotropic
 # places, is_semi_definite, and support for number fields.
 ###########################################################################
 
@@ -37,16 +37,16 @@ def rational_diagonal_form(self, return_matrix=False):
 
     INPUT:
 
-    - ``return_matrix`` -- (boolean, default: False) also return the
+    - ``return_matrix`` -- boolean (default: ``False``); also return the
       transformation matrix
 
     OUTPUT: either the diagonal quadratic form `D` (if ``return_matrix`` is false)
     or the pair `(D, T)` (if ``return_matrix`` is true) where
 
-    - `D` -- the diagonalized form of this quadratic form
+    - ``D`` -- the diagonalized form of this quadratic form
 
-    - `T` -- transformation matrix. This is such that
-      ``T.transpose() * self.matrix() * T`` gives ``D.matrix()``.
+    - ``T`` -- transformation matrix. This is such that
+      ``T.transpose() * self.matrix() * T`` gives ``D.matrix()``
 
     Both `D` and `T` are defined over the fraction field of the
     base ring of the given form.
@@ -165,7 +165,19 @@ def rational_diagonal_form(self, return_matrix=False):
         sage: T[0,0] = 13
         Traceback (most recent call last):
         ...
-        ValueError: matrix is immutable; please change a copy instead (i.e., use copy(M) to change a copy of M).
+        ValueError: matrix is immutable; please change a copy instead
+        (i.e., use copy(M) to change a copy of M).
+
+    Test for a singular form::
+
+        sage: m = matrix(GF(11), [[1,5,0,0], [5,1,9,0], [0,9,1,5], [0,0,5,1]])
+        sage: qf = QuadraticForm(m)
+        sage: Q, T = qf.rational_diagonal_form(return_matrix=True)
+        sage: T
+        [ 1  6  5 10]
+        [ 0  1 10  9]
+        [ 0  0  1  2]
+        [ 0  0  0  1]
     """
     Q, T = self._rational_diagonal_form_and_transformation()
     T.set_immutable()
@@ -173,26 +185,24 @@ def rational_diagonal_form(self, return_matrix=False):
     # Quadratic forms do not support immutability, so we need to make
     # a copy to be safe.
     Q = deepcopy(Q)
-
-    if return_matrix:
-        return Q, T
-    else:
-        return Q
+    return (Q, T) if return_matrix else Q
 
 
 @cached_method
 def _rational_diagonal_form_and_transformation(self):
     """
     Return a diagonal form equivalent to the given quadratic from and
-    the corresponding transformation matrix. This is over the fraction
-    field of the base ring of the given quadratic form.
+    the corresponding transformation matrix.
+
+    This is over the fraction field of the base ring of the given
+    quadratic form.
 
     OUTPUT: a tuple `(D,T)` where
 
-    - `D` -- the diagonalized form of this quadratic form
+    - ``D`` -- the diagonalized form of this quadratic form
 
-    - `T` -- transformation matrix. This is such that
-      ``T.transpose() * self.matrix() * T`` gives ``D.matrix()``.
+    - ``T`` -- transformation matrix. This is such that
+      ``T.transpose() * self.matrix() * T`` gives ``D.matrix()``
 
     Both `D` and `T` are defined over the fraction field of the
     base ring of the given form.
@@ -237,14 +247,14 @@ def _rational_diagonal_form_and_transformation(self):
         # Diagonal matrix
         D = MS()
         for i in range(n):
-            D[i,i] = R[i,i]
-        Q = Q.parent()(D)
+            D[i, i] = R[i, i]
+        newQ = Q.parent()(D)
         # Transformation matrix (inverted)
         T = MS(R.sage())
         for i in range(n):
-            T[i,i] = K.one()
+            T[i, i] = K.one()
         try:
-            return Q, ~T
+            return newQ, ~T
         except ZeroDivisionError:
             # Singular case is not fully supported by PARI
             pass
@@ -256,13 +266,13 @@ def _rational_diagonal_form_and_transformation(self):
     for i in range(n):
 
         # Deal with rows where the diagonal entry is zero.
-        if Q[i,i] == 0:
+        if Q[i, i] == 0:
 
-            # Look for a non-zero entry and use it to make the diagonal non-zero (if it exists)
-            for j in range(i+1, n):
-                if Q[i,j] != 0:
+            # Look for a nonzero entry and use it to make the diagonal nonzero (if it exists)
+            for j in range(i + 1, n):
+                if Q[i, j] != 0:
                     temp = MS(1)
-                    if Q[i,j] + Q[j,j] == 0:
+                    if Q[i, j] + Q[j, j] == 0:
                         temp[j, i] = -1
                     else:
                         temp[j, i] = 1
@@ -274,9 +284,10 @@ def _rational_diagonal_form_and_transformation(self):
 
         # Create a matrix which deals with off-diagonal entries (all at once for each row)
         temp = MS(1)
-        for j in range(i+1, n):
-            if Q[i,j] != 0:
-                temp[i,j] = -Q[i,j] / (Q[i,i] * 2)    # This should only occur when Q[i,i] != 0, which the above step guarantees.
+        for j in range(i + 1, n):
+            if Q[i, j] != 0:
+                temp[i, j] = -Q[i, j] / (Q[i, i] * 2)
+                # This should only occur when Q[i,i] != 0, which the above step guarantees.
 
         Q = Q(temp)
         T = T * temp
@@ -318,16 +329,15 @@ def signature_vector(self):
         [ * * * 9 ]
         sage: Q.signature_vector()
         (3, 1, 0)
-
     """
     diag = self.rational_diagonal_form()
     p = 0
     n = 0
     z = 0
     for i in range(diag.dim()):
-        if diag[i,i] > 0:
+        if diag[i, i] > 0:
             p += 1
-        elif diag[i,i] < 0:
+        elif diag[i, i] < 0:
             n += 1
         else:
             z += 1
@@ -343,7 +353,7 @@ def signature(self):
 
     of the matrix of the quadratic form.
 
-    OUTPUT: an integer
+    OUTPUT: integer
 
     EXAMPLES::
 
@@ -367,9 +377,8 @@ def signature(self):
         [ * * * 9 ]
         sage: Q.signature()
         2
-
     """
-    (p, n, z) = self.signature_vector()
+    p, n, _ = self.signature_vector()
     return p - n
 
 
@@ -411,33 +420,33 @@ def hasse_invariant(self, p):
         Quadratic form in 2 variables over Rational Field with coefficients:
         [ 1 0 ]
         [ * 2 ]
-        sage: [Q.hasse_invariant(p) for p in prime_range(20)]                       # optional - sage.libs.pari
+        sage: [Q.hasse_invariant(p) for p in prime_range(20)]                           # needs sage.libs.pari
         [1, 1, 1, 1, 1, 1, 1, 1]
-        sage: [Q.hasse_invariant__OMeara(p) for p in prime_range(20)]               # optional - sage.libs.pari
+        sage: [Q.hasse_invariant__OMeara(p) for p in prime_range(20)]                   # needs sage.libs.pari
         [1, 1, 1, 1, 1, 1, 1, 1]
 
     ::
 
         sage: Q = DiagonalQuadraticForm(ZZ, [1,-1])
-        sage: [Q.hasse_invariant(p) for p in prime_range(20)]                       # optional - sage.libs.pari
+        sage: [Q.hasse_invariant(p) for p in prime_range(20)]                           # needs sage.libs.pari
         [1, 1, 1, 1, 1, 1, 1, 1]
-        sage: [Q.hasse_invariant__OMeara(p) for p in prime_range(20)]               # optional - sage.libs.pari
+        sage: [Q.hasse_invariant__OMeara(p) for p in prime_range(20)]                   # needs sage.libs.pari
         [-1, 1, 1, 1, 1, 1, 1, 1]
 
     ::
 
         sage: Q = DiagonalQuadraticForm(ZZ, [1,-1,5])
-        sage: [Q.hasse_invariant(p) for p in prime_range(20)]                       # optional - sage.libs.pari
+        sage: [Q.hasse_invariant(p) for p in prime_range(20)]                           # needs sage.libs.pari
         [1, 1, 1, 1, 1, 1, 1, 1]
-        sage: [Q.hasse_invariant__OMeara(p) for p in prime_range(20)]               # optional - sage.libs.pari
+        sage: [Q.hasse_invariant__OMeara(p) for p in prime_range(20)]                   # needs sage.libs.pari
         [-1, 1, 1, 1, 1, 1, 1, 1]
 
     ::
 
         sage: x = polygen(ZZ, 'x')
-        sage: K.<a> = NumberField(x^2 - 23)                                         # optional - sage.rings.number_field
-        sage: Q = DiagonalQuadraticForm(K, [-a, a + 2])                             # optional - sage.rings.number_field
-        sage: [Q.hasse_invariant(p) for p in K.primes_above(19)]                    # optional - sage.rings.number_field
+        sage: K.<a> = NumberField(x^2 - 23)                                             # needs sage.rings.number_field
+        sage: Q = DiagonalQuadraticForm(K, [-a, a + 2])                                 # needs sage.rings.number_field
+        sage: [Q.hasse_invariant(p) for p in K.primes_above(19)]                        # needs sage.rings.number_field
         [-1, 1]
     """
     # TO DO: Need to deal with the case n=1 separately somewhere!
@@ -449,14 +458,16 @@ def hasse_invariant(self, p):
     n = Diag.dim()
 
     if R == QQ:
-        for j in range(n-1):
-            for k in range(j+1, n):
-                hasse_temp = hasse_temp * hilbert_symbol(Diag[j,j], Diag[k,k], p)
+        for j in range(n - 1):
+            for k in range(j + 1, n):
+                hasse_temp = hasse_temp * hilbert_symbol(Diag[j, j],
+                                                         Diag[k, k], p)
 
     else:
-        for j in range(n-1):
-            for k in range(j+1, n):
-                hasse_temp = hasse_temp * R.hilbert_symbol(Diag[j,j], Diag[k,k], p)
+        for j in range(n - 1):
+            for k in range(j + 1, n):
+                hasse_temp = hasse_temp * R.hilbert_symbol(Diag[j, j],
+                                                           Diag[k, k], p)
 
     return hasse_temp
 
@@ -494,33 +505,33 @@ def hasse_invariant__OMeara(self, p):
         Quadratic form in 2 variables over Rational Field with coefficients:
         [ 1 0 ]
         [ * 2 ]
-        sage: [Q.hasse_invariant(p) for p in prime_range(20)]                       # optional - sage.libs.pari
+        sage: [Q.hasse_invariant(p) for p in prime_range(20)]                           # needs sage.libs.pari
         [1, 1, 1, 1, 1, 1, 1, 1]
-        sage: [Q.hasse_invariant__OMeara(p) for p in prime_range(20)]               # optional - sage.libs.pari
+        sage: [Q.hasse_invariant__OMeara(p) for p in prime_range(20)]                   # needs sage.libs.pari
         [1, 1, 1, 1, 1, 1, 1, 1]
 
     ::
 
         sage: Q = DiagonalQuadraticForm(ZZ, [1,-1])
-        sage: [Q.hasse_invariant(p) for p in prime_range(20)]                       # optional - sage.libs.pari
+        sage: [Q.hasse_invariant(p) for p in prime_range(20)]                           # needs sage.libs.pari
         [1, 1, 1, 1, 1, 1, 1, 1]
-        sage: [Q.hasse_invariant__OMeara(p) for p in prime_range(20)]               # optional - sage.libs.pari
+        sage: [Q.hasse_invariant__OMeara(p) for p in prime_range(20)]                   # needs sage.libs.pari
         [-1, 1, 1, 1, 1, 1, 1, 1]
 
     ::
 
         sage: Q = DiagonalQuadraticForm(ZZ,[1,-1,-1])
-        sage: [Q.hasse_invariant(p) for p in prime_range(20)]                       # optional - sage.libs.pari
+        sage: [Q.hasse_invariant(p) for p in prime_range(20)]                           # needs sage.libs.pari
         [-1, 1, 1, 1, 1, 1, 1, 1]
-        sage: [Q.hasse_invariant__OMeara(p) for p in prime_range(20)]               # optional - sage.libs.pari
+        sage: [Q.hasse_invariant__OMeara(p) for p in prime_range(20)]                   # needs sage.libs.pari
         [-1, 1, 1, 1, 1, 1, 1, 1]
 
     ::
 
         sage: x = polygen(ZZ, 'x')
-        sage: K.<a> = NumberField(x^2 - 23)                                         # optional - sage.rings.number_field
-        sage: Q = DiagonalQuadraticForm(K, [-a, a + 2])                             # optional - sage.rings.number_field
-        sage: [Q.hasse_invariant__OMeara(p) for p in K.primes_above(19)]            # optional - sage.rings.number_field
+        sage: K.<a> = NumberField(x^2 - 23)                                             # needs sage.rings.number_field
+        sage: Q = DiagonalQuadraticForm(K, [-a, a + 2])                                 # needs sage.rings.number_field
+        sage: [Q.hasse_invariant__OMeara(p) for p in K.primes_above(19)]                # needs sage.rings.number_field
         [1, 1]
     """
     # TO DO: Need to deal with the case n=1 separately somewhere!
@@ -533,17 +544,19 @@ def hasse_invariant__OMeara(self, p):
     if R == QQ:
         for j in range(n):
             for k in range(j, n):
-                hasse_temp = hasse_temp * hilbert_symbol(Diag[j,j], Diag[k,k], p)
+                hasse_temp = hasse_temp * hilbert_symbol(Diag[j, j],
+                                                         Diag[k, k], p)
 
     else:
         for j in range(n):
             for k in range(j, n):
-                hasse_temp = hasse_temp * R.hilbert_symbol(Diag[j,j], Diag[k,k], p)
+                hasse_temp = hasse_temp * R.hilbert_symbol(Diag[j, j],
+                                                           Diag[k, k], p)
 
     return hasse_temp
 
 
-def is_hyperbolic(self, p):
+def is_hyperbolic(self, p) -> bool:
     r"""
     Check if the quadratic form is a sum of hyperbolic planes over
     the `p`-adic numbers `\QQ_p` or over the real numbers `\RR`.
@@ -563,18 +576,19 @@ def is_hyperbolic(self, p):
 
     EXAMPLES::
 
+        sage: # needs sage.libs.pari
         sage: Q = DiagonalQuadraticForm(ZZ, [1,1])
-        sage: Q.is_hyperbolic(-1)                                                   # optional - sage.libs.pari
+        sage: Q.is_hyperbolic(-1)
         False
-        sage: Q.is_hyperbolic(2)                                                    # optional - sage.libs.pari
+        sage: Q.is_hyperbolic(2)
         False
-        sage: Q.is_hyperbolic(3)                                                    # optional - sage.libs.pari
+        sage: Q.is_hyperbolic(3)
         False
-        sage: Q.is_hyperbolic(5)     # Here -1 is a square, so it's true.           # optional - sage.libs.pari
+        sage: Q.is_hyperbolic(5)     # Here -1 is a square, so it's true.
         True
-        sage: Q.is_hyperbolic(7)                                                    # optional - sage.libs.pari
+        sage: Q.is_hyperbolic(7)
         False
-        sage: Q.is_hyperbolic(13)    # Here -1 is a square, so it's true.           # optional - sage.libs.pari
+        sage: Q.is_hyperbolic(13)    # Here -1 is a square, so it's true.
         True
     """
     # False for odd-dim'l forms
@@ -614,33 +628,33 @@ def is_anisotropic(self, p):
     EXAMPLES::
 
         sage: Q = DiagonalQuadraticForm(ZZ, [1,1])
-        sage: Q.is_anisotropic(2)                                                   # optional - sage.libs.pari
+        sage: Q.is_anisotropic(2)                                                       # needs sage.libs.pari
         True
-        sage: Q.is_anisotropic(3)                                                   # optional - sage.libs.pari
+        sage: Q.is_anisotropic(3)                                                       # needs sage.libs.pari
         True
-        sage: Q.is_anisotropic(5)                                                   # optional - sage.libs.pari
+        sage: Q.is_anisotropic(5)                                                       # needs sage.libs.pari
         False
 
     ::
 
         sage: Q = DiagonalQuadraticForm(ZZ, [1,-1])
-        sage: Q.is_anisotropic(2)                                                   # optional - sage.libs.pari
+        sage: Q.is_anisotropic(2)                                                       # needs sage.libs.pari
         False
-        sage: Q.is_anisotropic(3)                                                   # optional - sage.libs.pari
+        sage: Q.is_anisotropic(3)                                                       # needs sage.libs.pari
         False
-        sage: Q.is_anisotropic(5)                                                   # optional - sage.libs.pari
+        sage: Q.is_anisotropic(5)                                                       # needs sage.libs.pari
         False
 
     ::
 
-        sage: [DiagonalQuadraticForm(ZZ,                                            # optional - sage.libs.pari
+        sage: [DiagonalQuadraticForm(ZZ,                                                # needs sage.libs.pari
         ....:                        [1, -least_quadratic_nonresidue(p)]).is_anisotropic(p)
         ....:  for p in prime_range(3, 30)]
         [True, True, True, True, True, True, True, True, True]
 
     ::
 
-        sage: [DiagonalQuadraticForm(ZZ, [1, -least_quadratic_nonresidue(p),        # optional - sage.libs.pari
+        sage: [DiagonalQuadraticForm(ZZ, [1, -least_quadratic_nonresidue(p),            # needs sage.libs.pari
         ....:                             p, -p*least_quadratic_nonresidue(p)]).is_anisotropic(p)
         ....:  for p in prime_range(3, 30)]
         [True, True, True, True, True, True, True, True, True]
@@ -673,7 +687,7 @@ def is_anisotropic(self, p):
 
 def is_isotropic(self, p):
     r"""
-    Checks if `Q` is isotropic over the `p`-adic numbers `\QQ_p` or `\RR`.
+    Check if `Q` is isotropic over the `p`-adic numbers `\QQ_p` or `\RR`.
 
     INPUT:
 
@@ -684,37 +698,36 @@ def is_isotropic(self, p):
     EXAMPLES::
 
         sage: Q = DiagonalQuadraticForm(ZZ, [1,1])
-        sage: Q.is_isotropic(2)                                                     # optional - sage.libs.pari
+        sage: Q.is_isotropic(2)                                                         # needs sage.libs.pari
         False
-        sage: Q.is_isotropic(3)                                                     # optional - sage.libs.pari
+        sage: Q.is_isotropic(3)                                                         # needs sage.libs.pari
         False
-        sage: Q.is_isotropic(5)                                                     # optional - sage.libs.pari
+        sage: Q.is_isotropic(5)                                                         # needs sage.libs.pari
         True
 
     ::
 
         sage: Q = DiagonalQuadraticForm(ZZ, [1,-1])
-        sage: Q.is_isotropic(2)                                                     # optional - sage.libs.pari
+        sage: Q.is_isotropic(2)                                                         # needs sage.libs.pari
         True
-        sage: Q.is_isotropic(3)                                                     # optional - sage.libs.pari
+        sage: Q.is_isotropic(3)                                                         # needs sage.libs.pari
         True
-        sage: Q.is_isotropic(5)                                                     # optional - sage.libs.pari
+        sage: Q.is_isotropic(5)                                                         # needs sage.libs.pari
         True
 
     ::
 
-        sage: [DiagonalQuadraticForm(ZZ,                                            # optional - sage.libs.pari
+        sage: [DiagonalQuadraticForm(ZZ,                                                # needs sage.libs.pari
         ....:                        [1, -least_quadratic_nonresidue(p)]).is_isotropic(p)
         ....:  for p in prime_range(3, 30)]
         [False, False, False, False, False, False, False, False, False]
 
     ::
 
-        sage: [DiagonalQuadraticForm(ZZ, [1, -least_quadratic_nonresidue(p),        # optional - sage.libs.pari
+        sage: [DiagonalQuadraticForm(ZZ, [1, -least_quadratic_nonresidue(p),            # needs sage.libs.pari
         ....:                             p, -p*least_quadratic_nonresidue(p)]).is_isotropic(p)
         ....:  for p in prime_range(3, 30)]
         [False, False, False, False, False, False, False, False, False]
-
     """
     return not self.is_anisotropic(p)
 
@@ -728,15 +741,15 @@ def anisotropic_primes(self):
     EXAMPLES::
 
         sage: Q = DiagonalQuadraticForm(ZZ, [1,1,1])
-        sage: Q.anisotropic_primes()                                                # optional - sage.libs.pari
+        sage: Q.anisotropic_primes()                                                    # needs sage.libs.pari
         [2, -1]
 
         sage: Q = DiagonalQuadraticForm(ZZ, [1,1,1,1])
-        sage: Q.anisotropic_primes()                                                # optional - sage.libs.pari
+        sage: Q.anisotropic_primes()                                                    # needs sage.libs.pari
         [2, -1]
 
         sage: Q = DiagonalQuadraticForm(ZZ, [1,1,1,1,1])
-        sage: Q.anisotropic_primes()                                                # optional - sage.libs.pari
+        sage: Q.anisotropic_primes()                                                    # needs sage.libs.pari
         [-1]
     """
     # Look at all prime divisors of 2 * Det(Q) to find the
@@ -759,7 +772,7 @@ def compute_definiteness(self):
 
         A degenerate form is considered neither definite nor indefinite.
 
-    .. NOTE:
+    .. NOTE::
 
         The zero-dimensional form is considered both positive definite and negative definite.
 
@@ -803,7 +816,6 @@ def compute_definiteness(self):
         False
         sage: Q.is_definite()
         False
-
     """
     # Sanity Check
     from sage.rings.real_mpfr import RR
@@ -895,8 +907,8 @@ def compute_definiteness_string_by_determinants(self):
         return "degenerate"
 
     # Check the sign of the ratios of consecutive determinants of the upper triangular r x r submatrices
-    first_coeff = self[0,0]
-    for r in range(1,n+1):
+    first_coeff = self[0, 0]
+    for r in range(1, n + 1):
         I = list(range(r))
         new_det = M.matrix_from_rows_and_columns(I, I).det()
 
@@ -924,7 +936,7 @@ def is_positive_definite(self):
 
         The zero-dimensional form is considered both positive definite and negative definite.
 
-    OUTPUT: boolean -- True or False
+    OUTPUT: boolean
 
     EXAMPLES::
 
@@ -961,7 +973,7 @@ def is_negative_definite(self):
 
         The zero-dimensional form is considered both positive definite and negative definite.
 
-    OUTPUT: boolean -- True or False
+    OUTPUT: boolean
 
     EXAMPLES::
 
@@ -998,7 +1010,7 @@ def is_indefinite(self):
 
         The zero-dimensional form is not considered indefinite.
 
-    OUTPUT: boolean -- True or False
+    OUTPUT: boolean
 
     EXAMPLES::
 
@@ -1011,7 +1023,6 @@ def is_indefinite(self):
         sage: Q = DiagonalQuadraticForm(ZZ, [1,-3,5])
         sage: Q.is_indefinite()
         True
-
     """
     # Try to use the cached value
     try:
@@ -1036,7 +1047,7 @@ def is_definite(self):
 
         The zero-dimensional form is considered indefinite.
 
-    OUTPUT: boolean -- True or False
+    OUTPUT: boolean
 
     EXAMPLES::
 
