@@ -22,8 +22,7 @@ used as minimal polynomial.
 from sage.rings.finite_rings.finite_field_base import FiniteField
 from sage.rings.integer import Integer
 from sage.rings.finite_rings.element_givaro import Cache_givaro
-from sage.libs.pari.all import pari
-from sage.misc.superseded import deprecated_function_alias
+from sage.libs.pari import pari
 
 
 class FiniteField_givaro(FiniteField):
@@ -39,7 +38,7 @@ class FiniteField_givaro(FiniteField):
     - ``name`` -- (default: ``'a'``) variable used for
       :meth:`~sage.rings.finite_rings.element_givaro.FiniteField_givaroElement.poly_repr()`
 
-    - ``modulus`` -- A minimal polynomial to use for reduction.
+    - ``modulus`` -- a minimal polynomial to use for reduction
 
     - ``repr`` -- (default: ``'poly'``) controls the way elements are printed
       to the user:
@@ -51,15 +50,13 @@ class FiniteField_givaro(FiniteField):
       - 'poly': repr is
         :meth:`~sage.rings.finite_rings.element_givaro.FiniteField_givaroElement.poly_repr()`
 
-    - cache -- (default: ``False``) if ``True`` a cache of all elements of
-      this field is created. Thus, arithmetic does not create new elements
-      which speeds calculations up. Also, if many elements are needed during a
-      calculation this cache reduces the memory requirement as at most
+    - ``cache`` -- boolean (default: ``False``); if ``True`` a cache of all
+      elements of this field is created. Thus, arithmetic does not create new
+      elements which speeds calculations up. Also, if many elements are needed
+      during a calculation this cache reduces the memory requirement as at most
       :meth:`order` elements are created.
 
-    OUTPUT:
-
-    Givaro finite field with characteristic `p` and cardinality `p^n`.
+    OUTPUT: Givaro finite field with characteristic `p` and cardinality `p^n`
 
     EXAMPLES:
 
@@ -104,7 +101,7 @@ class FiniteField_givaro(FiniteField):
         sage: GF(1009, impl='givaro', modulus='conway').modulus()
         x + 998
     """
-    def __init__(self, q, name="a", modulus=None, repr="poly", cache=False):
+    def __init__(self, q, name='a', modulus=None, repr='poly', cache=False):
         """
         Initialize ``self``.
 
@@ -161,9 +158,7 @@ class FiniteField_givaro(FiniteField):
         """
         Return the cardinality of this field.
 
-        OUTPUT:
-
-        Integer -- the number of elements in ``self``.
+        OUTPUT: integer; the number of elements in ``self``
 
         EXAMPLES::
 
@@ -178,9 +173,7 @@ class FiniteField_givaro(FiniteField):
         r"""
         If the cardinality of ``self`` is `p^n`, then this returns `n`.
 
-        OUTPUT:
-
-        Integer -- the degree
+        OUTPUT: integer; the degree
 
         EXAMPLES::
 
@@ -334,10 +327,10 @@ class FiniteField_givaro(FiniteField):
 
         We can coerce from PARI finite field implementations::
 
-            sage: K.<a> = GF(3^10, impl="givaro")
+            sage: K.<a> = GF(3^10, impl='givaro')
             sage: a^20
             2*a^9 + 2*a^8 + a^7 + 2*a^5 + 2*a^4 + 2*a^3 + 1
-            sage: M.<c> = GF(3^10, impl="pari_ffelt")
+            sage: M.<c> = GF(3^10, impl='pari_ffelt')
             sage: K(c^20)
             2*a^9 + 2*a^8 + a^7 + 2*a^5 + 2*a^4 + 2*a^3 + 1
 
@@ -409,7 +402,7 @@ class FiniteField_givaro(FiniteField):
 
     def prime_subfield(self):
         r"""
-        Return the prime subfield `\GF{p}` of self if ``self`` is `\GF{p^n}`.
+        Return the prime subfield `\GF{p}` of ``self`` if ``self`` is `\GF{p^n}`.
 
         EXAMPLES::
 
@@ -440,9 +433,7 @@ class FiniteField_givaro(FiniteField):
 
         - ``n`` -- log representation of a finite field element
 
-        OUTPUT:
-
-        integer representation of a finite field element.
+        OUTPUT: integer representation of a finite field element
 
         EXAMPLES::
 
@@ -464,9 +455,7 @@ class FiniteField_givaro(FiniteField):
 
         - ``n`` -- integer representation of a finite field element
 
-        OUTPUT:
-
-        log representation of ``n``
+        OUTPUT: log representation of ``n``
 
         EXAMPLES::
 
@@ -498,8 +487,6 @@ class FiniteField_givaro(FiniteField):
         """
         return self._cache.fetch_int(n)
 
-    fetch_int = deprecated_function_alias(33941, from_integer)
-
     def _pari_modulus(self):
         """
         Return the modulus of ``self`` in a format for PARI.
@@ -577,7 +564,7 @@ class FiniteField_givaro(FiniteField):
         """
         INPUT:
 
-        -  ``n`` -- an integer (default: 1)
+        - ``n`` -- integer (default: 1)
 
         OUTPUT:
 
