@@ -2,14 +2,16 @@
 r"""
 Drinfeld modules over rings of characteristic zero
 
-This module provides the class
-:class:`sage.rings.function_fields.drinfeld_module.charzero_drinfeld_module.DrinfeldModule_charzero`,
-which inherits
+This module provides the classes
+:class:`sage.rings.function_fields.drinfeld_module.charzero_drinfeld_module.DrinfeldModule_charzero` and
+:class:`sage.rings.function_fields.drinfeld_module.charzero_drinfeld_module.DrinfeldModule_rational`,
+which both inherit
 :class:`sage.rings.function_fields.drinfeld_module.drinfeld_module.DrinfeldModule`.
 
 AUTHORS:
 
 - David Ayotte (2023-09)
+- Xavier Caruso (2024-12) - computation of class polynomials
 """
 
 # *****************************************************************************
@@ -25,11 +27,16 @@ AUTHORS:
 from .drinfeld_module import DrinfeldModule
 
 from sage.rings.integer_ring import ZZ
+from sage.rings.infinity import Infinity
+
+from sage.matrix.constructor import matrix
+from sage.modules.free_module_element import vector
 
 from sage.misc.cachefunc import cached_method
 from sage.misc.lazy_import import lazy_import
 
 lazy_import('sage.rings.lazy_series_ring', 'LazyPowerSeriesRing')
+lazy_import('sage.rings.power_series_ring', 'PowerSeriesRing')
 
 
 class DrinfeldModule_charzero(DrinfeldModule):
@@ -149,7 +156,7 @@ class DrinfeldModule_charzero(DrinfeldModule):
             c += self._compute_coefficient_exp(i)*self._compute_coefficient_log(j)**(q**i)
         return -c
 
-    def exponential(self, name='z'):
+    def exponential(self, prec=Infinity, name='z'):
         r"""
         Return the exponential of this Drinfeld module.
 
@@ -158,28 +165,38 @@ class DrinfeldModule_charzero(DrinfeldModule):
 
         INPUT:
 
+        - ``prec`` -- an integer or ``Infinity`` (default: ``Infinity``);
+          the precision at which the series is returned; if ``Infinity``,
+          a lazy power series in returned, else, a classical power series
+          is returned.
+
         - ``name`` -- string (default: ``'z'``); the name of the
           generator of the lazy power series ring
 
-        OUTPUT: a lazy power series over the base field
-
         EXAMPLES::
 
             sage: A = GF(2)['T']
             sage: K.<T> = Frac(A)
             sage: phi = DrinfeldModule(A, [T, 1])
             sage: q = A.base_ring().cardinality()
+
+        When ``prec`` is ``Infinity`` (which is the default),
+        the exponential is returned as a lazy power series, meaning
+        that any of its coefficients can be computed on demands::
+
             sage: exp = phi.exponential(); exp
             z + ((1/(T^2+T))*z^2) + ((1/(T^8+T^6+T^5+T^3))*z^4) + O(z^8)
-
-        The exponential is returned as a lazy power series, meaning that
-        any of its coefficients can be computed on demands::
-
             sage: exp[2^4]
             1/(T^64 + T^56 + T^52 + ... + T^27 + T^23 + T^15)
             sage: exp[2^5]
             1/(T^160 + T^144 + T^136 + ... + T^55 + T^47 + T^31)
 
+        On the contrary, when ``prec`` is a finite number, all the
+        required coefficients are computed at once::
+
+            sage: phi.exponential(prec=10)
+            z + (1/(T^2 + T))*z^2 + (1/(T^8 + T^6 + T^5 + T^3))*z^4 + (1/(T^24 + T^20 + T^18 + T^17 + T^14 + T^13 + T^11 + T^7))*z^8 + O(z^10)
+
         Example in higher rank::
 
             sage: A = GF(5)['T']
@@ -216,7 +233,6 @@ class DrinfeldModule_charzero(DrinfeldModule):
         See section 4.6 of [Gos1998]_ for the definition of the
         exponential.
         """
-        L = LazyPowerSeriesRing(self._base, name)
         zero = self._base.zero()
         q = self._Fq.cardinality()
 
@@ -228,7 +244,12 @@ class DrinfeldModule_charzero(DrinfeldModule):
                 return self._compute_coefficient_exp(v)
             else:
                 return zero
-        return L(coeff_exp, valuation=1)
+
+        if prec is Infinity:
+            L = LazyPowerSeriesRing(self._base, name)
+            return L(coeff_exp, valuation=1)
+        L = PowerSeriesRing(self._base, name, default_prec=prec)
+        return L([0] + [coeff_exp(i) for i in range(1,prec)], prec=prec)
 
     @cached_method
     def _compute_coefficient_log(self, k):
@@ -264,7 +285,7 @@ class DrinfeldModule_charzero(DrinfeldModule):
                 c += self._compute_coefficient_log(i)*self._gen[j]**(q**i)
         return c/(T - T**(q**k))
 
-    def logarithm(self, name='z'):
+    def logarithm(self, prec=Infinity, name='z'):
         r"""
         Return the logarithm of the given Drinfeld module.
 
@@ -275,27 +296,36 @@ class DrinfeldModule_charzero(DrinfeldModule):
 
         INPUT:
 
+        - ``prec`` -- an integer or ``Infinity`` (default: ``Infinity``);
+          the precision at which the series is returned; if ``Infinity``,
+          a lazy power series in returned
+
         - ``name`` -- string (default: ``'z'``); the name of the
           generator of the lazy power series ring
 
-        OUTPUT: a lazy power series over the base field
-
         EXAMPLES::
 
             sage: A = GF(2)['T']
             sage: K.<T> = Frac(A)
             sage: phi = DrinfeldModule(A, [T, 1])
+
+        When ``prec`` is ``Infinity`` (which is the default),
+        the logarithm is returned as a lazy power series, meaning
+        that any of its coefficients can be computed on demands::
+
             sage: log = phi.logarithm(); log
             z + ((1/(T^2+T))*z^2) + ((1/(T^6+T^5+T^3+T^2))*z^4) + O(z^8)
-
-        The logarithm is returned as a lazy power series, meaning that
-        any of its coefficients can be computed on demands::
-
             sage: log[2^4]
             1/(T^30 + T^29 + T^27 + ... + T^7 + T^5 + T^4)
             sage: log[2^5]
             1/(T^62 + T^61 + T^59 + ... + T^8 + T^6 + T^5)
 
+        If ``prec`` is a finite number, all the
+        required coefficients are computed at once::
+
+            sage: phi.logarithm(prec=10)
+            z + (1/(T^2 + T))*z^2 + (1/(T^6 + T^5 + T^3 + T^2))*z^4 + (1/(T^14 + T^13 + T^11 + T^10 + T^7 + T^6 + T^4 + T^3))*z^8 + O(z^10)
+
         Example in higher rank::
 
             sage: A = GF(5)['T']
@@ -317,7 +347,6 @@ class DrinfeldModule_charzero(DrinfeldModule):
             sage: log[2**3] == -1/((T**q - T)*(T**(q**2) - T)*(T**(q**3) - T))  # expected value
             True
         """
-        L = LazyPowerSeriesRing(self._base, name)
         q = self._Fq.cardinality()
 
         def coeff_log(k):
@@ -328,7 +357,12 @@ class DrinfeldModule_charzero(DrinfeldModule):
                 return self._compute_coefficient_log(v)
             else:
                 return self._base.zero()
-        return L(coeff_log, valuation=1)
+
+        if prec is Infinity:
+            L = LazyPowerSeriesRing(self._base, name)
+            return L(coeff_log, valuation=1)
+        L = PowerSeriesRing(self._base, name, default_prec=prec)
+        return L([0] + [coeff_log(i) for i in range(1, prec)], prec=prec)
 
     @cached_method
     def _compute_goss_polynomial(self, n, q, poly_ring, X):
@@ -414,3 +448,225 @@ class DrinfeldModule_charzero(DrinfeldModule):
         X = poly_ring.gen()
         q = self._Fq.cardinality()
         return self._compute_goss_polynomial(n, q, poly_ring, X)
+
+
+class DrinfeldModule_rational(DrinfeldModule_charzero):
+    """
+    A class for Drinfeld modules defined over the fraction
+    field of the underlying function field.
+
+    TESTS::
+
+        sage: q = 9
+        sage: Fq = GF(q)
+        sage: A = Fq['T']
+        sage: K.<T> = Frac(A)
+        sage: C = DrinfeldModule(A, [T, 1]); C
+        Drinfeld module defined by T |--> t + T
+        sage: type(C)
+        <class 'sage.rings.function_field.drinfeld_modules.charzero_drinfeld_module.DrinfeldModule_rational_with_category'>
+    """
+    def coefficient_in_function_ring(self, n):
+        r"""
+        Return the `n`-th coefficient of this Drinfeld module as
+        an element of the underlying function ring.
+
+        INPUT:
+
+        - ``n`` -- an integer
+
+        EXAMPLES::
+
+            sage: q = 5
+            sage: Fq = GF(q)
+            sage: A = Fq['T']
+            sage: R = Fq['U']
+            sage: K.<U> = Frac(R)
+            sage: phi = DrinfeldModule(A, [U, 0, U^2, U^3])
+            sage: phi.coefficient_in_function_ring(2)
+            T^2
+
+        Compare with the method meth:`coefficient`::
+
+            sage: phi.coefficient(2)
+            U^2
+
+        If the required coefficient is not a polynomials,
+        an error is raised::
+
+            sage: psi = DrinfeldModule(A, [U, 1/U])
+            sage: psi.coefficient_in_function_ring(0)
+            T
+            sage: psi.coefficient_in_function_ring(1)
+            Traceback (most recent call last):
+            ...
+            ValueError: coefficient is not polynomial
+        """
+        A = self.function_ring()
+        g = self.coefficient(n)
+        g = g.backend(force=True)
+        if g.denominator().is_one():
+            return A(g.numerator().list())
+        else:
+            raise ValueError("coefficient is not polynomial")
+
+    def coefficients_in_function_ring(self, sparse=True):
+        r"""
+        Return the coefficients of this Drinfeld module as elements
+        of the underlying function ring.
+
+        INPUT:
+
+        - ``sparse`` -- a boolean (default: ``True``); if ``True``,
+          only return the nonzero coefficients; otherwise, return
+          all of them.
+
+        EXAMPLES::
+
+            sage: q = 5
+            sage: Fq = GF(q)
+            sage: A = Fq['T']
+            sage: R = Fq['U']
+            sage: K.<U> = Frac(R)
+            sage: phi = DrinfeldModule(A, [U, 0, U^2, U^3])
+            sage: phi.coefficients_in_function_ring()
+            [T, T^2, T^3]
+            sage: phi.coefficients_in_function_ring(sparse=False)
+            [T, 0, T^2, T^3]
+
+        Compare with the method meth:`coefficients`::
+
+            sage: phi.coefficients()
+            [U, U^2, U^3]
+
+        If the coefficients are not polynomials, an error is raised::
+
+            sage: psi = DrinfeldModule(A, [U, 1/U])
+            sage: psi.coefficients_in_function_ring()
+            Traceback (most recent call last):
+            ...
+            ValueError: coefficients are not polynomials
+        """
+        A = self.function_ring()
+        gs = []
+        for g in self.coefficients(sparse):
+            g = g.backend(force=True)
+            if g.denominator().is_one():
+                gs.append(A(g.numerator().list()))
+            else:
+                raise ValueError("coefficients are not polynomials")
+        return gs
+
+    def class_polynomial(self):
+        r"""
+        Return the class polynomial, that is the Fitting ideal
+        of the class module, of this Drinfeld module.
+
+        We refer to [Tae2012]_ for the definition and basic
+        properties of the class module.
+
+        EXAMPLES:
+
+        We check that the class module of the Carlitz module
+        is trivial::
+
+            sage: q = 5
+            sage: Fq = GF(q)
+            sage: A = Fq['T']
+            sage: K.<T> = Frac(A)
+            sage: C = DrinfeldModule(A, [T, 1]); C
+            Drinfeld module defined by T |--> t + T
+            sage: C.class_polynomial()
+            1
+
+        When the coefficients of the Drinfeld module have small
+        enough degrees, the class module is always trivial::
+
+            sage: gs = [T] + [A.random_element(degree = q^i)
+            ....:             for i in range(1, 5)]
+            sage: phi = DrinfeldModule(A, gs)
+            sage: phi.class_polynomial()
+            1
+
+        Here is an example with a nontrivial class module::
+
+            sage: phi = DrinfeldModule(A, [T, 2*T^14 + 2*T^4])
+            sage: phi.class_polynomial()
+            T + 3
+
+        TESTS:
+
+        The Drinfeld module must have polynomial coefficients::
+
+            sage: phi = DrinfeldModule(A, [T, 1/T])
+            sage: phi.class_polynomial()
+            Traceback (most recent call last):
+            ...
+            ValueError: coefficients are not polynomials
+        """
+        # The algorithm is based on the following remark:
+        # writing phi_T = g_0 + g_1*tau + ... + g_r*tau^r,
+        # if s > deg(g_i/(q^i - 1)) - 1 for all i, then the
+        # class module is equal to
+        #   H := E(Kinfty/A) / < T^(-s), T^(-s-1), ... >
+        # where E(Kinfty/A) is Kinfty/A equipped with the
+        # A-module structure coming from phi.
+
+        A = self.function_ring()
+        Fq = A.base_ring()
+        q = Fq.cardinality()
+        r = self.rank()
+
+        # We compute the bound s
+        gs = self.coefficients_in_function_ring(sparse=False)
+        s = max(gs[i].degree() // (q**i - 1) for i in range(1, r+1))
+        if s == 0:
+            return A.one()
+
+        # We compute the matrix of phi_T acting on the quotient
+        #   M := (Kinfty/A) / < T^(-s), T^(-s-1), ... >
+        # (for the standard structure of A-module!)
+        M = matrix(Fq, s)
+        qk = 1
+        for k in range(r+1):
+            for i in range(s):
+                e = (i+1)*qk
+                for j in range(s):
+                    e -= 1
+                    if e < 0:
+                        break
+                    M[i, j] += gs[k][e]
+            qk *= q
+
+        # We compute the subspace of E(Kinfty/A) (for the twisted
+        # structure of A-module!)
+        #   V = < T^(-s), T^(-s+1), ... >
+        # It is also the phi_T-saturation of T^(-s+1) in M, i.e.
+        # the Fq-vector space generated by the phi_T^i(T^(-s+1))
+        # for i varying in NN.
+        v = vector(Fq, s)
+        v[s-1] = 1
+        vs = [v]
+        for i in range(s-1):
+            v = v*M
+            vs.append(v)
+        V = matrix(vs)
+        V.echelonize()
+
+        # We compute the action of phi_T on H = M/V
+        # as an Fq-linear map (encoded in the matrix N)
+        dim = V.rank()
+        pivots = V.pivots()
+        j = ip = 0
+        for i in range(dim, s):
+            while ip < dim and j == pivots[ip]:
+                j += 1
+            ip += 1
+            V[i,j] = 1
+        N = (V * M * ~V).submatrix(dim, dim)
+
+        # The class module is now H where the action of T
+        # is given by the matrix N
+        # The class polynomial is then the characteristic
+        # polynomial of N
+        return A(N.charpoly())
