@@ -68,6 +68,7 @@ Riemann-Roch space.
 
 EXAMPLES::
 
+    sage: # long time
     sage: P2.<x,y,z> = ProjectiveSpace(GF(17), 2)
     sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
     sage: F = C.function_field()
@@ -154,6 +155,7 @@ class JacobianPoint(JacobianPoint_base):
 
     EXAMPLES::
 
+        sage: # long time
         sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
         sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
         sage: b = C([0,1,0]).place()
@@ -176,6 +178,7 @@ class JacobianPoint(JacobianPoint_base):
 
         TESTS::
 
+            sage: # long time
             sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
             sage: b = C([0,1,0]).place()
@@ -196,6 +199,7 @@ class JacobianPoint(JacobianPoint_base):
 
         EXAMPLES::
 
+            sage: # long time
             sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
             sage: h = C.function(y/x).divisor_of_poles()
@@ -218,6 +222,7 @@ class JacobianPoint(JacobianPoint_base):
 
         EXAMPLES::
 
+            sage: # long time
             sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
             sage: F = C.function_field()
@@ -242,6 +247,7 @@ class JacobianPoint(JacobianPoint_base):
 
         EXAMPLES::
 
+            sage: # long time
             sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
             sage: h = C.function(y/x).divisor_of_poles()
@@ -275,6 +281,7 @@ class JacobianPoint(JacobianPoint_base):
 
         EXAMPLES::
 
+            sage: # long time
             sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
             sage: h = C.function(y/x).divisor_of_poles()
@@ -306,6 +313,7 @@ class JacobianPoint(JacobianPoint_base):
 
         EXAMPLES::
 
+            sage: # long time
             sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
             sage: F = C.function_field()
@@ -340,6 +348,7 @@ class JacobianPoint(JacobianPoint_base):
 
         EXAMPLES::
 
+            sage: # long time
             sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
             sage: h = C.function(y/x).divisor_of_poles()
@@ -363,6 +372,7 @@ class JacobianPoint(JacobianPoint_base):
 
         EXAMPLES::
 
+            sage: # long time
             sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
             sage: h = C.function(y/x).divisor_of_poles()
@@ -394,6 +404,7 @@ class JacobianPoint(JacobianPoint_base):
 
         EXAMPLES::
 
+            sage: # long time
             sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
             sage: h = C.function(y/x).divisor_of_poles()
@@ -426,6 +437,7 @@ class JacobianPoint(JacobianPoint_base):
 
         EXAMPLES::
 
+            sage: # long time
             sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
             sage: h = C.function(y/x).divisor_of_poles()
@@ -450,6 +462,7 @@ class JacobianPoint(JacobianPoint_base):
 
         EXAMPLES::
 
+            sage: # long time
             sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
             sage: F = C.function_field()
@@ -493,6 +506,7 @@ class JacobianGroupEmbedding(Map):
 
     EXAMPLES::
 
+        sage: # long time
         sage: k = GF(5)
         sage: P2.<x,y,z> = ProjectiveSpace(k, 2)
         sage: C = Curve(x^3 + z^3 - y^2*z, P2)
@@ -514,6 +528,7 @@ class JacobianGroupEmbedding(Map):
 
         TESTS::
 
+            sage: # long time
             sage: k = GF(5)
             sage: P2.<x,y,z> = ProjectiveSpace(k, 2)
             sage: C = Curve(x^3 + z^3 - y^2*z, P2)
@@ -538,6 +553,7 @@ class JacobianGroupEmbedding(Map):
 
         TESTS::
 
+            sage: # long time
             sage: k = GF(5)
             sage: P2.<x,y,z> = ProjectiveSpace(k, 2)
             sage: C = Curve(x^3 + z^3 - y^2*z, P2)
@@ -561,6 +577,7 @@ class JacobianGroupEmbedding(Map):
 
         TESTS::
 
+            sage: # long time
             sage: k = GF(5)
             sage: P2.<x,y,z> = ProjectiveSpace(k, 2)
             sage: C = Curve(x^3 + z^3 - y^2*z, P2)
@@ -592,6 +609,7 @@ class JacobianGroup(UniqueRepresentation, JacobianGroup_base):
 
     EXAMPLES::
 
+        sage: # long time
         sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
         sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
         sage: h = C.function(y/x).divisor_of_poles()
@@ -609,6 +627,7 @@ class JacobianGroup(UniqueRepresentation, JacobianGroup_base):
 
         TESTS::
 
+            sage: # long time
             sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
             sage: h = C.function(y/x).divisor_of_poles()
@@ -619,6 +638,7 @@ class JacobianGroup(UniqueRepresentation, JacobianGroup_base):
 
         D0 = base_div
 
+        self._base_div_degree = base_div.degree()
         self._V_cache = 10*[None]
 
         V_cache = self._V_cache
@@ -672,6 +692,7 @@ class JacobianGroup(UniqueRepresentation, JacobianGroup_base):
 
         EXAMPLES::
 
+            sage: # long time
             sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
             sage: h = C.function(y/x).divisor_of_poles()
@@ -693,6 +714,7 @@ class JacobianGroup(UniqueRepresentation, JacobianGroup_base):
 
         TESTS:
 
+            sage: # long time
             sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
             sage: h = C.function(y/x).divisor_of_poles()
@@ -719,6 +741,7 @@ class JacobianGroup(UniqueRepresentation, JacobianGroup_base):
 
         TESTS::
 
+            sage: # long time
             sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
             sage: h = C.function(y/x).divisor_of_poles()
@@ -760,10 +783,12 @@ class JacobianGroup(UniqueRepresentation, JacobianGroup_base):
             if x.degree() == 0:
                 return self.point(x)
             if x.is_effective():
+                if x.degree() != self._base_div_degree:
+                    raise ValueError(f"effective divisor is not of degree {self._base_div_degree}")
                 wd = self._wd_from_divisor(x)
                 return self.element_class(self, wd)
 
-        raise ValueError(f"Cannot construct a point from {x}")
+        raise ValueError(f"cannot construct a point from {x}")
 
     def point(self, divisor):
         """
@@ -775,6 +800,7 @@ class JacobianGroup(UniqueRepresentation, JacobianGroup_base):
 
         EXAMPLES::
 
+            sage: # long time
             sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
             sage: h = C.function(y/x).divisor_of_poles()
@@ -808,6 +834,7 @@ class JacobianGroup(UniqueRepresentation, JacobianGroup_base):
 
         EXAMPLES::
 
+            sage: # long time
             sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
             sage: h = C.function(y/x).divisor_of_poles()
@@ -839,6 +866,7 @@ class JacobianGroup_finite_field(JacobianGroup, JacobianGroup_finite_field_base)
 
     EXAMPLES::
 
+        sage: # long time
         sage: k = GF(7)
         sage: P2.<x,y,z> = ProjectiveSpace(k, 2)
         sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
@@ -862,6 +890,7 @@ class JacobianGroup_finite_field(JacobianGroup, JacobianGroup_finite_field_base)
 
         TESTS::
 
+            sage: # long time
             sage: k = GF(7)
             sage: P2.<x,y,z> = ProjectiveSpace(k, 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
@@ -952,6 +981,7 @@ class JacobianGroup_finite_field(JacobianGroup, JacobianGroup_finite_field_base)
 
         TESTS::
 
+            sage: # long time
             sage: k = GF(7)
             sage: A.<x,y> = AffineSpace(k,2)
             sage: C = Curve(y^2 + x^3 + 2*x + 1).projective_closure()
@@ -986,6 +1016,7 @@ class Jacobian(UniqueRepresentation, Jacobian_base):
 
         TESTS::
 
+            sage: # long time
             sage: P2.<x,y,z> = ProjectiveSpace(GF(7), 2)
             sage: C = Curve(x^3 + 5*z^3 - y^2*z, P2)
             sage: J = C.jacobian(model='km_large')
@@ -993,6 +1024,7 @@ class Jacobian(UniqueRepresentation, Jacobian_base):
 
         ::
 
+            sage: # long time
             sage: J = C.jacobian(model='km_unknown')
             Traceback (most recent call last):
             ...
