@@ -158,7 +158,7 @@ from sage.misc.lazy_import import lazy_import
 from sage.rings.finite_rings.integer_mod_ring import Zmod
 from sage.rings.infinity import infinity, InfinityElement
 from sage.rings.integer import Integer
-from sage.rings.polynomial.polynomial_ring import PolynomialRing_general
+from sage.rings.polynomial.polynomial_ring import PolynomialRing_generic
 from sage.rings.power_series_ring_element import PowerSeries
 from sage.structure.richcmp import richcmp
 
@@ -406,7 +406,7 @@ class MPowerSeries(PowerSeries):
                 self._bg_value = parent._send_to_bg(x).add_bigoh(prec)
 
         # test whether x coerces to underlying polynomial ring of parent
-        elif isinstance(xparent, PolynomialRing_general):
+        elif isinstance(xparent, PolynomialRing_generic):
             self._bg_value = parent._send_to_bg(x).add_bigoh(prec)
 
         else:
@@ -1099,7 +1099,7 @@ class MPowerSeries(PowerSeries):
             return self.change_ring(Zmod(other))
         raise NotImplementedError("Mod on multivariate power series ring elements not defined except modulo an integer.")
 
-    def monomial_coefficients(self):
+    def monomial_coefficients(self, copy=None):
         """
         Return underlying dictionary with keys the exponents and values the
         coefficients of this power series.
@@ -1150,7 +1150,7 @@ class MPowerSeries(PowerSeries):
             Field
             sage: t = M.gens()
             sage: f = 1/2*t[0]^3*t[1]^3*t[2]^2 + 2/3*t[0]*t[2]^6*t[3] \
-            - t[0]^3*t[1]^3*t[3]^3 - 1/4*t[0]*t[1]*t[2]^7 + M.O(10)
+            ....: - t[0]^3*t[1]^3*t[3]^3 - 1/4*t[0]*t[1]*t[2]^7 + M.O(10)
             sage: f
             1/2*t0^3*t1^3*t2^2 + 2/3*t0*t2^6*t3 - t0^3*t1^3*t3^3
             - 1/4*t0*t1*t2^7 + O(t0, t1, t2, t3)^10
@@ -1299,7 +1299,7 @@ class MPowerSeries(PowerSeries):
             sage: H = QQ[['x,y,z']]
             sage: (x,y,z) = H.gens()
             sage: h = -x*y^4*z^7 - 1/4*y*z^12 + 1/2*x^7*y^5*z^2 \
-            + 2/3*y^6*z^8 + H.O(15)
+            ....: + 2/3*y^6*z^8 + H.O(15)
             sage: h.V(3)
             -x^3*y^12*z^21 - 1/4*y^3*z^36 + 1/2*x^21*y^15*z^6 + 2/3*y^18*z^24 + O(x, y, z)^45
         """
@@ -1382,7 +1382,7 @@ class MPowerSeries(PowerSeries):
             Multivariate Power Series Ring in t0, t1, t2, t3 over Rational Field
             sage: t = M.gens()
             sage: f = 1/2*t[0]^3*t[1]^3*t[2]^2 + 2/3*t[0]*t[2]^6*t[3] \
-            - t[0]^3*t[1]^3*t[3]^3 - 1/4*t[0]*t[1]*t[2]^7 + M.O(10)
+            ....: - t[0]^3*t[1]^3*t[3]^3 - 1/4*t[0]*t[1]*t[2]^7 + M.O(10)
             sage: f
             1/2*t0^3*t1^3*t2^2 + 2/3*t0*t2^6*t3 - t0^3*t1^3*t3^3
             - 1/4*t0*t1*t2^7 + O(t0, t1, t2, t3)^10
