@@ -21,13 +21,14 @@ AUTHORS:
 # *****************************************************************************
 
 from copy import copy
-from sage.rings.ring import CommutativeRing
+
 from sage.categories.complete_discrete_valuation import CompleteDiscreteValuationRings, CompleteDiscreteValuationFields
 from sage.structure.category_object import check_default_category
-from sage.structure.parent import Parent
 from sage.rings.integer import Integer
 from sage.rings.integer_ring import ZZ
 from sage.rings.infinity import Infinity
+from sage.rings.ring import CommutativeRing
+
 
 class LocalGeneric(CommutativeRing):
     def __init__(self, base, prec, names, element_class, category=None):
@@ -36,15 +37,15 @@ class LocalGeneric(CommutativeRing):
 
         EXAMPLES::
 
-            sage: R = Zp(5) #indirect doctest
+            sage: R = Zp(5)  # indirect doctest
             sage: R.precision_cap()
             20
 
-        In :trac:`14084`, the category framework has been implemented for p-adic rings::
+        In :issue:`14084`, the category framework has been implemented for `p`-adic rings::
 
-            sage: TestSuite(R).run()
+            sage: TestSuite(R).run()                                                    # needs sage.geometry.polyhedron
             sage: K = Qp(7)
-            sage: TestSuite(K).run()
+            sage: TestSuite(K).run()                                                    # needs sage.geometry.polyhedron
 
         TESTS::
 
@@ -73,7 +74,8 @@ class LocalGeneric(CommutativeRing):
         category = category.Metric().Complete().Infinite()
         if default_category is not None:
             category = check_default_category(default_category, category)
-        Parent.__init__(self, base, names=(names,), normalize=False, category=category)
+        CommutativeRing.__init__(self, base, names=(names,),
+                                 normalize=False, category=category)
 
     def is_capped_relative(self):
         r"""
@@ -228,7 +230,7 @@ class LocalGeneric(CommutativeRing):
 
         EXAMPLES::
 
-            sage: latex(Zq(27,names='a')) #indirect doctest
+            sage: latex(Zq(27,names='a'))  # indirect doctest                           # needs sage.libs.ntl
             \Bold{Z}_{3^{3}}
         """
         return self._repr_(do_latex=True)
@@ -242,14 +244,14 @@ class LocalGeneric(CommutativeRing):
         The following arguments are applied to every ring in the tower:
 
         - ``type`` -- string, the precision type
-        - ``p`` -- the prime of the ground ring.  Defining polynomials
-                   will be converted to the new base rings.
+        - ``p`` -- the prime of the ground ring; defining polynomials
+          will be converted to the new base rings
         - ``print_mode`` -- string
-        - ``print_pos`` -- bool
+        - ``print_pos`` -- boolean
         - ``print_sep`` -- string
-        - ``print_alphabet`` -- dict
-        - ``show_prec`` -- bool
-        - ``check`` -- bool
+        - ``print_alphabet`` -- dictionary
+        - ``show_prec`` -- boolean
+        - ``check`` -- boolean
         - ``label`` -- string (only for lattice precision)
 
         The following arguments are only applied to the top ring in the tower:
@@ -263,19 +265,19 @@ class LocalGeneric(CommutativeRing):
 
         The following arguments have special behavior:
 
-        - ``prec`` -- integer.  If the precision is increased on an extension ring,
-                       the precision on the base is increased as necessary (respecting ramification).
-                       If the precision is decreased, the precision of the base is unchanged.
+        - ``prec`` -- integer; if the precision is increased on an extension ring,
+          the precision on the base is increased as necessary (respecting ramification).
+          If the precision is decreased, the precision of the base is unchanged.
 
-        - ``field`` -- bool.  If ``True``, switch to a tower of fields via the fraction field.
-                        If False, switch to a tower of rings of integers.
+        - ``field`` -- boolean; if ``True``, switch to a tower of fields via the fraction field
+          If ``False``, switch to a tower of rings of integers
 
-        - ``q`` -- prime power.  Replace the initial unramified extension of `\QQ_p` or `\ZZ_p`
-                    with an unramified extension of residue cardinality `q`.
-                    If the initial extension is ramified, add in an unramified extension.
+        - ``q`` -- prime power; replace the initial unramified extension of `\QQ_p` or `\ZZ_p`
+          with an unramified extension of residue cardinality `q`.
+          If the initial extension is ramified, add in an unramified extension.
 
-        - ``base`` -- ring or field. Use a specific base ring instead of recursively
-                       calling :meth:`change` down the tower.
+        - ``base`` -- ring or field; use a specific base ring instead of recursively
+          calling :meth:`change` down the tower
 
         See the :mod:`constructors <sage.rings.padics.factory>` for more details on the
         meaning of these arguments.
@@ -289,7 +291,7 @@ class LocalGeneric(CommutativeRing):
 
         or the precision type::
 
-            sage: Zp(5).change(type="capped-abs")
+            sage: Zp(5).change(type='capped-abs')
             5-adic Ring with capped absolute precision 20
 
         or even the prime::
@@ -310,6 +312,7 @@ class LocalGeneric(CommutativeRing):
 
         Changing print mode to 'digits' works for Eisenstein extensions::
 
+            sage: # needs sage.libs.ntl
             sage: S.<x> = ZZ[]
             sage: W.<w> = Zp(3).extension(x^4 + 9*x^2 + 3*x - 3)
             sage: W.print_mode()
@@ -319,6 +322,7 @@ class LocalGeneric(CommutativeRing):
 
         You can change extensions::
 
+            sage: # needs sage.libs.flint
             sage: K.<a> = QqFP(125, prec=4)
             sage: K.change(q=64)
             2-adic Unramified Extension Field in a defined by x^6 + x^4 + x^3 + x + 1
@@ -328,11 +332,12 @@ class LocalGeneric(CommutativeRing):
 
         and variable names::
 
-            sage: K.change(names='b')
+            sage: K.change(names='b')                                                   # needs sage.libs.flint
             5-adic Unramified Extension Field in b defined by x^3 + 3*x + 3
 
         and precision::
 
+            sage: # needs sage.libs.flint
             sage: Kup = K.change(prec=8); Kup
             5-adic Unramified Extension Field in a defined by x^3 + 3*x + 3
             sage: Kup.precision_cap()
@@ -342,6 +347,7 @@ class LocalGeneric(CommutativeRing):
 
         If you decrease the precision, the precision of the base stays the same::
 
+            sage: # needs sage.libs.flint
             sage: Kdown = K.change(prec=2); Kdown
             5-adic Unramified Extension Field in a defined by x^3 + 3*x + 3
             sage: Kdown.precision_cap()
@@ -351,6 +357,7 @@ class LocalGeneric(CommutativeRing):
 
         Changing the prime works for extensions::
 
+            sage: # needs sage.libs.ntl
             sage: x = polygen(ZZ)
             sage: R.<a> = Zp(5).extension(x^2 + 2)
             sage: S = R.change(p=7)
@@ -364,6 +371,7 @@ class LocalGeneric(CommutativeRing):
 
         ::
 
+            sage: # needs sage.libs.ntl
             sage: R.<a> = Zq(5^3)
             sage: S = R.change(prec=50)
             sage: S.defining_polynomial(exact=True)
@@ -382,6 +390,7 @@ class LocalGeneric(CommutativeRing):
 
         The `secure` attribute for relaxed type is copied::
 
+            sage: # needs sage.libs.flint
             sage: R = ZpER(5, secure=True); R
             5-adic Ring handled with relaxed arithmetics
             sage: K = R.change(field=True); K
@@ -391,6 +400,7 @@ class LocalGeneric(CommutativeRing):
 
         The `check=False` option works for relaxed type::
 
+            sage: # needs sage.libs.flint
             sage: R = ZpER(5) ; R
             5-adic Ring handled with relaxed arithmetics
             sage: K = R.change(field=True, check=False) ; K
@@ -443,7 +453,7 @@ class LocalGeneric(CommutativeRing):
                 kwds['type'] = 'capped-rel'
             elif self._prec_type() == 'fixed-mod':
                 kwds['type'] = 'floating-point'
-                kwds['show_prec'] = False # This can be removed once printing of fixed mod elements is changed.
+                kwds['show_prec'] = False  # This can be removed once printing of fixed mod elements is changed.
 
         # There are two kinds of functors possible:
         # CompletionFunctor and AlgebraicExtensionFunctor
@@ -452,7 +462,7 @@ class LocalGeneric(CommutativeRing):
             functor.extras = copy(functor.extras)
             functor.extras['print_mode'] = copy(functor.extras['print_mode'])
             if 'type' in kwds and kwds['type'] not in functor._dvr_types:
-                raise ValueError("completion type must be one of %s"%(", ".join(functor._dvr_types[1:])))
+                raise ValueError("completion type must be one of %s" % (", ".join(functor._dvr_types[1:])))
             if 'field' in kwds:
                 field = kwds.pop('field')
                 if field:
@@ -480,7 +490,7 @@ class LocalGeneric(CommutativeRing):
             # Labels for lattice precision
             if 'label' in kwds:
                 functor.extras['label'] = kwds.pop('label')
-            elif 'label' in functor.extras and functor.type not in ['lattice-cap','lattice-float']:
+            elif 'label' in functor.extras and functor.type not in ['lattice-cap', 'lattice-float']:
                 del functor.extras['label']
             for atr in ('ram_name', 'var_name'):
                 if atr in kwds:
@@ -493,7 +503,7 @@ class LocalGeneric(CommutativeRing):
                 if atr in kwds:
                     functor.extras['print_mode'][atr] = kwds.pop(atr)
             if kwds:
-                raise ValueError("Extra arguments received: %s"%(", ".join(kwds.keys())))
+                raise ValueError("Extra arguments received: %s" % (", ".join(kwds.keys())))
             if q is not None:
                 # Create an unramified extension
                 base = functor(ring)
@@ -607,11 +617,9 @@ class LocalGeneric(CommutativeRing):
 
         INPUT:
 
-        - ``self`` -- a p-adic ring.
+        - ``self`` -- a `p`-adic ring
 
-        OUTPUT:
-
-        The characteristic of the residue field.
+        OUTPUT: the characteristic of the residue field
 
         EXAMPLES::
 
@@ -622,19 +630,17 @@ class LocalGeneric(CommutativeRing):
 
     def defining_polynomial(self, var='x', exact=False):
         r"""
-        Return the defining polynomial of this local ring
+        Return the defining polynomial of this local ring.
 
         INPUT:
 
-        - ``var`` -- string (default: ``'x'``), the name of the variable
+        - ``var`` -- string (default: ``'x'``); the name of the variable
 
-        - ``exact`` -- a boolean (default: ``False``), whether to return the
-          underlying exact  defining polynomial rather than the one with coefficients
-          in the base ring.
+        - ``exact`` -- boolean (default: ``False``); whether to return the
+          underlying exact defining polynomial rather than the one with coefficients
+          in the base ring
 
-        OUTPUT:
-
-        The defining polynomial of this ring as an extension over its ground ring
+        OUTPUT: the defining polynomial of this ring as an extension over its ground ring
 
         EXAMPLES::
 
@@ -651,9 +657,9 @@ class LocalGeneric(CommutativeRing):
         from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
         if exact:
             from sage.rings.integer_ring import ZZ
-            return PolynomialRing(ZZ,var).gen()
+            return PolynomialRing(ZZ, var).gen()
         else:
-            return PolynomialRing(self,var).gen()
+            return PolynomialRing(self, var).gen()
 
     def ground_ring(self):
         r"""
@@ -665,9 +671,7 @@ class LocalGeneric(CommutativeRing):
 
         - ``self`` -- a local ring
 
-        OUTPUT:
-
-        The ground ring of ``self``, i.e., itself.
+        OUTPUT: the ground ring of ``self``, i.e., itself
 
         EXAMPLES::
 
@@ -690,9 +694,7 @@ class LocalGeneric(CommutativeRing):
 
         - ``self`` -- a `p`-adic ring
 
-        OUTPUT:
-
-        The ground ring of the tower for ``self``, i.e., itself.
+        OUTPUT: the ground ring of the tower for ``self``, i.e., itself
 
         EXAMPLES::
 
@@ -704,16 +706,17 @@ class LocalGeneric(CommutativeRing):
 
     def absolute_degree(self):
         r"""
-        Return the degree of this extension over the prime p-adic field/ring.
+        Return the degree of this extension over the prime `p`-adic field/ring.
 
         EXAMPLES::
 
-            sage: K.<a> = Qq(3^5)
-            sage: K.absolute_degree()
+            sage: K.<a> = Qq(3^5)                                                       # needs sage.libs.ntl
+            sage: K.absolute_degree()                                                   # needs sage.libs.ntl
             5
 
-            sage: L.<pi> = Qp(3).extension(x^2 - 3)
-            sage: L.absolute_degree()
+            sage: R.<x> = QQ[]
+            sage: L.<pi> = Qp(3).extension(x^2 - 3)                                     # needs sage.libs.ntl
+            sage: L.absolute_degree()                                                   # needs sage.libs.ntl
             2
         """
         return self.absolute_e() * self.absolute_f()
@@ -724,12 +727,13 @@ class LocalGeneric(CommutativeRing):
 
         EXAMPLES::
 
-            sage: K.<a> = Qq(3^5)
-            sage: K.relative_degree()
+            sage: K.<a> = Qq(3^5)                                                       # needs sage.libs.ntl
+            sage: K.relative_degree()                                                   # needs sage.libs.ntl
             5
 
-            sage: L.<pi> = Qp(3).extension(x^2 - 3)
-            sage: L.relative_degree()
+            sage: R.<x> = QQ[]
+            sage: L.<pi> = Qp(3).extension(x^2 - 3)                                     # needs sage.libs.ntl
+            sage: L.relative_degree()                                                   # needs sage.libs.ntl
             2
         """
         return self.absolute_degree() // self.base_ring().absolute_degree()
@@ -742,12 +746,13 @@ class LocalGeneric(CommutativeRing):
 
         EXAMPLES::
 
-            sage: K.<a> = Qq(3^5)
-            sage: K.degree()
+            sage: K.<a> = Qq(3^5)                                                       # needs sage.libs.ntl
+            sage: K.degree()                                                            # needs sage.libs.ntl
             5
 
-            sage: L.<pi> = Qp(3).extension(x^2 - 3)
-            sage: L.degree()
+            sage: R.<x> = QQ[]
+            sage: L.<pi> = Qp(3).extension(x^2 - 3)                                     # needs sage.libs.ntl
+            sage: L.degree()                                                            # needs sage.libs.ntl
             2
         """
         if self.base_ring().absolute_degree() == 1:
@@ -761,12 +766,13 @@ class LocalGeneric(CommutativeRing):
 
         EXAMPLES::
 
-            sage: K.<a> = Qq(3^5)
-            sage: K.absolute_e()
+            sage: K.<a> = Qq(3^5)                                                       # needs sage.libs.ntl
+            sage: K.absolute_e()                                                        # needs sage.libs.ntl
             1
 
-            sage: L.<pi> = Qp(3).extension(x^2 - 3)
-            sage: L.absolute_e()
+            sage: R.<x> = QQ[]
+            sage: L.<pi> = Qp(3).extension(x^2 - 3)                                     # needs sage.libs.ntl
+            sage: L.absolute_e()                                                        # needs sage.libs.ntl
             2
         """
         # Override this in subclasses (if appropriate)
@@ -781,12 +787,13 @@ class LocalGeneric(CommutativeRing):
 
         EXAMPLES::
 
-            sage: K.<a> = Qq(3^5)
-            sage: K.absolute_ramification_index()
+            sage: K.<a> = Qq(3^5)                                                       # needs sage.libs.ntl
+            sage: K.absolute_ramification_index()                                       # needs sage.libs.ntl
             1
 
-            sage: L.<pi> = Qp(3).extension(x^2 - 3)
-            sage: L.absolute_ramification_index()
+            sage: R.<x> = QQ[]
+            sage: L.<pi> = Qp(3).extension(x^2 - 3)                                     # needs sage.libs.ntl
+            sage: L.absolute_ramification_index()                                       # needs sage.libs.ntl
             2
         """
         return self.absolute_e()
@@ -797,12 +804,13 @@ class LocalGeneric(CommutativeRing):
 
         EXAMPLES::
 
-            sage: K.<a> = Qq(3^5)
-            sage: K.relative_e()
+            sage: K.<a> = Qq(3^5)                                                       # needs sage.libs.ntl
+            sage: K.relative_e()                                                        # needs sage.libs.ntl
             1
 
-            sage: L.<pi> = Qp(3).extension(x^2 - 3)
-            sage: L.relative_e()
+            sage: R.<x> = QQ[]
+            sage: L.<pi> = Qp(3).extension(x^2 - 3)                                     # needs sage.libs.ntl
+            sage: L.relative_e()                                                        # needs sage.libs.ntl
             2
         """
         return self.absolute_e() // self.base_ring().absolute_e()
@@ -813,12 +821,13 @@ class LocalGeneric(CommutativeRing):
 
         EXAMPLES::
 
-            sage: K.<a> = Qq(3^5)
-            sage: K.relative_ramification_index()
+            sage: K.<a> = Qq(3^5)                                                       # needs sage.libs.ntl
+            sage: K.relative_ramification_index()                                       # needs sage.libs.ntl
             1
 
-            sage: L.<pi> = Qp(3).extension(x^2 - 3)
-            sage: L.relative_ramification_index()
+            sage: R.<x> = QQ[]
+            sage: L.<pi> = Qp(3).extension(x^2 - 3)                                     # needs sage.libs.ntl
+            sage: L.relative_ramification_index()                                       # needs sage.libs.ntl
             2
         """
         return self.relative_e()
@@ -831,12 +840,13 @@ class LocalGeneric(CommutativeRing):
 
         EXAMPLES::
 
-            sage: K.<a> = Qq(3^5)
-            sage: K.e()
+            sage: K.<a> = Qq(3^5)                                                       # needs sage.libs.ntl
+            sage: K.e()                                                                 # needs sage.libs.ntl
             1
 
-            sage: L.<pi> = Qp(3).extension(x^2 - 3)
-            sage: L.e()
+            sage: R.<x> = QQ[]
+            sage: L.<pi> = Qp(3).extension(x^2 - 3)                                     # needs sage.libs.ntl
+            sage: L.e()                                                                 # needs sage.libs.ntl
             2
         """
         if self.base_ring().absolute_degree() == 1:
@@ -852,12 +862,13 @@ class LocalGeneric(CommutativeRing):
 
         EXAMPLES::
 
-            sage: K.<a> = Qq(3^5)
-            sage: K.ramification_index()
+            sage: K.<a> = Qq(3^5)                                                       # needs sage.libs.ntl
+            sage: K.ramification_index()                                                # needs sage.libs.ntl
             1
 
-            sage: L.<pi> = Qp(3).extension(x^2 - 3)
-            sage: L.ramification_index()
+            sage: R.<x> = QQ[]
+            sage: L.<pi> = Qp(3).extension(x^2 - 3)                                     # needs sage.libs.ntl
+            sage: L.ramification_index()                                                # needs sage.libs.ntl
             2
         """
         return self.e()
@@ -869,12 +880,13 @@ class LocalGeneric(CommutativeRing):
 
         EXAMPLES::
 
-            sage: K.<a> = Qq(3^5)
-            sage: K.absolute_f()
+            sage: K.<a> = Qq(3^5)                                                       # needs sage.libs.ntl
+            sage: K.absolute_f()                                                        # needs sage.libs.ntl
             5
 
-            sage: L.<pi> = Qp(3).extension(x^2 - 3)
-            sage: L.absolute_f()
+            sage: R.<x> = QQ[]
+            sage: L.<pi> = Qp(3).extension(x^2 - 3)                                     # needs sage.libs.ntl
+            sage: L.absolute_f()                                                        # needs sage.libs.ntl
             1
         """
         # Override this in subclasses (if appropriate)
@@ -890,12 +902,13 @@ class LocalGeneric(CommutativeRing):
 
         EXAMPLES::
 
-            sage: K.<a> = Qq(3^5)
-            sage: K.absolute_inertia_degree()
+            sage: K.<a> = Qq(3^5)                                                       # needs sage.libs.ntl
+            sage: K.absolute_inertia_degree()                                           # needs sage.libs.ntl
             5
 
-            sage: L.<pi> = Qp(3).extension(x^2 - 3)
-            sage: L.absolute_inertia_degree()
+            sage: R.<x> = QQ[]
+            sage: L.<pi> = Qp(3).extension(x^2 - 3)                                     # needs sage.libs.ntl
+            sage: L.absolute_inertia_degree()                                           # needs sage.libs.ntl
             1
         """
         return self.absolute_f()
@@ -906,12 +919,13 @@ class LocalGeneric(CommutativeRing):
 
         EXAMPLES::
 
-            sage: K.<a> = Qq(3^5)
-            sage: K.relative_f()
+            sage: K.<a> = Qq(3^5)                                                       # needs sage.libs.ntl
+            sage: K.relative_f()                                                        # needs sage.libs.ntl
             5
 
-            sage: L.<pi> = Qp(3).extension(x^2 - 3)
-            sage: L.relative_f()
+            sage: R.<x> = QQ[]
+            sage: L.<pi> = Qp(3).extension(x^2 - 3)                                     # needs sage.libs.ntl
+            sage: L.relative_f()                                                        # needs sage.libs.ntl
             1
         """
         return self.absolute_f() // self.base_ring().absolute_f()
@@ -922,12 +936,13 @@ class LocalGeneric(CommutativeRing):
 
         EXAMPLES::
 
-            sage: K.<a> = Qq(3^5)
-            sage: K.relative_inertia_degree()
+            sage: K.<a> = Qq(3^5)                                                       # needs sage.libs.ntl
+            sage: K.relative_inertia_degree()                                           # needs sage.libs.ntl
             5
 
-            sage: L.<pi> = Qp(3).extension(x^2 - 3)
-            sage: L.relative_inertia_degree()
+            sage: R.<x> = QQ[]
+            sage: L.<pi> = Qp(3).extension(x^2 - 3)                                     # needs sage.libs.ntl
+            sage: L.relative_inertia_degree()                                           # needs sage.libs.ntl
             1
         """
         return self.relative_f()
@@ -940,12 +955,13 @@ class LocalGeneric(CommutativeRing):
 
         EXAMPLES::
 
-            sage: K.<a> = Qq(3^5)
-            sage: K.f()
+            sage: K.<a> = Qq(3^5)                                                       # needs sage.libs.ntl
+            sage: K.f()                                                                 # needs sage.libs.ntl
             5
 
-            sage: L.<pi> = Qp(3).extension(x^2 - 3)
-            sage: L.f()
+            sage: R.<x> = QQ[]
+            sage: L.<pi> = Qp(3).extension(x^2 - 3)                                     # needs sage.libs.ntl
+            sage: L.f()                                                                 # needs sage.libs.ntl
             1
         """
         if self.base_ring().absolute_degree() == 1:
@@ -961,12 +977,13 @@ class LocalGeneric(CommutativeRing):
 
         EXAMPLES::
 
-            sage: K.<a> = Qq(3^5)
-            sage: K.inertia_degree()
+            sage: K.<a> = Qq(3^5)                                                       # needs sage.libs.ntl
+            sage: K.inertia_degree()                                                    # needs sage.libs.ntl
             5
 
-            sage: L.<pi> = Qp(3).extension(x^2 - 3)
-            sage: L.inertia_degree()
+            sage: R.<x> = QQ[]
+            sage: L.<pi> = Qp(3).extension(x^2 - 3)                                     # needs sage.libs.ntl
+            sage: L.inertia_degree()                                                    # needs sage.libs.ntl
             1
         """
         return self.f()
@@ -979,9 +996,7 @@ class LocalGeneric(CommutativeRing):
 
         - ``self`` -- a local ring
 
-        OUTPUT:
-
-        - the inertia subring of self, i.e., itself
+        OUTPUT: the inertia subring of ``self``, i.e., itself
 
         EXAMPLES::
 
@@ -999,9 +1014,7 @@ class LocalGeneric(CommutativeRing):
 
         - ``self`` -- a local ring
 
-        OUTPUT:
-
-        - the maximal unramified subextension of ``self``
+        OUTPUT: the maximal unramified subextension of ``self``
 
         EXAMPLES::
 
@@ -1027,16 +1040,17 @@ class LocalGeneric(CommutativeRing):
             sage: R.uniformiser()
             5 + O(5^21)
             sage: A = Zp(7,10)
-            sage: S.<x> = A[]
-            sage: B.<t> = A.ext(x^2+7)
-            sage: B.uniformiser()
+            sage: S.<x> = A[]                                                           # needs sage.libs.ntl
+            sage: B.<t> = A.ext(x^2+7)                                                  # needs sage.libs.ntl
+            sage: B.uniformiser()                                                       # needs sage.libs.ntl
             t + O(t^21)
         """
         return self.uniformizer()
 
     def uniformiser_pow(self, n):
         r"""
-        Return the `n`th power of the uniformiser of ``self`` (as an element of ``self``).
+        Return the `n`-th power of the uniformiser of ``self`` (as an element
+        of ``self``).
 
         EXAMPLES::
 
@@ -1048,14 +1062,14 @@ class LocalGeneric(CommutativeRing):
 
     def ext(self, *args, **kwds):
         r"""
-        Construct an extension of self.  See :meth:`extension` for more details.
+        Construct an extension of ``self``.  See :meth:`extension` for more details.
 
         EXAMPLES::
 
             sage: A = Zp(7,10)
-            sage: S.<x> = A[]
-            sage: B.<t> = A.ext(x^2+7)
-            sage: B.uniformiser()
+            sage: S.<x> = A[]                                                           # needs sage.libs.ntl
+            sage: B.<t> = A.ext(x^2 + 7)                                                # needs sage.libs.ntl
+            sage: B.uniformiser()                                                       # needs sage.libs.ntl
             t + O(t^21)
         """
         return self.extension(*args, **kwds)
@@ -1068,7 +1082,6 @@ class LocalGeneric(CommutativeRing):
 
             sage: K = Qp(3)
             sage: K._test_add_bigoh()
-
         """
         tester = self._tester(**options)
         for x in tester.some_elements():
@@ -1094,7 +1107,7 @@ class LocalGeneric(CommutativeRing):
                 tester.assertLessEqual(y.precision_absolute(), -1)
 
             # make sure that we handle very large values correctly
-            if self._prec_type() not in [ 'lattice-float', 'relaxed' ]:   # no cap in these models
+            if self._prec_type() not in ['lattice-float', 'relaxed']:  # no cap in these models
                 absprec = Integer(2)**1000
                 tester.assertEqual(x.add_bigoh(absprec), x)
 
@@ -1106,7 +1119,6 @@ class LocalGeneric(CommutativeRing):
 
             sage: R = Zp(2)
             sage: R._test_residue()
-
         """
         tester = self._tester(**options)
         tester.assertEqual(self.residue_field().characteristic(), self.residue_characteristic())
@@ -1171,15 +1183,15 @@ class LocalGeneric(CommutativeRing):
         cap = parent.precision_cap()
         n = M.nrows()
         m = M.ncols()
-        shift_rows = n * [ ZZ(0) ]
-        shift_cols = m * [ ZZ(0) ]
+        shift_rows = n * [ZZ.zero()]
+        shift_cols = m * [ZZ.zero()]
         for i in range(n):
-            prec = min(M[i,j].precision_absolute() for j in range(m))
+            prec = min(M[i, j].precision_absolute() for j in range(m))
             if prec is Infinity or prec == cap:
                 continue
             shift_rows[i] = s = cap - prec
             for j in range(m):
-                M[i,j] <<= s
+                M[i, j] <<= s
         for j in range(m):
             prec = min(M[i,j].precision_absolute() for i in range(n))
             if prec is Infinity or prec == cap:
@@ -1197,14 +1209,14 @@ class LocalGeneric(CommutativeRing):
         :meth:`sage.matrix.matrix2.Matrix.smith_form` to compute the Smith
         normal form over local rings and fields.
 
-        The entries of the Smith normal form are normalized such that non-zero
+        The entries of the Smith normal form are normalized such that nonzero
         entries of the diagonal are powers of the distinguished uniformizer.
 
         INPUT:
 
         - ``M`` -- a matrix over this ring
 
-        - ``transformation`` -- a boolean; whether the transformation matrices
+        - ``transformation`` -- boolean; whether the transformation matrices
           are returned
 
         - ``integral`` -- a subring of the base ring or ``True``; the entries
@@ -1212,13 +1224,13 @@ class LocalGeneric(CommutativeRing):
           entries are in the ring of integers of the base ring.
 
         - ``exact`` -- boolean.  If ``True``, the diagonal smith form will
-          be exact, or raise a ``PrecisionError`` if this is not possible.
+          be exact, or raise a :exc:`PrecisionError` if this is not possible
           If ``False``, the diagonal entries will be inexact, but the
           transformation matrices will be exact.
 
         EXAMPLES::
 
-            sage: A = Zp(5, prec=10, print_mode="digits")
+            sage: A = Zp(5, prec=10, print_mode='digits')
             sage: M = matrix(A, 2, 2, [2, 7, 1, 6])
 
             sage: S, L, R = M.smith_form()  # indirect doctest
@@ -1279,7 +1291,7 @@ class LocalGeneric(CommutativeRing):
         TESTS::
 
             sage: A = ZpCR(5, prec=10)
-            sage: M = zero_matrix(A, 2)
+            sage: M = zero_matrix(A, 2)                                                 # needs sage.geometry.polyhedron
             sage: M.smith_form(transformation=False)  # indirect doctest
             [0 0]
             [0 0]
@@ -1468,8 +1480,7 @@ class LocalGeneric(CommutativeRing):
 
         EXAMPLES::
 
-            sage: ZpCA(5, 15)._test_matrix_smith()
-
+            sage: ZpCA(5, 15)._test_matrix_smith()                                      # needs sage.geometry.polyhedron
         """
         tester = self._tester(**options)
         tester.assertEqual(self.residue_field().characteristic(), self.residue_characteristic())
@@ -1562,12 +1573,14 @@ class LocalGeneric(CommutativeRing):
             O(5^70)
             O(5^80)
 
+            sage: # needs sage.geometry.polyhedron
             sage: A = random_matrix(Qp(5),4)
             sage: B = random_matrix(Qp(5),4)
             sage: (A*B).det() == A.det()*B.det()
             True
             sage: A.change_ring(QQ).det() == A.det()
             True
+
             sage: matrix(Qp(37),[0]).determinant()
             0
             sage: matrix(Qp(37),[O(37)]).determinant()
@@ -1636,8 +1649,7 @@ class LocalGeneric(CommutativeRing):
                 for j in range(n):
                     prec = min(prec, S[i,j].precision_absolute())
                 prec -= S[i,i].valuation()
-                if prec < relprec:
-                    relprec = prec
+                relprec = min(prec, relprec)
                 if prec < 0:
                     relprec_neg += prec
             if relprec_neg < 0:
