@@ -17,7 +17,6 @@ AUTHORS:
 - Robert Bradshaw
 - John Cremona
 - William Stein
-
 """
 
 # ****************************************************************************
@@ -35,12 +34,10 @@ AUTHORS:
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 
-from sage.interfaces.magma import magma
 from sage.rings.integer import Integer
 from sage.rings.rational_field import QQ
 from sage.rings.integer_ring import ZZ
 from sage.rings.integer_ring import IntegerRing
-from sage.rings.number_field.number_field import is_fundamental_discriminant
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
 
 from sage.misc.cachefunc import cached_function
@@ -54,9 +51,9 @@ def hilbert_class_polynomial(D, algorithm=None):
 
     INPUT:
 
-    - ``D`` (int) -- a negative integer congruent to 0 or 1 modulo 4.
+    - ``D`` -- negative integer congruent to 0 or 1 modulo 4
 
-    - ``algorithm`` (string, default None).
+    - ``algorithm`` -- string (default: ``None``)
 
     OUTPUT:
 
@@ -65,7 +62,8 @@ def hilbert_class_polynomial(D, algorithm=None):
 
     ALGORITHM:
 
-    - If ``algorithm`` = "arb" (default): Use Arb's implementation which uses complex interval arithmetic.
+    - If ``algorithm`` = "arb" (default): Use FLINT's implementation inherited
+      from Arb which uses complex interval arithmetic.
 
     - If ``algorithm`` = "sage": Use complex approximations to the roots.
 
@@ -82,6 +80,7 @@ def hilbert_class_polynomial(D, algorithm=None):
 
     EXAMPLES::
 
+        sage: # needs sage.libs.flint
         sage: hilbert_class_polynomial(-4)
         x - 1728
         sage: hilbert_class_polynomial(-7)
@@ -90,19 +89,19 @@ def hilbert_class_polynomial(D, algorithm=None):
         x^3 + 3491750*x^2 - 5151296875*x + 12771880859375
         sage: hilbert_class_polynomial(-37*4)
         x^2 - 39660183801072000*x - 7898242515936467904000000
-        sage: hilbert_class_polynomial(-37*4, algorithm="magma") # optional - magma
+        sage: hilbert_class_polynomial(-37*4, algorithm='magma') # optional - magma
         x^2 - 39660183801072000*x - 7898242515936467904000000
         sage: hilbert_class_polynomial(-163)
         x + 262537412640768000
-        sage: hilbert_class_polynomial(-163, algorithm="sage")
+        sage: hilbert_class_polynomial(-163, algorithm='sage')
         x + 262537412640768000
-        sage: hilbert_class_polynomial(-163, algorithm="magma") # optional - magma
+        sage: hilbert_class_polynomial(-163, algorithm='magma') # optional - magma
         x + 262537412640768000
 
     TESTS::
 
-        sage: all(hilbert_class_polynomial(d, algorithm="arb") ==
-        ....:      hilbert_class_polynomial(d, algorithm="sage")
+        sage: all(hilbert_class_polynomial(d, algorithm='arb') ==
+        ....:      hilbert_class_polynomial(d, algorithm='sage')
         ....:        for d in range(-1,-100,-1) if d % 4 in [0, 1])
         True
     """
@@ -112,7 +111,7 @@ def hilbert_class_polynomial(D, algorithm=None):
     D = Integer(D)
     if D >= 0:
         raise ValueError("D (=%s) must be negative" % D)
-    if not (D % 4 in [0, 1]):
+    if (D % 4) not in [0, 1]:
         raise ValueError("D (=%s) must be a discriminant" % D)
 
     if algorithm == "arb":
@@ -120,6 +119,7 @@ def hilbert_class_polynomial(D, algorithm=None):
         return sage.libs.arb.arith.hilbert_class_polynomial(D)
 
     if algorithm == "magma":
+        from sage.interfaces.magma import magma
         magma.eval("R<x> := PolynomialRing(IntegerRing())")
         f = str(magma.eval("HilbertClassPolynomial(%s)" % D))
         return IntegerRing()['x'](f)
@@ -182,10 +182,9 @@ def is_HCP(f, check_monic_irreducible=True):
 
     INPUT:
 
-    - ``f`` -- a polynomial in `\ZZ[X]`.
-    - ``check_monic_irreducible`` (boolean, default ``True``) -- if
-      ``True``, check that ``f`` is a monic, irreducible, integer
-      polynomial.
+    - ``f`` -- a polynomial in `\ZZ[X]`
+    - ``check_monic_irreducible`` -- boolean (default: ``True``); if ``True``,
+      check that ``f`` is a monic, irreducible, integer polynomial
 
     OUTPUT:
 
@@ -204,8 +203,10 @@ def is_HCP(f, check_monic_irreducible=True):
 
         sage: from sage.schemes.elliptic_curves.cm import is_HCP
         sage: D = -1856563
-        sage: D.class_number()
+        sage: D.class_number()                                                          # needs sage.libs.pari
         100
+
+        sage: # needs sage.libs.flint
         sage: H = hilbert_class_polynomial(D)
         sage: H.degree()
         100
@@ -216,17 +217,27 @@ def is_HCP(f, check_monic_irreducible=True):
 
     Testing polynomials which are not HCPs is faster::
 
-        sage: is_HCP(H+1)
+        sage: is_HCP(H+1)                                                               # needs sage.libs.flint
         0
 
 
     TESTS::
 
+        sage: # needs sage.libs.flint
         sage: from sage.schemes.elliptic_curves.cm import is_HCP
-        sage: all(is_HCP(hilbert_class_polynomial(D))==D for D in srange(-4,-100,-1) if D.is_discriminant())
+        sage: all(is_HCP(hilbert_class_polynomial(D)) == D
+        ....:     for D in srange(-4,-100,-1) if D.is_discriminant())
         True
-        sage: all(not is_HCP(hilbert_class_polynomial(D)+1) for D in srange(-4,-100,-1) if D.is_discriminant())
+        sage: all(not is_HCP(hilbert_class_polynomial(D) + 1)
+        ....:     for D in srange(-4,-100,-1) if D.is_discriminant())
         True
+
+    Ensure that :issue:`37471` is fixed::
+
+        sage: from sage.schemes.elliptic_curves.cm import is_HCP
+        sage: set_random_seed(297388353221545796156853787333338705098)
+        sage: is_HCP(hilbert_class_polynomial(-55))
+        -55
     """
     zero = ZZ(0)
     # optional check that input is monic and irreducible
@@ -258,14 +269,15 @@ def is_HCP(f, check_monic_irreducible=True):
         # Compute X^p-X mod fp
         z = fp.parent().gen()
         r = pow(z, p, fp) - z
-        d = r.gcd(fp).degree()  # number of roots mod p
+        r = r.gcd(fp)
+        d = r.degree()  # number of roots mod p
         if d == 0:
             continue
-        if not fp.is_squarefree():
+        if not r.is_squarefree():
             continue
         if d < h and d not in h2list:
             return zero
-        jp = fp.any_root(degree=-1, assume_squarefree=True)
+        jp = r.any_root(degree=1, assume_squarefree=True, assume_equal_deg=True)
         E = EllipticCurve(j=jp)
         if E.is_supersingular():
             continue
@@ -275,15 +287,16 @@ def is_HCP(f, check_monic_irreducible=True):
             return zero
         return D if f == hilbert_class_polynomial(D) else zero
 
-def OrderClassNumber(D0,h0,f):
+
+def OrderClassNumber(D0, h0, f):
     r"""
     Return the class number h(f**2 * D0), given h(D0)=h0.
 
     INPUT:
 
-    - ``D0`` (integer) -- a negative fundamental discriminant
-    - ``h0`` (integer) -- the class number of the (maximal) imaginary quadratic order of discriminant ``D0``
-    - ``f`` (integer) -- a positive integer
+    - ``D0`` -- integer; a negative fundamental discriminant
+    - ``h0`` -- integer; the class number of the (maximal) imaginary quadratic order of discriminant ``D0``
+    - ``f`` -- positive integer
 
     OUTPUT:
 
@@ -300,6 +313,7 @@ def OrderClassNumber(D0,h0,f):
 
     EXAMPLES::
 
+        sage: # needs sage.libs.pari
         sage: from sage.schemes.elliptic_curves.cm import OrderClassNumber
         sage: D0 = -4
         sage: h = D0.class_number()
@@ -307,7 +321,6 @@ def OrderClassNumber(D0,h0,f):
         [1, 1, 2, 2, 2, 4, 4, 4, 6, 4, 6, 8, 6, 8, 8, 8, 8, 12, 10]
         sage: all([OrderClassNumber(D0,h,f) == (D0*f**2).class_number() for f in srange(1,20)])
         True
-
     """
     if not D0.is_fundamental_discriminant():
         raise ValueError("{} is not a fundamental discriminant".format(D0))
@@ -350,25 +363,26 @@ def cm_j_invariants(K, proof=None):
 
     Over imaginary quadratic fields there are no more than over `QQ`::
 
-        sage: cm_j_invariants(QuadraticField(-1, 'i'))                                  # optional - sage.rings.number_field
+        sage: cm_j_invariants(QuadraticField(-1, 'i'))                                  # needs sage.rings.number_field
         [-262537412640768000, -147197952000, -884736000, -12288000, -884736,
          -32768, -3375, 0, 1728, 8000, 54000, 287496, 16581375]
 
     Over real quadratic fields there may be more, for example::
 
-        sage: len(cm_j_invariants(QuadraticField(5, 'a')))                              # optional - sage.rings.number_field
+        sage: len(cm_j_invariants(QuadraticField(5, 'a')))                              # needs sage.rings.number_field
         31
 
     Over number fields K of many higher degrees this also works::
 
+        sage: # needs sage.rings.number_field
         sage: x = polygen(ZZ, 'x')
-        sage: K.<a> = NumberField(x^3 - 2)                                              # optional - sage.rings.number_field
-        sage: cm_j_invariants(K)                                                        # optional - sage.rings.number_field
+        sage: K.<a> = NumberField(x^3 - 2)
+        sage: cm_j_invariants(K)
         [-262537412640768000, -147197952000, -884736000, -884736, -32768,
          8000, -3375, 16581375, 1728, 287496, 0, 54000, -12288000,
          31710790944000*a^2 + 39953093016000*a + 50337742902000]
-        sage: K.<a> = NumberField(x^4 - 2)                                              # optional - sage.rings.number_field
-        sage: len(cm_j_invariants(K))                                                   # optional - sage.rings.number_field
+        sage: K.<a> = NumberField(x^4 - 2)
+        sage: len(cm_j_invariants(K))
         23
     """
     return sorted(j for D, f, j in cm_j_invariants_and_orders(K, proof=proof))
@@ -386,9 +400,8 @@ def cm_j_invariants_and_orders(K, proof=None):
 
     OUTPUT:
 
-    (list) A list of 3-tuples `(D,f,j)` where `j` is a CM
-    `j`-invariant in `K` with quadratic fundamental discriminant `D`
-    and conductor `f`.
+    A list of 3-tuples `(D,f,j)` where `j` is a CM `j`-invariant in `K` with
+    quadratic fundamental discriminant `D` and conductor `f`.
 
     EXAMPLES::
 
@@ -400,7 +413,7 @@ def cm_j_invariants_and_orders(K, proof=None):
 
     Over an imaginary quadratic field there are no more than over `QQ`::
 
-        sage: cm_j_invariants_and_orders(QuadraticField(-1, 'i'))                       # optional - sage.rings.number_field
+        sage: cm_j_invariants_and_orders(QuadraticField(-1, 'i'))                       # needs sage.rings.number_field
         [(-163, 1, -262537412640768000), (-67, 1, -147197952000),
          (-43, 1, -884736000), (-19, 1, -884736), (-11, 1, -32768),
          (-8, 1, 8000), (-7, 1, -3375), (-7, 2, 16581375), (-4, 1, 1728),
@@ -408,9 +421,9 @@ def cm_j_invariants_and_orders(K, proof=None):
 
     Over real quadratic fields there may be more::
 
-        sage: v = cm_j_invariants_and_orders(QuadraticField(5,'a')); len(v)             # optional - sage.rings.number_field
+        sage: v = cm_j_invariants_and_orders(QuadraticField(5,'a')); len(v)             # needs sage.rings.number_field
         31
-        sage: [(D, f) for D, f, j in v if j not in QQ]                                  # optional - sage.rings.number_field
+        sage: [(D, f) for D, f, j in v if j not in QQ]                                  # needs sage.rings.number_field
         [(-235, 1), (-235, 1), (-115, 1), (-115, 1), (-40, 1), (-40, 1),
          (-35, 1), (-35, 1), (-20, 1), (-20, 1), (-15, 1), (-15, 1), (-15, 2),
          (-15, 2), (-4, 5), (-4, 5), (-3, 5), (-3, 5)]
@@ -418,8 +431,8 @@ def cm_j_invariants_and_orders(K, proof=None):
     Over number fields K of many higher degrees this also works::
 
         sage: x = polygen(ZZ, 'x')
-        sage: K.<a> = NumberField(x^3 - 2)                                              # optional - sage.rings.number_field
-        sage: cm_j_invariants_and_orders(K)                                             # optional - sage.rings.number_field
+        sage: K.<a> = NumberField(x^3 - 2)                                              # needs sage.rings.number_field
+        sage: cm_j_invariants_and_orders(K)                                             # needs sage.rings.number_field
         [(-163, 1, -262537412640768000), (-67, 1, -147197952000),
          (-43, 1, -884736000), (-19, 1, -884736), (-11, 1, -32768),
          (-8, 1, 8000), (-7, 1, -3375), (-7, 2, 16581375), (-4, 1, 1728),
@@ -463,12 +476,10 @@ def cm_orders(h, proof=None):
 
     INPUT:
 
-    - `h` -- positive integer
+    - ``h`` -- positive integer
     - ``proof`` -- (default: proof.number_field())
 
-    OUTPUT:
-
-    - list of 2-tuples `(D,f)` sorted lexicographically by `(|D|, f)`
+    OUTPUT: list of 2-tuples `(D,f)` sorted lexicographically by `(|D|, f)`
 
     EXAMPLES::
 
@@ -479,6 +490,7 @@ def cm_orders(h, proof=None):
          (-11, 1), (-19, 1), (-43, 1), (-67, 1), (-163, 1)]
         sage: type(v[0][0]), type(v[0][1])
         (<... 'sage.rings.integer.Integer'>, <... 'sage.rings.integer.Integer'>)
+        sage: # needs sage.libs.pari
         sage: v = cm_orders(2); v
          [(-3, 4), (-3, 5), (-3, 7), (-4, 3), (-4, 4), (-4, 5), (-7, 4), (-8, 2),
           (-8, 3), (-11, 3), (-15, 1), (-15, 2), (-20, 1), (-24, 1), (-35, 1),
@@ -491,6 +503,7 @@ def cm_orders(h, proof=None):
 
     Any degree up to 100 is implemented, but may be slow::
 
+        sage: # needs sage.libs.pari
         sage: cm_orders(3)
         [(-3, 6), (-3, 9), (-11, 2), (-19, 2), (-23, 1), (-23, 2), (-31, 1), (-31, 2),
          (-43, 2), (-59, 1), (-67, 2), (-83, 1), (-107, 1), (-139, 1), (-163, 2),
@@ -525,6 +538,7 @@ def cm_orders(h, proof=None):
 # quadratic field with class number h, and n is the number of such
 # fields.  These are all *unconditional* (not dependent on GRH).
 
+
 watkins_table = {1: (163, 9), 2: (427, 18), 3: (907, 16), 4: (1555, 54), 5: (2683, 25),
                  6: (3763, 51), 7: (5923, 31), 8: (6307, 131), 9: (10627, 34), 10:
                  (13843, 87), 11: (15667, 41), 12: (17803, 206), 13: (20563, 37), 14:
@@ -610,7 +624,7 @@ def largest_fundamental_disc_with_class_number(h):
 
     INPUT:
 
-    - `h` -- integer
+    - ``h`` -- integer
 
     EXAMPLES::
 
@@ -629,7 +643,6 @@ def largest_fundamental_disc_with_class_number(h):
         Traceback (most recent call last):
         ...
         NotImplementedError: largest fundamental discriminant not available for class number 101
-
     """
     h = Integer(h)
     if h <= 0:
@@ -640,6 +653,7 @@ def largest_fundamental_disc_with_class_number(h):
     except KeyError:
         raise NotImplementedError("largest fundamental discriminant not available for class number %s" % h)
 
+
 def largest_disc_with_class_number(h):
     r"""
     Return largest absolute value of any negative discriminant with
@@ -660,7 +674,7 @@ def largest_disc_with_class_number(h):
 
     INPUT:
 
-    - `h` -- integer
+    - ``h`` -- integer
 
     EXAMPLES::
 
@@ -691,7 +705,6 @@ def largest_disc_with_class_number(h):
         (3763, 51)
         sage: largest_disc_with_class_number(6)
         (4075, 101)
-
     """
     h = Integer(h)
     if h <= 0:
@@ -707,10 +720,12 @@ def largest_disc_with_class_number(h):
 # initialise it with h=1 only; other values will be added by calls to
 # discriminants_with_bounded_class_number().
 
+
 hDf_dict = {ZZ(1): [(ZZ(D), ZZ(h)) for D,h in
                     [(-3, 1), (-3, 2), (-3, 3), (-4, 1), (-4, 2), (-7, 1), (-7, 2),
                      (-8, 1), (-11, 1), (-19, 1), (-43, 1), (-67, 1), (-163, 1)]]}
 
+
 def discriminants_with_bounded_class_number(hmax, B=None, proof=None):
     r"""Return a dictionary with keys class numbers `h\le hmax` and values the
     list of all pairs `(D_0, f)`, with `D_0<0` a fundamental discriminant such
@@ -720,15 +735,13 @@ def discriminants_with_bounded_class_number(hmax, B=None, proof=None):
     INPUT:
 
     - ``hmax`` -- integer
-    - `B` -- integer or None; if None returns all pairs
+    - ``B`` -- integer or ``None``; if ``None`` returns all pairs
     - ``proof`` -- this code calls the PARI function :pari:`qfbclassno`, so it
       could give wrong answers when ``proof``==``False`` (though only for
       discriminants greater than `2\cdot10^{10}`).  The default is
       the current value of ``proof.number_field()``.
 
-    OUTPUT:
-
-    - dictionary
+    OUTPUT: dictionary
 
     .. NOTE::
 
@@ -738,6 +751,7 @@ def discriminants_with_bounded_class_number(hmax, B=None, proof=None):
 
     EXAMPLES::
 
+        sage: # needs sage.libs.pari
         sage: from sage.schemes.elliptic_curves.cm import discriminants_with_bounded_class_number
         sage: v = discriminants_with_bounded_class_number(3)
         sage: sorted(v)
@@ -763,7 +777,6 @@ def discriminants_with_bounded_class_number(hmax, B=None, proof=None):
 
         sage: sage.schemes.elliptic_curves.cm.discriminants_with_bounded_class_number(hmax=5, B=50)
         {1: [(-3, 1), (-3, 2), (-3, 3), (-4, 1), (-4, 2), (-7, 1), (-7, 2), (-8, 1), (-11, 1), (-19, 1), (-43, 1)], 2: [(-3, 4), (-4, 3), (-8, 2), (-15, 1), (-20, 1), (-24, 1), (-35, 1), (-40, 1)], 3: [(-11, 2), (-23, 1), (-31, 1)], 4: [(-39, 1)], 5: [(-47, 1)]}
-
     """
     hmax = Integer(hmax)
     global hDf_dict
@@ -880,11 +893,11 @@ def is_cm_j_invariant(j, algorithm='CremonaSutherland', method=None):
 
     - ``j`` -- an element of a number field `K`
 
-    - ``algorithm`` (string, default 'CremonaSutherland') -- the algorithm
-      used, either 'CremonaSutherland' (the default, very much faster
-      for all but very small degrees), 'exhaustive' or 'reduction'
+    - ``algorithm`` -- string (default: ``'CremonaSutherland'``); the algorithm
+      used, either ``'CremonaSutherland'`` (the default, very much faster
+      for all but very small degrees), ``'exhaustive'`` or ``'reduction'``
 
-    - ``method`` (string) -- deprecated name for ``algorithm``
+    - ``method`` -- string; deprecated name for ``algorithm``
 
     OUTPUT:
 
@@ -920,23 +933,24 @@ def is_cm_j_invariant(j, algorithm='CremonaSutherland', method=None):
         sage: is_cm_j_invariant(8000)
         (True, (-8, 1))
 
-        sage: K.<a> = QuadraticField(5)                                                    # optional - sage.rings.number_field
-        sage: is_cm_j_invariant(282880*a + 632000)                                         # optional - sage.rings.number_field
+        sage: # needs sage.rings.number_field
+        sage: K.<a> = QuadraticField(5)
+        sage: is_cm_j_invariant(282880*a + 632000)
         (True, (-20, 1))
         sage: x = polygen(ZZ, 'x')
-        sage: K.<a> = NumberField(x^3 - 2)                                                 # optional - sage.rings.number_field
-        sage: is_cm_j_invariant(31710790944000*a^2 + 39953093016000*a + 50337742902000)    # optional - sage.rings.number_field
+        sage: K.<a> = NumberField(x^3 - 2)
+        sage: is_cm_j_invariant(31710790944000*a^2 + 39953093016000*a + 50337742902000)
         (True, (-3, 6))
 
     An example of large degree.  This is only possible using the default algorithm::
 
         sage: from sage.schemes.elliptic_curves.cm import is_cm_j_invariant
         sage: D = -1856563
-        sage: H = hilbert_class_polynomial(D)
-        sage: H.degree()
+        sage: H = hilbert_class_polynomial(D)                                           # needs sage.libs.flint
+        sage: H.degree()                                                                # needs sage.libs.flint
         100
-        sage: K.<j> = NumberField(H)
-        sage: is_cm_j_invariant(j)
+        sage: K.<j> = NumberField(H)                                                    # needs sage.libs.flint sage.rings.number_field
+        sage: is_cm_j_invariant(j)                                                      # needs sage.libs.flint sage.rings.number_field
         (True, (-1856563, 1))
 
     TESTS::
@@ -944,7 +958,6 @@ def is_cm_j_invariant(j, algorithm='CremonaSutherland', method=None):
         sage: from sage.schemes.elliptic_curves.cm import is_cm_j_invariant
         sage: all(is_cm_j_invariant(j) == (True, (d,f)) for d,f,j in cm_j_invariants_and_orders(QQ))
         True
-
     """
     if method:
         if not algorithm:
@@ -959,7 +972,7 @@ def is_cm_j_invariant(j, algorithm='CremonaSutherland', method=None):
 
     if j in ZZ:
         j = ZZ(j)
-        table = dict([(jj,(d,f)) for d,f,jj in cm_j_invariants_and_orders(QQ)])
+        table = {jj: (d,f) for d,f,jj in cm_j_invariants_and_orders(QQ)}
         if j in table:
             return True, table[j]
         return False, None
