@@ -102,7 +102,7 @@ from sage.rings.integer import Integer
 from sage.rings.number_field.number_field_ideal import NumberFieldFractionalIdeal
 
 from sage.rings.number_field.number_field_base import NumberField
-from sage.rings.ideal import is_Ideal
+from sage.rings.ideal import Ideal_generic
 
 from .constructor import EllipticCurve
 from .kodaira_symbol import KodairaSymbol
@@ -118,17 +118,17 @@ class EllipticCurveLocalData(SageObject):
 
     INPUT:
 
-    - ``E`` -- an elliptic curve defined over a number field, or `\QQ`.
+    - ``E`` -- an elliptic curve defined over a number field, or `\QQ`
 
-    - ``P`` -- a prime ideal of the field, or a prime integer if the field is `\QQ`.
+    - ``P`` -- a prime ideal of the field, or a prime integer if the field is `\QQ`
 
-    - ``proof`` (bool) -- if ``True``, only use provably correct
-      methods (default controlled by global proof module).  Note
+    - ``proof`` -- boolean; if ``True``, only use provably correct
+      methods (default: controlled by global proof module).  Note
       that the proof module is number_field, not elliptic_curves,
       since the functions that actually need the flag are in
       number fields.
 
-    - ``algorithm`` (string, default: "pari") -- Ignored unless the
+    - ``algorithm`` -- string (default: ``'pari'``); ignored unless the
       base field is `\QQ`.  If "pari", use the PARI C-library
       ``ellglobalred`` implementation of Tate's algorithm over
       `\QQ`. If "generic", use the general number field
@@ -155,29 +155,29 @@ class EllipticCurveLocalData(SageObject):
           Tamagawa Number: 2
     """
 
-    def __init__(self, E, P, proof=None, algorithm="pari", globally=False):
+    def __init__(self, E, P, proof=None, algorithm='pari', globally=False):
         r"""
         Initialize the reduction data for the elliptic curve `E` at the prime `P`.
 
         INPUT:
 
-        - ``E`` -- an elliptic curve defined over a number field, or `\QQ`.
+        - ``E`` -- an elliptic curve defined over a number field, or `\QQ`
 
-        - ``P`` -- a prime ideal of the field, or a prime integer if the field is `\QQ`.
+        - ``P`` -- a prime ideal of the field, or a prime integer if the field is `\QQ`
 
-        - ``proof`` (bool)-- if True, only use provably correct
-          methods (default controlled by global proof module).  Note
+        - ``proof`` -- boolean; if ``True``, only use provably correct
+          methods (default: controlled by global proof module).  Note
           that the proof module is number_field, not elliptic_curves,
           since the functions that actually need the flag are in
           number fields.
 
-        - ``algorithm`` (string, default: "pari") -- Ignored unless the
+        - ``algorithm`` -- string (default: ``'pari'``); ignored unless the
           base field is `\QQ`.  If "pari", use the PARI C-library
           ``ellglobalred`` implementation of Tate's algorithm over
           `\QQ`. If "generic", use the general number field
           implementation.
 
-        - ``globally`` (bool, default: ``False``) -- If True, the algorithm
+        - ``globally`` -- boolean (default: ``False``); if ``True``, the algorithm
           uses the generators of principal ideals rather than an arbitrary
           uniformizer.
 
@@ -203,7 +203,7 @@ class EllipticCurveLocalData(SageObject):
 
         ::
 
-            sage: EllipticCurveLocalData(E, 2, algorithm="generic")
+            sage: EllipticCurveLocalData(E, 2, algorithm='generic')
             Local data at Principal ideal (2) of Integer Ring:
               Reduction type: bad non-split multiplicative
               Local minimal model: Elliptic Curve defined by y^2 + x*y + y = x^3 + 4*x - 6
@@ -215,7 +215,7 @@ class EllipticCurveLocalData(SageObject):
 
         ::
 
-            sage: EllipticCurveLocalData(E, 2, algorithm="pari")
+            sage: EllipticCurveLocalData(E, 2, algorithm='pari')
             Local data at Principal ideal (2) of Integer Ring:
               Reduction type: bad non-split multiplicative
               Local minimal model: Elliptic Curve defined by y^2 + x*y + y = x^3 + 4*x - 6
@@ -227,7 +227,7 @@ class EllipticCurveLocalData(SageObject):
 
         ::
 
-            sage: EllipticCurveLocalData(E, 2, algorithm="unknown")
+            sage: EllipticCurveLocalData(E, 2, algorithm='unknown')
             Traceback (most recent call last):
             ...
             ValueError: algorithm must be one of 'pari', 'generic'
@@ -315,7 +315,7 @@ class EllipticCurveLocalData(SageObject):
 
         INPUT:
 
-        - ``reduce`` -- (default: ``True``) if set to ``True`` and if
+        - ``reduce`` -- boolean (default: ``True``); if set to ``True`` and if
           the initial elliptic curve had globally integral
           coefficients, then the elliptic curve returned by Tate's
           algorithm will be "reduced" as specified in _reduce_model()
@@ -346,15 +346,15 @@ class EllipticCurveLocalData(SageObject):
              over Number Field in a with defining polynomial x^3 + x + 1
 
             sage: E = EllipticCurve([2, 1, 0, -2, -1])
-            sage: E.local_data(ZZ.ideal(2), algorithm="generic").minimal_model(reduce=False)
+            sage: E.local_data(ZZ.ideal(2), algorithm='generic').minimal_model(reduce=False)
             Elliptic Curve defined by y^2 + 2*x*y + 2*y = x^3 + x^2 - 4*x - 2 over Rational Field
-            sage: E.local_data(ZZ.ideal(2), algorithm="pari").minimal_model(reduce=False)
+            sage: E.local_data(ZZ.ideal(2), algorithm='pari').minimal_model(reduce=False)
             Traceback (most recent call last):
             ...
             ValueError: the argument reduce must not be False if algorithm=pari is used
-            sage: E.local_data(ZZ.ideal(2), algorithm="generic").minimal_model()
+            sage: E.local_data(ZZ.ideal(2), algorithm='generic').minimal_model()
             Elliptic Curve defined by y^2 = x^3 - x^2 - 3*x + 2 over Rational Field
-            sage: E.local_data(ZZ.ideal(2), algorithm="pari").minimal_model()
+            sage: E.local_data(ZZ.ideal(2), algorithm='pari').minimal_model()
             Elliptic Curve defined by y^2 = x^3 - x^2 - 3*x + 2 over Rational Field
 
         :issue:`14476`::
@@ -508,7 +508,7 @@ class EllipticCurveLocalData(SageObject):
 
         OUTPUT:
 
-        (int or ``None``):
+        integer or ``None``:
 
         - +1 for split multiplicative reduction
         - -1 for non-split multiplicative reduction
@@ -697,12 +697,12 @@ class EllipticCurveLocalData(SageObject):
 
         (tuple) ``(Emin, p, val_disc, fp, KS, cp)`` where:
 
-        - ``Emin`` (EllipticCurve) is a model (integral and) minimal at P
-        - ``p`` (int) is the residue characteristic
-        - ``val_disc`` (int) is the valuation of the local minimal discriminant
-        - ``fp`` (int) is the valuation of the conductor
-        - ``KS`` (string) is the Kodaira symbol
-        - ``cp`` (int) is the Tamagawa number
+        - ``Emin`` -- :class:`EllipticCurve`; a model (integral and) minimal at P
+        - ``p`` -- integer; the residue characteristic
+        - ``val_disc`` -- integer; the valuation of the local minimal discriminant
+        - ``fp`` -- integer; the valuation of the conductor
+        - ``KS`` -- string; the Kodaira symbol
+        - ``cp`` -- integer; the Tamagawa number
 
         EXAMPLES (this raised a type error in sage prior to 4.4.4, see :issue:`7930`) ::
 
@@ -759,7 +759,7 @@ class EllipticCurveLocalData(SageObject):
         # reduce (mod P) elements of K which are not integral (but are
         # P-integral).  However, if the model is non-minimal and we
         # end up dividing a_i by pi^i then at that point we use a
-        # uniformiser pi which has non-positive valuation at all other
+        # uniformiser pi which has nonpositive valuation at all other
         # primes, so that we can divide by it without losing
         # integrality at other primes.
 
@@ -805,7 +805,8 @@ class EllipticCurveLocalData(SageObject):
 
         def _pquadroots(a, b, c):
             r"""
-            Local function returning True iff `ax^2 + bx + c` has roots modulo `P`
+            Local function returning ``True`` iff `ax^2 + bx + c` has roots
+            modulo `P`.
             """
             (a, b, c) = (F(a), F(b), F(c))
             if a == 0:
@@ -1129,19 +1130,17 @@ def check_prime(K, P):
 
     INPUT:
 
-    - ``K`` -- a number field (including `\QQ`).
+    - ``K`` -- a number field (including `\QQ`)
 
-    - ``P`` -- an element of ``K`` or a (fractional) ideal of ``K``.
+    - ``P`` -- an element of ``K`` or a (fractional) ideal of ``K``
 
-    OUTPUT:
-
-    - If ``K`` is `\QQ`: the prime integer equal to or which generates `P`.
+    OUTPUT: if ``K`` is `\QQ`: the prime integer equal to or which generates `P`
 
     - If ``K`` is not `\QQ`: the prime ideal equal to or generated by `P`.
 
     .. NOTE::
 
-        If `P` is not a prime and does not generate a prime, a :class:`TypeError`
+        If `P` is not a prime and does not generate a prime, a :exc:`TypeError`
         is raised.
 
     EXAMPLES::
@@ -1162,7 +1161,7 @@ def check_prime(K, P):
         sage: check_prime(K, a + 1)
         Fractional ideal (a + 1)
         sage: [check_prime(K, P) for P in K.primes_above(31)]
-        [Fractional ideal (5/2*a + 1/2), Fractional ideal (5/2*a - 1/2)]
+        [Fractional ideal (-5/2*a - 1/2), Fractional ideal (-5/2*a + 1/2)]
         sage: L.<b> = NumberField(x^2 + 3)
         sage: check_prime(K, L.ideal(5))
         Traceback (most recent call last):
@@ -1185,7 +1184,7 @@ def check_prime(K, P):
                 raise TypeError("The element %s is not prime" % (P,))
         elif P in QQ:
             raise TypeError("The element %s is not prime" % (P,))
-        elif is_Ideal(P) and P.base_ring() is ZZ:
+        elif isinstance(P, Ideal_generic) and P.base_ring() is ZZ:
             if P.is_prime():
                 return P.gen()
             else:
