@@ -33,15 +33,18 @@ EXAMPLES::
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
 
-from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
+import sage.schemes.curves.projective_curve as plane_curve
+
+from sage.misc.lazy_import import lazy_import
 from sage.rings.big_oh import O
-from sage.rings.power_series_ring import PowerSeriesRing
 from sage.rings.laurent_series_ring import LaurentSeriesRing
+from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
+from sage.rings.power_series_ring import PowerSeriesRing
 from sage.rings.real_mpfr import RR
-from sage.functions.all import log
 from sage.structure.category_object import normalize_names
 
-import sage.schemes.curves.projective_curve as plane_curve
+lazy_import("sage.functions.all", "log")
+
 
 def is_HyperellipticCurve(C):
     """
@@ -127,7 +130,7 @@ class HyperellipticCurve_generic(plane_curve.ProjectivePlaneCurve):
 
     def change_ring(self, R):
         """
-        Returns this HyperellipticCurve over a new base ring ``R``.
+        Return this HyperellipticCurve over a new base ring ``R``.
 
         EXAMPLES::
 
@@ -169,16 +172,44 @@ class HyperellipticCurve_generic(plane_curve.ProjectivePlaneCurve):
             Hyperelliptic Curve over Rational Field defined by y^2 = 4*x^5 - 30*x^3 + 45*x - 22
             sage: C = HyperellipticCurve(f,names='u,v'); C
             Hyperelliptic Curve over Rational Field defined by v^2 = 4*u^5 - 30*u^3 + 45*u - 22
+            sage: C = HyperellipticCurve(x^5 + 1, x^3 + 2); C
+            Hyperelliptic Curve over Rational Field defined by y^2 + (x^3 + 2)*y = x^5 + 1
         """
 
         f, h = self._hyperelliptic_polynomials
         R = self.base_ring()
         y = self._printing_ring.gen()
         x = self._printing_ring.base_ring().gen()
-        if h == 0:
+        if h.is_zero():
             return "Hyperelliptic Curve over %s defined by %s = %s" % (R, y**2, f(x))
-        else:
-            return "Hyperelliptic Curve over %s defined by %s + %s = %s" % (R, y**2, h(x)*y, f(x))
+        return "Hyperelliptic Curve over %s defined by %s + %s = %s" % (R, y**2, h(x)*y, f(x))
+
+    def _latex_(self):
+        r"""
+        LaTeX representation of hyperelliptic curves.
+
+        EXAMPLES::
+
+            sage: P.<x> = QQ[]
+            sage: f = 4*x^5 - 30*x^3 + 45*x - 22
+            sage: C = HyperellipticCurve(f); latex(C)
+            \text{Hyperelliptic Curve over $\Bold{Q}$ defined by $y^{2} = 4 x^{5} - 30 x^{3} + 45 x - 22$}
+            sage: C = HyperellipticCurve(f,names='u,v'); latex(C)
+            \text{Hyperelliptic Curve over $\Bold{Q}$ defined by $v^{2} = 4 u^{5} - 30 u^{3} + 45 u - 22$}
+            sage: C = HyperellipticCurve(x^5 + 1, x^2 + 3); latex(C)
+            \text{Hyperelliptic Curve over $\Bold{Q}$ defined by $y^{2} + \left(x^{2} + 3\right) y = x^{5} + 1$}
+        """
+
+        f, h = self._hyperelliptic_polynomials
+        R = self.base_ring()
+        y = self._printing_ring.gen()
+        x = self._printing_ring.base_ring().gen()
+        if h.is_zero():
+            return (fr'\text{{Hyperelliptic Curve over ${R._latex_()}$ '
+                    f'defined by ${(y**2)._latex_()} = {(f(x))._latex_()}$}}')
+        return (fr'\text{{Hyperelliptic Curve over ${R._latex_()}$ '
+                f'defined by ${(y**2)._latex_()} + {(h(x)*y)._latex_()} = '
+                f'{(f(x))._latex_()}$}}')
 
     def hyperelliptic_polynomials(self, K=None, var='x'):
         """
@@ -198,7 +229,7 @@ class HyperellipticCurve_generic(plane_curve.ProjectivePlaneCurve):
 
     def is_singular(self):
         r"""
-        Returns False, because hyperelliptic curves are smooth projective
+        Return ``False``, because hyperelliptic curves are smooth projective
         curves, as checked on construction.
 
         EXAMPLES::
@@ -226,7 +257,7 @@ class HyperellipticCurve_generic(plane_curve.ProjectivePlaneCurve):
 
     def is_smooth(self):
         r"""
-        Returns True, because hyperelliptic curves are smooth projective
+        Return ``True``, because hyperelliptic curves are smooth projective
         curves, as checked on construction.
 
         EXAMPLES::
@@ -255,7 +286,7 @@ class HyperellipticCurve_generic(plane_curve.ProjectivePlaneCurve):
 
     def is_x_coord(self, x):
         """
-        Return True if ``x`` is the `x`-coordinate of a point on this curve.
+        Return ``True`` if ``x`` is the `x`-coordinate of a point on this curve.
 
         .. SEEALSO::
 
@@ -268,9 +299,8 @@ class HyperellipticCurve_generic(plane_curve.ProjectivePlaneCurve):
 
         - ``x`` -- an element of the base ring of the curve
 
-        OUTPUT:
-
-        A bool stating whether or not `x` is a x-coordinate of a point on the curve
+        OUTPUT: boolean stating whether or not `x` is a x-coordinate of a point
+        on the curve
 
         EXAMPLES:
 
@@ -370,13 +400,11 @@ class HyperellipticCurve_generic(plane_curve.ProjectivePlaneCurve):
 
         - ``x`` -- an element of the base ring of the curve
 
-        - ``all`` (bool, default ``False``) -- if ``True``, return a
-          (possibly empty) list of all points; if ``False``, return
-          just one point, or raise a :class:`ValueError` if there are none.
+        - ``all`` -- boolean (default: ``False``); if ``True``, return a
+          (possibly empty) list of all points. If ``False``, return
+          just one point, or raise a :exc:`ValueError` if there are none.
 
-        OUTPUT:
-
-        A point or list of up to two points on this curve.
+        OUTPUT: a point or list of up to two points on this curve
 
         .. SEEALSO::
 
@@ -522,7 +550,8 @@ class HyperellipticCurve_generic(plane_curve.ProjectivePlaneCurve):
 
     def odd_degree_model(self):
         r"""
-        Return an odd degree model of self, or raise ValueError if one does not exist over the field of definition.
+        Return an odd degree model of ``self``, or raise :exc:`ValueError` if
+        one does not exist over the field of definition.
 
         EXAMPLES::
 
@@ -603,7 +632,8 @@ class HyperellipticCurve_generic(plane_curve.ProjectivePlaneCurve):
 
     def has_odd_degree_model(self):
         r"""
-        Return True if an odd degree model of self exists over the field of definition; False otherwise.
+        Return ``True`` if an odd degree model of ``self`` exists over the
+        field of definition; ``False`` otherwise.
 
         Use ``odd_degree_model`` to calculate an odd degree model.
 
@@ -639,7 +669,7 @@ class HyperellipticCurve_generic(plane_curve.ProjectivePlaneCurve):
             Hyperelliptic Curve over Finite Field in a of size 3^2
             defined by y^2 + x^10*y = x^3 + x + 2
             sage: D = magma(C); D                                                       # needs sage.rings.finite_rings
-            Hyperelliptic Curve defined by y^2 + (x^10)*y = x^3 + x + 2 over GF(3^2)
+            Hyperelliptic Curve defined by y^2 + x^10*y = x^3 + x + 2 over GF(3^2)
             sage: D.sage()                                                              # needs sage.rings.finite_rings
             Hyperelliptic Curve over Finite Field in a of size 3^2
             defined by y^2 + x^10*y = x^3 + x + 2
@@ -654,8 +684,8 @@ class HyperellipticCurve_generic(plane_curve.ProjectivePlaneCurve):
 
     def invariant_differential(self):
         """
-        Returns `dx/2y`, as an element of the Monsky-Washnitzer cohomology
-        of self
+        Return `dx/2y`, as an element of the Monsky-Washnitzer cohomology
+        of ``self``.
 
         EXAMPLES::
 
@@ -663,7 +693,6 @@ class HyperellipticCurve_generic(plane_curve.ProjectivePlaneCurve):
             sage: C = HyperellipticCurve(x^5 - 4*x + 4)
             sage: C.invariant_differential()
             1 dx/2y
-
         """
         import sage.schemes.hyperelliptic_curves.monsky_washnitzer as m_w
         S = m_w.SpecialHyperellipticQuotientRing(self)
@@ -678,8 +707,8 @@ class HyperellipticCurve_generic(plane_curve.ProjectivePlaneCurve):
 
         INPUT:
 
-        - ``P = (a, b)`` -- a non-Weierstrass point on self
-        - ``prec`` --  desired precision of the local coordinates
+        - ``P = (a, b)`` -- a non-Weierstrass point on ``self``
+        - ``prec`` -- desired precision of the local coordinates
         - ``name`` -- gen of the power series ring (default: ``t``)
 
         OUTPUT:
@@ -730,7 +759,7 @@ class HyperellipticCurve_generic(plane_curve.ProjectivePlaneCurve):
 
         INPUT:
 
-        - ``P`` -- a finite Weierstrass point on self
+        - ``P`` -- a finite Weierstrass point on ``self``
         - ``prec`` -- desired precision of the local coordinates
         - ``name`` -- gen of the power series ring (default: `t`)
 
@@ -832,11 +861,11 @@ class HyperellipticCurve_generic(plane_curve.ProjectivePlaneCurve):
 
     def local_coord(self, P, prec=20, name='t'):
         """
-        Calls the appropriate local_coordinates function
+        Call the appropriate local_coordinates function.
 
         INPUT:
 
-        - ``P`` -- a point on self
+        - ``P`` -- a point on ``self``
         - ``prec`` -- desired precision of the local coordinates
         - ``name`` -- generator of the power series ring (default: ``t``)
 
