@@ -23,24 +23,22 @@ AUTHORS:
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 
-from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
-from sage.rings.integer_ring import ZZ
-from sage.rings.rational_field import QQ
-
 import sage.rings.abc
 
-from sage.structure.sequence import Sequence
-from sage.schemes.projective.projective_space import ProjectiveSpace
-from sage.matrix.constructor import Matrix
-
-from sage.quadratic_forms.qfsolve import qfsolve, qfparam
-
-from .con_number_field import ProjectiveConic_number_field
-
-from sage.structure.element import InfinityElement
-
 from sage.arith.functions import lcm
 from sage.arith.misc import hilbert_symbol
+from sage.matrix.constructor import Matrix
+from sage.misc.lazy_import import lazy_import
+from sage.rings.integer_ring import ZZ
+from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
+from sage.rings.rational_field import QQ
+from sage.schemes.projective.projective_space import ProjectiveSpace
+from sage.structure.element import InfinityElement
+from sage.structure.sequence import Sequence
+
+lazy_import('sage.quadratic_forms.qfsolve', ['qfsolve', 'qfparam'])
+
+from .con_number_field import ProjectiveConic_number_field
 
 
 class ProjectiveConic_rational_field(ProjectiveConic_number_field):
@@ -98,16 +96,16 @@ class ProjectiveConic_rational_field(ProjectiveConic_number_field):
         The parameter ``algorithm``
         specifies the algorithm to be used:
 
-        - ``'qfsolve'`` -- Use PARI/GP function :pari:`qfsolve`
+        - ``'qfsolve'`` -- use PARI/GP function :pari:`qfsolve`
 
-        - ``'rnfisnorm'`` -- Use PARI's function :pari:`rnfisnorm`
+        - ``'rnfisnorm'`` -- use PARI's function :pari:`rnfisnorm`
           (cannot be combined with ``obstruction = True``)
 
-        - ``'local'`` -- Check if a local solution exists for all primes
+        - ``'local'`` -- check if a local solution exists for all primes
           and infinite places of `\QQ` and apply the Hasse principle
           (cannot be combined with ``point = True``)
 
-        - ``'default'`` -- Use ``'qfsolve'``
+        - ``'default'`` -- use ``'qfsolve'``
 
         - ``'magma'`` (requires Magma to be installed) --
           delegates the task to the Magma computer algebra system.
@@ -359,7 +357,7 @@ class ProjectiveConic_rational_field(ProjectiveConic_number_field):
             sage: i[0](p) / i[1](p)
             x/y
 
-        A :class:`ValueError` is raised if ``self`` has no rational point ::
+        A :exc:`ValueError` is raised if ``self`` has no rational point ::
 
             sage: # needs sage.libs.pari
             sage: C = Conic(x^2 + 2*y^2 + z^2)
@@ -369,7 +367,7 @@ class ProjectiveConic_rational_field(ProjectiveConic_number_field):
             ValueError: Conic Projective Conic Curve over Rational Field defined
             by x^2 + 2*y^2 + z^2 has no rational points over Rational Field!
 
-        A :class:`ValueError` is raised if ``self`` is not smooth ::
+        A :exc:`ValueError` is raised if ``self`` is not smooth ::
 
             sage: # needs sage.libs.pari
             sage: C = Conic(x^2 + y^2)
